@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011-2019, The DART development contributors
+ * Copyright (c) 2011-2021, The DART development contributors
  * All rights reserved.
  *
  * The list of contributors can be found at:
@@ -30,50 +30,47 @@
  *   POSSIBILITY OF SUCH DAMAGE.
  */
 
-// Must be included before any Bullet headers.
-#include "dart/config.hpp"
+#include "dart/collision/bullet/BulletCollisionDetector.hpp"
 
 #include <algorithm>
 
-#include "dart/collision/bullet/BulletCollisionDetector.hpp"
-
-#include <BulletCollision/Gimpact/btGImpactShape.h>
-#include <BulletCollision/CollisionShapes/btHeightfieldTerrainShape.h>
-
-#include "dart/common/Console.hpp"
-#include "dart/collision/CollisionObject.hpp"
 #include "dart/collision/CollisionFilter.hpp"
-#include "dart/collision/bullet/BulletTypes.hpp"
-#include "dart/collision/bullet/BulletCollisionObject.hpp"
+#include "dart/collision/CollisionObject.hpp"
 #include "dart/collision/bullet/BulletCollisionGroup.hpp"
+#include "dart/collision/bullet/BulletCollisionObject.hpp"
+#include "dart/collision/bullet/BulletInclude.hpp"
+#include "dart/collision/bullet/BulletTypes.hpp"
 #include "dart/collision/bullet/detail/BulletCollisionDispatcher.hpp"
 #include "dart/collision/bullet/detail/BulletOverlapFilterCallback.hpp"
-#include "dart/dynamics/ShapeFrame.hpp"
-#include "dart/dynamics/Shape.hpp"
-#include "dart/dynamics/SphereShape.hpp"
+#include "dart/common/Console.hpp"
 #include "dart/dynamics/BoxShape.hpp"
-#include "dart/dynamics/EllipsoidShape.hpp"
-#include "dart/dynamics/CylinderShape.hpp"
 #include "dart/dynamics/CapsuleShape.hpp"
 #include "dart/dynamics/ConeShape.hpp"
-#include "dart/dynamics/PlaneShape.hpp"
-#include "dart/dynamics/MultiSphereConvexHullShape.hpp"
-#include "dart/dynamics/MeshShape.hpp"
-#include "dart/dynamics/SoftMeshShape.hpp"
+#include "dart/dynamics/CylinderShape.hpp"
+#include "dart/dynamics/EllipsoidShape.hpp"
 #include "dart/dynamics/HeightmapShape.hpp"
+#include "dart/dynamics/MeshShape.hpp"
+#include "dart/dynamics/MultiSphereConvexHullShape.hpp"
+#include "dart/dynamics/PlaneShape.hpp"
+#include "dart/dynamics/Shape.hpp"
+#include "dart/dynamics/ShapeFrame.hpp"
+#include "dart/dynamics/SoftMeshShape.hpp"
+#include "dart/dynamics/SphereShape.hpp"
 
 namespace dart {
 namespace collision {
 
 namespace {
 
-Contact convertContact(const btManifoldPoint& bulletManifoldPoint,
-                       BulletCollisionObject* collObj1,
-                       BulletCollisionObject* collObj2);
+Contact convertContact(
+    const btManifoldPoint& bulletManifoldPoint,
+    BulletCollisionObject* collObj1,
+    BulletCollisionObject* collObj2);
 
-void reportContacts(btCollisionWorld* collWorld,
-                     const CollisionOption& option,
-                     CollisionResult& result);
+void reportContacts(
+    btCollisionWorld* collWorld,
+    const CollisionOption& option,
+    CollisionResult& result);
 
 void reportRayHits(
     const btCollisionWorld::ClosestRayResultCallback callback,
@@ -91,7 +88,8 @@ std::unique_ptr<btCollisionShape> createBulletEllipsoidMesh(
 std::unique_ptr<btCollisionShape> createBulletCollisionShapeFromAssimpScene(
     const Eigen::Vector3d& scale, const aiScene* scene);
 
-std::unique_ptr<btCollisionShape> createBulletCollisionShapeFromAssimpMesh(const aiMesh* mesh);
+std::unique_ptr<btCollisionShape> createBulletCollisionShapeFromAssimpMesh(
+    const aiMesh* mesh);
 
 template <typename HeightmapShapeT>
 std::unique_ptr<BulletCollisionShape> createBulletCollisionShapeFromHeightmap(
@@ -101,17 +99,17 @@ std::unique_ptr<BulletCollisionShape> createBulletCollisionShapeFromHeightmap(
 
 //==============================================================================
 BulletCollisionDetector::Registrar<BulletCollisionDetector>
-BulletCollisionDetector::mRegistrar{
-  BulletCollisionDetector::getStaticType(),
-  []() -> std::shared_ptr<dart::collision::BulletCollisionDetector> {
-      return dart::collision::BulletCollisionDetector::create();
-  }};
+    BulletCollisionDetector::mRegistrar{
+        BulletCollisionDetector::getStaticType(),
+        []() -> std::shared_ptr<dart::collision::BulletCollisionDetector> {
+          return dart::collision::BulletCollisionDetector::create();
+        }};
 
 //==============================================================================
 std::shared_ptr<BulletCollisionDetector> BulletCollisionDetector::create()
 {
   return std::shared_ptr<BulletCollisionDetector>(
-        new BulletCollisionDetector());
+      new BulletCollisionDetector());
 }
 
 //==============================================================================
@@ -141,8 +139,7 @@ const std::string& BulletCollisionDetector::getStaticType()
 }
 
 //==============================================================================
-std::unique_ptr<CollisionGroup>
-BulletCollisionDetector::createCollisionGroup()
+std::unique_ptr<CollisionGroup> BulletCollisionDetector::createCollisionGroup()
 {
   return std::make_unique<BulletCollisionGroup>(shared_from_this());
 }
@@ -189,8 +186,8 @@ void filterOutCollisions(btCollisionWorld* world)
 {
   assert(world);
 
-  auto dispatcher = static_cast<detail::BulletCollisionDispatcher*>(
-      world->getDispatcher());
+  auto dispatcher
+      = static_cast<detail::BulletCollisionDispatcher*>(world->getDispatcher());
   assert(dispatcher);
 
   const auto filter = dispatcher->getFilter();
@@ -265,8 +262,10 @@ bool BulletCollisionDetector::collide(
 
 //==============================================================================
 bool BulletCollisionDetector::collide(
-    CollisionGroup* group1, CollisionGroup* group2,
-    const CollisionOption& option, CollisionResult* result)
+    CollisionGroup* group1,
+    CollisionGroup* group2,
+    const CollisionOption& option,
+    CollisionResult* result)
 {
   if (result)
     result->clear();
@@ -280,17 +279,12 @@ bool BulletCollisionDetector::collide(
   if (!checkGroupValidity(this, group2))
     return false;
 
-  dtwarn << "[BulletCollisionDetector::collide] collide(group1, group2) "
-         << "supposed to check collisions of the objects in group1 against the "
-         << "objects in group2. However, the current implementation of this "
-         << "function checks for all the objects against each other of both "
-         << "group1 and group2, which is an incorrect behavior. This bug will "
-         << "be fixed in the next patch release. (see #717 for the details)\n";
-
+  // Create a new collision group, merging the two groups into
   mGroupForFiltering.reset(new BulletCollisionGroup(shared_from_this()));
   auto bulletCollisionWorld = mGroupForFiltering->getBulletCollisionWorld();
   auto bulletPairCache = bulletCollisionWorld->getPairCache();
-  auto filterCallback = new detail::BulletOverlapFilterCallback(option.collisionFilter);
+  auto filterCallback = new detail::BulletOverlapFilterCallback(
+      option.collisionFilter, group1, group2);
   bulletPairCache->setOverlapFilterCallback(filterCallback);
 
   mGroupForFiltering->addShapeFramesOf(group1, group2);
@@ -316,8 +310,14 @@ double BulletCollisionDetector::distance(
     const DistanceOption& /*option*/,
     DistanceResult* /*result*/)
 {
-  dtwarn << "[BulletCollisionDetector::distance] This collision detector does "
-         << "not support (signed) distance queries. Returning 0.0.\n";
+  static bool warned = false;
+  if (!warned)
+  {
+    dtwarn
+        << "[BulletCollisionDetector::distance] This collision detector does "
+        << "not support (signed) distance queries. Returning 0.0.\n";
+    warned = true;
+  }
 
   return 0.0;
 }
@@ -329,8 +329,14 @@ double BulletCollisionDetector::distance(
     const DistanceOption& /*option*/,
     DistanceResult* /*result*/)
 {
-  dtwarn << "[BulletCollisionDetector::distance] This collision detector does "
-         << "not support (signed) distance queries. Returning.\n";
+  static bool warned = false;
+  if (!warned)
+  {
+    dtwarn
+        << "[BulletCollisionDetector::distance] This collision detector does "
+        << "not support (signed) distance queries. Returning.\n";
+    warned = true;
+  }
 
   return 0.0;
 }
@@ -362,14 +368,17 @@ bool BulletCollisionDetector::raycast(
     castedGroup->updateEngineData();
     collisionWorld->rayTest(btFrom, btTo, callback);
 
-    if (result)
+    if (result == nullptr)
+      return callback.hasHit();
+
+    if (callback.hasHit())
     {
       reportRayHits(callback, option, *result);
       return result->hasHit();
     }
     else
     {
-      return callback.hasHit();
+      return false;
     }
   }
   else
@@ -378,21 +387,23 @@ bool BulletCollisionDetector::raycast(
     castedGroup->updateEngineData();
     collisionWorld->rayTest(btFrom, btTo, callback);
 
-    if (result)
+    if (result == nullptr)
+      return callback.hasHit();
+
+    if (callback.hasHit())
     {
       reportRayHits(callback, option, *result);
       return result->hasHit();
     }
     else
     {
-      return callback.hasHit();
+      return false;
     }
   }
 }
 
 //==============================================================================
-BulletCollisionDetector::BulletCollisionDetector()
-  : CollisionDetector()
+BulletCollisionDetector::BulletCollisionDetector() : CollisionDetector()
 {
   mCollisionObjectManager.reset(new ManagerForUnsharableCollisionObjects(this));
 }
@@ -404,7 +415,7 @@ std::unique_ptr<CollisionObject> BulletCollisionDetector::createCollisionObject(
   auto bulletCollShape = claimBulletCollisionShape(shapeFrame->getShape());
 
   return std::unique_ptr<BulletCollisionObject>(
-        new BulletCollisionObject(this, shapeFrame, bulletCollShape));
+      new BulletCollisionObject(this, shapeFrame, bulletCollShape));
 }
 
 //==============================================================================
@@ -414,7 +425,7 @@ void BulletCollisionDetector::refreshCollisionObject(CollisionObject* object)
 
   bullet->mBulletCollisionShape = claimBulletCollisionShape(bullet->getShape());
   bullet->mBulletCollisionObject->setCollisionShape(
-        bullet->mBulletCollisionShape->mCollisionShape.get());
+      bullet->mBulletCollisionShape->mCollisionShape.get());
 }
 
 //==============================================================================
@@ -444,8 +455,8 @@ BulletCollisionDetector::claimBulletCollisionShape(
   }
 
   auto newBulletCollisionShape = std::shared_ptr<BulletCollisionShape>(
-        createBulletCollisionShape(shape).release(),
-        BulletCollisionShapeDeleter(this, shape));
+      createBulletCollisionShape(shape).release(),
+      BulletCollisionShapeDeleter(this, shape));
   info.mShape = newBulletCollisionShape;
   info.mLastKnownVersion = currentVersion;
 
@@ -457,11 +468,11 @@ void BulletCollisionDetector::reclaimBulletCollisionShape(
     const dynamics::ConstShapePtr& shape)
 {
   const auto& search = mShapeMap.find(shape);
-  if(search == mShapeMap.end())
+  if (search == mShapeMap.end())
     return;
 
   const auto& bulletShape = search->second.mShape.lock();
-  if(!bulletShape || bulletShape.use_count() <= 2)
+  if (!bulletShape || bulletShape.use_count() <= 2)
     mShapeMap.erase(search);
 }
 
@@ -470,19 +481,19 @@ std::unique_ptr<BulletCollisionShape>
 BulletCollisionDetector::createBulletCollisionShape(
     const dynamics::ConstShapePtr& shape)
 {
-  using dynamics::Shape;
-  using dynamics::SphereShape;
   using dynamics::BoxShape;
-  using dynamics::EllipsoidShape;
-  using dynamics::CylinderShape;
   using dynamics::CapsuleShape;
   using dynamics::ConeShape;
-  using dynamics::PlaneShape;
-  using dynamics::MultiSphereConvexHullShape;
-  using dynamics::MeshShape;
-  using dynamics::SoftMeshShape;
-  using dynamics::HeightmapShapef;
+  using dynamics::CylinderShape;
+  using dynamics::EllipsoidShape;
   using dynamics::HeightmapShaped;
+  using dynamics::HeightmapShapef;
+  using dynamics::MeshShape;
+  using dynamics::MultiSphereConvexHullShape;
+  using dynamics::PlaneShape;
+  using dynamics::Shape;
+  using dynamics::SoftMeshShape;
+  using dynamics::SphereShape;
 
   if (shape->is<SphereShape>())
   {
@@ -494,7 +505,7 @@ BulletCollisionDetector::createBulletCollisionShape(
     auto bulletCollisionShape = std::make_unique<btSphereShape>(radius);
 
     return std::make_unique<BulletCollisionShape>(
-          std::move(bulletCollisionShape));
+        std::move(bulletCollisionShape));
   }
   else if (shape->is<BoxShape>())
   {
@@ -504,10 +515,10 @@ BulletCollisionDetector::createBulletCollisionShape(
     const Eigen::Vector3d& size = box->getSize();
 
     auto bulletCollisionShape
-        = std::make_unique<btBoxShape>(convertVector3(size*0.5));
+        = std::make_unique<btBoxShape>(convertVector3(size * 0.5));
 
     return std::make_unique<BulletCollisionShape>(
-          std::move(bulletCollisionShape));
+        std::move(bulletCollisionShape));
   }
   else if (shape->is<EllipsoidShape>())
   {
@@ -517,10 +528,10 @@ BulletCollisionDetector::createBulletCollisionShape(
     const Eigen::Vector3d& radii = ellipsoid->getRadii();
 
     auto bulletCollisionShape = createBulletEllipsoidMesh(
-          radii[0]*2.0, radii[1]*2.0, radii[2]*2.0);
+        radii[0] * 2.0, radii[1] * 2.0, radii[2] * 2.0);
 
     return std::make_unique<BulletCollisionShape>(
-          std::move(bulletCollisionShape));
+        std::move(bulletCollisionShape));
   }
   else if (shape->is<CylinderShape>())
   {
@@ -534,7 +545,7 @@ BulletCollisionDetector::createBulletCollisionShape(
     auto bulletCollisionShape = std::make_unique<btCylinderShapeZ>(size);
 
     return std::make_unique<BulletCollisionShape>(
-          std::move(bulletCollisionShape));
+        std::move(bulletCollisionShape));
   }
   else if (shape->is<CapsuleShape>())
   {
@@ -548,7 +559,7 @@ BulletCollisionDetector::createBulletCollisionShape(
         = std::make_unique<btCapsuleShapeZ>(radius, height);
 
     return std::make_unique<BulletCollisionShape>(
-          std::move(bulletCollisionShape));
+        std::move(bulletCollisionShape));
   }
   else if (shape->is<ConeShape>())
   {
@@ -558,8 +569,7 @@ BulletCollisionDetector::createBulletCollisionShape(
     const auto radius = cone->getRadius();
     const auto height = cone->getHeight();
 
-    auto bulletCollisionShape
-        = std::make_unique<btConeShapeZ>(radius, height);
+    auto bulletCollisionShape = std::make_unique<btConeShapeZ>(radius, height);
     bulletCollisionShape->setMargin(0.0);
     // TODO(JS): Bullet seems to use constant margin 0.4, however this could be
     // dangerous when the cone is sufficiently small. We use zero margin here
@@ -567,7 +577,7 @@ BulletCollisionDetector::createBulletCollisionShape(
     // https://www.sjbaker.org/wiki/index.php?title=Physics_-_Bullet_Collected_random_advice#Minimum_object_sizes_-_by_Erwin
 
     return std::make_unique<BulletCollisionShape>(
-          std::move(bulletCollisionShape));
+        std::move(bulletCollisionShape));
   }
   else if (shape->is<PlaneShape>())
   {
@@ -577,11 +587,11 @@ BulletCollisionDetector::createBulletCollisionShape(
     const Eigen::Vector3d normal = plane->getNormal();
     const double offset = plane->getOffset();
 
-    auto bulletCollisionShape = std::make_unique<btStaticPlaneShape>(
-          convertVector3(normal), offset);
+    auto bulletCollisionShape
+        = std::make_unique<btStaticPlaneShape>(convertVector3(normal), offset);
 
     return std::make_unique<BulletCollisionShape>(
-          std::move(bulletCollisionShape));
+        std::move(bulletCollisionShape));
   }
   else if (shape->is<MultiSphereConvexHullShape>())
   {
@@ -602,10 +612,10 @@ BulletCollisionDetector::createBulletCollisionShape(
     }
 
     auto bulletCollisionShape = std::make_unique<btMultiSphereShape>(
-          bulletPositions.data(), bulletRadii.data(), numSpheres);
+        bulletPositions.data(), bulletRadii.data(), numSpheres);
 
     return std::make_unique<BulletCollisionShape>(
-          std::move(bulletCollisionShape));
+        std::move(bulletCollisionShape));
   }
   else if (shape->is<MeshShape>())
   {
@@ -615,11 +625,11 @@ BulletCollisionDetector::createBulletCollisionShape(
     const auto scale = shapeMesh->getScale();
     const auto mesh = shapeMesh->getMesh();
 
-    auto bulletCollisionShape = createBulletCollisionShapeFromAssimpScene(
-          scale, mesh);
+    auto bulletCollisionShape
+        = createBulletCollisionShapeFromAssimpScene(scale, mesh);
 
     return std::make_unique<BulletCollisionShape>(
-          std::move(bulletCollisionShape));
+        std::move(bulletCollisionShape));
   }
   else if (shape->is<SoftMeshShape>())
   {
@@ -631,7 +641,7 @@ BulletCollisionDetector::createBulletCollisionShape(
     auto bulletCollisionShape = createBulletCollisionShapeFromAssimpMesh(mesh);
 
     return std::make_unique<BulletCollisionShape>(
-          std::move(bulletCollisionShape));
+        std::move(bulletCollisionShape));
   }
   else if (shape->is<HeightmapShapef>())
   {
@@ -651,7 +661,7 @@ BulletCollisionDetector::createBulletCollisionShape(
           << "instead.\n";
 
     return std::make_unique<BulletCollisionShape>(
-          std::make_unique<btSphereShape>(0.1));
+        std::make_unique<btSphereShape>(0.1));
 
     // take this back in as soon as bullet supports double in heightmaps
     // const auto heightMap = static_cast<const HeightmapShaped*>(shape.get());
@@ -665,24 +675,22 @@ BulletCollisionDetector::createBulletCollisionShape(
           << "instead.\n";
 
     return std::make_unique<BulletCollisionShape>(
-          std::make_unique<btSphereShape>(0.1));
+        std::make_unique<btSphereShape>(0.1));
   }
 }
 
 //==============================================================================
-BulletCollisionDetector::BulletCollisionShapeDeleter
-::BulletCollisionShapeDeleter(
-    BulletCollisionDetector* cd,
-    const dynamics::ConstShapePtr& shape)
-  : mBulletCollisionDetector(cd),
-    mShape(shape)
+BulletCollisionDetector::BulletCollisionShapeDeleter ::
+    BulletCollisionShapeDeleter(
+        BulletCollisionDetector* cd, const dynamics::ConstShapePtr& shape)
+  : mBulletCollisionDetector(cd), mShape(shape)
 {
   // Do nothing
 }
 
 //==============================================================================
-void BulletCollisionDetector::BulletCollisionShapeDeleter
-::operator()(BulletCollisionShape* shape) const
+void BulletCollisionDetector::BulletCollisionShapeDeleter ::operator()(
+    BulletCollisionShape* shape) const
 {
   mBulletCollisionDetector->reclaimBulletCollisionShape(mShape);
 
@@ -692,9 +700,10 @@ void BulletCollisionDetector::BulletCollisionShapeDeleter
 namespace {
 
 //==============================================================================
-Contact convertContact(const btManifoldPoint& bulletManifoldPoint,
-                       BulletCollisionObject* collObj1,
-                       BulletCollisionObject* collObj2)
+Contact convertContact(
+    const btManifoldPoint& bulletManifoldPoint,
+    BulletCollisionObject* collObj1,
+    BulletCollisionObject* collObj2)
 {
   assert(collObj1);
   assert(collObj2);
@@ -718,8 +727,8 @@ void reportContacts(
 {
   assert(world);
 
-  auto dispatcher = static_cast<detail::BulletCollisionDispatcher*>(
-      world->getDispatcher());
+  auto dispatcher
+      = static_cast<detail::BulletCollisionDispatcher*>(world->getDispatcher());
   assert(dispatcher);
 
   const auto numManifolds = dispatcher->getNumManifolds();
@@ -765,8 +774,8 @@ void reportContacts(
 //==============================================================================
 RayHit convertRayHit(
     const btCollisionObject* btCollObj,
-    btVector3	hitPointWorld,
-    btVector3	hitNormalWorld,
+    btVector3 hitPointWorld,
+    btVector3 hitNormalWorld,
     btScalar closestHitFraction)
 {
   RayHit rayHit;
@@ -789,6 +798,9 @@ void reportRayHits(
     const RaycastOption& /*option*/,
     RaycastResult& result)
 {
+  // This function shouldn't be called if callback has not ray hit.
+  assert(callback.hasHit());
+
   const auto rayHit = convertRayHit(
       callback.m_collisionObject,
       callback.m_hitPointWorld,
@@ -837,184 +849,90 @@ void reportRayHits(
 std::unique_ptr<btCollisionShape> createBulletEllipsoidMesh(
     float sizeX, float sizeY, float sizeZ)
 {
-  float v[59][3] =
-  {
-    {0, 0, 0},
-    {0.135299, -0.461940, -0.135299},
-    {0.000000, -0.461940, -0.191342},
-    {-0.135299, -0.461940, -0.135299},
-    {-0.191342, -0.461940, 0.000000},
-    {-0.135299, -0.461940, 0.135299},
-    {0.000000, -0.461940, 0.191342},
-    {0.135299, -0.461940, 0.135299},
-    {0.191342, -0.461940, 0.000000},
-    {0.250000, -0.353553, -0.250000},
-    {0.000000, -0.353553, -0.353553},
-    {-0.250000, -0.353553, -0.250000},
-    {-0.353553, -0.353553, 0.000000},
-    {-0.250000, -0.353553, 0.250000},
-    {0.000000, -0.353553, 0.353553},
-    {0.250000, -0.353553, 0.250000},
-    {0.353553, -0.353553, 0.000000},
-    {0.326641, -0.191342, -0.326641},
-    {0.000000, -0.191342, -0.461940},
-    {-0.326641, -0.191342, -0.326641},
-    {-0.461940, -0.191342, 0.000000},
-    {-0.326641, -0.191342, 0.326641},
-    {0.000000, -0.191342, 0.461940},
-    {0.326641, -0.191342, 0.326641},
-    {0.461940, -0.191342, 0.000000},
-    {0.353553, 0.000000, -0.353553},
-    {0.000000, 0.000000, -0.500000},
-    {-0.353553, 0.000000, -0.353553},
-    {-0.500000, 0.000000, 0.000000},
-    {-0.353553, 0.000000, 0.353553},
-    {0.000000, 0.000000, 0.500000},
-    {0.353553, 0.000000, 0.353553},
-    {0.500000, 0.000000, 0.000000},
-    {0.326641, 0.191342, -0.326641},
-    {0.000000, 0.191342, -0.461940},
-    {-0.326641, 0.191342, -0.326641},
-    {-0.461940, 0.191342, 0.000000},
-    {-0.326641, 0.191342, 0.326641},
-    {0.000000, 0.191342, 0.461940},
-    {0.326641, 0.191342, 0.326641},
-    {0.461940, 0.191342, 0.000000},
-    {0.250000, 0.353553, -0.250000},
-    {0.000000, 0.353553, -0.353553},
-    {-0.250000, 0.353553, -0.250000},
-    {-0.353553, 0.353553, 0.000000},
-    {-0.250000, 0.353553, 0.250000},
-    {0.000000, 0.353553, 0.353553},
-    {0.250000, 0.353553, 0.250000},
-    {0.353553, 0.353553, 0.000000},
-    {0.135299, 0.461940, -0.135299},
-    {0.000000, 0.461940, -0.191342},
-    {-0.135299, 0.461940, -0.135299},
-    {-0.191342, 0.461940, 0.000000},
-    {-0.135299, 0.461940, 0.135299},
-    {0.000000, 0.461940, 0.191342},
-    {0.135299, 0.461940, 0.135299},
-    {0.191342, 0.461940, 0.000000},
-    {0.000000, -0.500000, 0.000000},
-    {0.000000, 0.500000, 0.000000}
-  };
+  float v[59][3] = {{0, 0, 0},
+                    {0.135299, -0.461940, -0.135299},
+                    {0.000000, -0.461940, -0.191342},
+                    {-0.135299, -0.461940, -0.135299},
+                    {-0.191342, -0.461940, 0.000000},
+                    {-0.135299, -0.461940, 0.135299},
+                    {0.000000, -0.461940, 0.191342},
+                    {0.135299, -0.461940, 0.135299},
+                    {0.191342, -0.461940, 0.000000},
+                    {0.250000, -0.353553, -0.250000},
+                    {0.000000, -0.353553, -0.353553},
+                    {-0.250000, -0.353553, -0.250000},
+                    {-0.353553, -0.353553, 0.000000},
+                    {-0.250000, -0.353553, 0.250000},
+                    {0.000000, -0.353553, 0.353553},
+                    {0.250000, -0.353553, 0.250000},
+                    {0.353553, -0.353553, 0.000000},
+                    {0.326641, -0.191342, -0.326641},
+                    {0.000000, -0.191342, -0.461940},
+                    {-0.326641, -0.191342, -0.326641},
+                    {-0.461940, -0.191342, 0.000000},
+                    {-0.326641, -0.191342, 0.326641},
+                    {0.000000, -0.191342, 0.461940},
+                    {0.326641, -0.191342, 0.326641},
+                    {0.461940, -0.191342, 0.000000},
+                    {0.353553, 0.000000, -0.353553},
+                    {0.000000, 0.000000, -0.500000},
+                    {-0.353553, 0.000000, -0.353553},
+                    {-0.500000, 0.000000, 0.000000},
+                    {-0.353553, 0.000000, 0.353553},
+                    {0.000000, 0.000000, 0.500000},
+                    {0.353553, 0.000000, 0.353553},
+                    {0.500000, 0.000000, 0.000000},
+                    {0.326641, 0.191342, -0.326641},
+                    {0.000000, 0.191342, -0.461940},
+                    {-0.326641, 0.191342, -0.326641},
+                    {-0.461940, 0.191342, 0.000000},
+                    {-0.326641, 0.191342, 0.326641},
+                    {0.000000, 0.191342, 0.461940},
+                    {0.326641, 0.191342, 0.326641},
+                    {0.461940, 0.191342, 0.000000},
+                    {0.250000, 0.353553, -0.250000},
+                    {0.000000, 0.353553, -0.353553},
+                    {-0.250000, 0.353553, -0.250000},
+                    {-0.353553, 0.353553, 0.000000},
+                    {-0.250000, 0.353553, 0.250000},
+                    {0.000000, 0.353553, 0.353553},
+                    {0.250000, 0.353553, 0.250000},
+                    {0.353553, 0.353553, 0.000000},
+                    {0.135299, 0.461940, -0.135299},
+                    {0.000000, 0.461940, -0.191342},
+                    {-0.135299, 0.461940, -0.135299},
+                    {-0.191342, 0.461940, 0.000000},
+                    {-0.135299, 0.461940, 0.135299},
+                    {0.000000, 0.461940, 0.191342},
+                    {0.135299, 0.461940, 0.135299},
+                    {0.191342, 0.461940, 0.000000},
+                    {0.000000, -0.500000, 0.000000},
+                    {0.000000, 0.500000, 0.000000}};
 
-  int f[112][3] =
-  {
-    {1, 2, 9},
-    {9, 2, 10},
-    {2, 3, 10},
-    {10, 3, 11},
-    {3, 4, 11},
-    {11, 4, 12},
-    {4, 5, 12},
-    {12, 5, 13},
-    {5, 6, 13},
-    {13, 6, 14},
-    {6, 7, 14},
-    {14, 7, 15},
-    {7, 8, 15},
-    {15, 8, 16},
-    {8, 1, 16},
-    {16, 1, 9},
-    {9, 10, 17},
-    {17, 10, 18},
-    {10, 11, 18},
-    {18, 11, 19},
-    {11, 12, 19},
-    {19, 12, 20},
-    {12, 13, 20},
-    {20, 13, 21},
-    {13, 14, 21},
-    {21, 14, 22},
-    {14, 15, 22},
-    {22, 15, 23},
-    {15, 16, 23},
-    {23, 16, 24},
-    {16, 9, 24},
-    {24, 9, 17},
-    {17, 18, 25},
-    {25, 18, 26},
-    {18, 19, 26},
-    {26, 19, 27},
-    {19, 20, 27},
-    {27, 20, 28},
-    {20, 21, 28},
-    {28, 21, 29},
-    {21, 22, 29},
-    {29, 22, 30},
-    {22, 23, 30},
-    {30, 23, 31},
-    {23, 24, 31},
-    {31, 24, 32},
-    {24, 17, 32},
-    {32, 17, 25},
-    {25, 26, 33},
-    {33, 26, 34},
-    {26, 27, 34},
-    {34, 27, 35},
-    {27, 28, 35},
-    {35, 28, 36},
-    {28, 29, 36},
-    {36, 29, 37},
-    {29, 30, 37},
-    {37, 30, 38},
-    {30, 31, 38},
-    {38, 31, 39},
-    {31, 32, 39},
-    {39, 32, 40},
-    {32, 25, 40},
-    {40, 25, 33},
-    {33, 34, 41},
-    {41, 34, 42},
-    {34, 35, 42},
-    {42, 35, 43},
-    {35, 36, 43},
-    {43, 36, 44},
-    {36, 37, 44},
-    {44, 37, 45},
-    {37, 38, 45},
-    {45, 38, 46},
-    {38, 39, 46},
-    {46, 39, 47},
-    {39, 40, 47},
-    {47, 40, 48},
-    {40, 33, 48},
-    {48, 33, 41},
-    {41, 42, 49},
-    {49, 42, 50},
-    {42, 43, 50},
-    {50, 43, 51},
-    {43, 44, 51},
-    {51, 44, 52},
-    {44, 45, 52},
-    {52, 45, 53},
-    {45, 46, 53},
-    {53, 46, 54},
-    {46, 47, 54},
-    {54, 47, 55},
-    {47, 48, 55},
-    {55, 48, 56},
-    {48, 41, 56},
-    {56, 41, 49},
-    {2, 1, 57},
-    {3, 2, 57},
-    {4, 3, 57},
-    {5, 4, 57},
-    {6, 5, 57},
-    {7, 6, 57},
-    {8, 7, 57},
-    {1, 8, 57},
-    {49, 50, 58},
-    {50, 51, 58},
-    {51, 52, 58},
-    {52, 53, 58},
-    {53, 54, 58},
-    {54, 55, 58},
-    {55, 56, 58},
-    {56, 49, 58}
-  };
+  int f[112][3]
+      = {{1, 2, 9},    {9, 2, 10},   {2, 3, 10},   {10, 3, 11},  {3, 4, 11},
+         {11, 4, 12},  {4, 5, 12},   {12, 5, 13},  {5, 6, 13},   {13, 6, 14},
+         {6, 7, 14},   {14, 7, 15},  {7, 8, 15},   {15, 8, 16},  {8, 1, 16},
+         {16, 1, 9},   {9, 10, 17},  {17, 10, 18}, {10, 11, 18}, {18, 11, 19},
+         {11, 12, 19}, {19, 12, 20}, {12, 13, 20}, {20, 13, 21}, {13, 14, 21},
+         {21, 14, 22}, {14, 15, 22}, {22, 15, 23}, {15, 16, 23}, {23, 16, 24},
+         {16, 9, 24},  {24, 9, 17},  {17, 18, 25}, {25, 18, 26}, {18, 19, 26},
+         {26, 19, 27}, {19, 20, 27}, {27, 20, 28}, {20, 21, 28}, {28, 21, 29},
+         {21, 22, 29}, {29, 22, 30}, {22, 23, 30}, {30, 23, 31}, {23, 24, 31},
+         {31, 24, 32}, {24, 17, 32}, {32, 17, 25}, {25, 26, 33}, {33, 26, 34},
+         {26, 27, 34}, {34, 27, 35}, {27, 28, 35}, {35, 28, 36}, {28, 29, 36},
+         {36, 29, 37}, {29, 30, 37}, {37, 30, 38}, {30, 31, 38}, {38, 31, 39},
+         {31, 32, 39}, {39, 32, 40}, {32, 25, 40}, {40, 25, 33}, {33, 34, 41},
+         {41, 34, 42}, {34, 35, 42}, {42, 35, 43}, {35, 36, 43}, {43, 36, 44},
+         {36, 37, 44}, {44, 37, 45}, {37, 38, 45}, {45, 38, 46}, {38, 39, 46},
+         {46, 39, 47}, {39, 40, 47}, {47, 40, 48}, {40, 33, 48}, {48, 33, 41},
+         {41, 42, 49}, {49, 42, 50}, {42, 43, 50}, {50, 43, 51}, {43, 44, 51},
+         {51, 44, 52}, {44, 45, 52}, {52, 45, 53}, {45, 46, 53}, {53, 46, 54},
+         {46, 47, 54}, {54, 47, 55}, {47, 48, 55}, {55, 48, 56}, {48, 41, 56},
+         {56, 41, 49}, {2, 1, 57},   {3, 2, 57},   {4, 3, 57},   {5, 4, 57},
+         {6, 5, 57},   {7, 6, 57},   {8, 7, 57},   {1, 8, 57},   {49, 50, 58},
+         {50, 51, 58}, {51, 52, 58}, {52, 53, 58}, {53, 54, 58}, {54, 55, 58},
+         {55, 56, 58}, {56, 49, 58}};
 
   auto triMesh = new btTriangleMesh();
 
@@ -1040,7 +958,7 @@ std::unique_ptr<btCollisionShape> createBulletEllipsoidMesh(
   auto gimpactMeshShape = std::make_unique<btGImpactMeshShape>(triMesh);
   gimpactMeshShape->updateBound();
 
-  return std::move(gimpactMeshShape);
+  return gimpactMeshShape;
 }
 
 //==============================================================================
@@ -1056,11 +974,11 @@ std::unique_ptr<btCollisionShape> createBulletCollisionShapeFromAssimpScene(
       btVector3 vertices[3];
       for (auto k = 0u; k < 3; ++k)
       {
-        const aiVector3D& vertex = scene->mMeshes[i]->mVertices[
-                                   scene->mMeshes[i]->mFaces[j].mIndices[k]];
-        vertices[k] = btVector3(vertex.x * scale[0],
-                                vertex.y * scale[1],
-                                vertex.z * scale[2]);
+        const aiVector3D& vertex
+            = scene->mMeshes[i]
+                  ->mVertices[scene->mMeshes[i]->mFaces[j].mIndices[k]];
+        vertices[k] = btVector3(
+            vertex.x * scale[0], vertex.y * scale[1], vertex.z * scale[2]);
       }
       triMesh->addTriangle(vertices[0], vertices[1], vertices[2]);
     }
@@ -1070,7 +988,7 @@ std::unique_ptr<btCollisionShape> createBulletCollisionShapeFromAssimpScene(
   gimpactMeshShape->updateBound();
   gimpactMeshShape->setUserPointer(triMesh);
 
-  return std::move(gimpactMeshShape);
+  return gimpactMeshShape;
 }
 
 //==============================================================================
@@ -1093,13 +1011,12 @@ std::unique_ptr<btCollisionShape> createBulletCollisionShapeFromAssimpMesh(
   auto gimpactMeshShape = std::make_unique<btGImpactMeshShape>(triMesh);
   gimpactMeshShape->updateBound();
 
-  return std::move(gimpactMeshShape);
+  return gimpactMeshShape;
 }
 
 //==============================================================================
 template <typename HeightmapShapeT>
-std::unique_ptr<BulletCollisionShape>
-createBulletCollisionShapeFromHeightmap(
+std::unique_ptr<BulletCollisionShape> createBulletCollisionShapeFromHeightmap(
     const HeightmapShapeT* heightMap)
 {
   // get the heightmap parameters
@@ -1126,22 +1043,23 @@ createBulletCollisionShapeFromHeightmap(
   const btVector3 localScaling(scale.x(), scale.y(), scale.z());
   const bool flipQuadEdges = false;
   auto heightFieldShape = std::make_unique<btHeightfieldTerrainShape>(
-      heightMap->getWidth(),   // Width of height field
-      heightMap->getDepth(),   // Depth of height field
-      heights.data(),          // Height values
-      1,                       // Height scaling
-      minHeight,               // Min height
-      maxHeight,               // Max height
-      2,                       // Up axis
-      scalarType,              // Float or double field
-      flipQuadEdges);          // Flip quad edges
+      heightMap->getWidth(), // Width of height field
+      heightMap->getDepth(), // Depth of height field
+      heights.data(),        // Height values
+      1,                     // Height scaling
+      minHeight,             // Min height
+      maxHeight,             // Max height
+      2,                     // Up axis
+      scalarType,            // Float or double field
+      flipQuadEdges);        // Flip quad edges
   heightFieldShape->setLocalScaling(localScaling);
   heightFieldShape->setUseZigzagSubdivision(true);
 
   // change the relative transform of the height field so that the minimum
   // height is at the same z coordinate. Bullet shifts the height map such
   // that its center is the AABB center.
-  const btVector3 trans(0, 0, ((maxHeight - minHeight)*0.5 + minHeight)*scale.z());
+  const btVector3 trans(
+      0, 0, ((maxHeight - minHeight) * 0.5 + minHeight) * scale.z());
   btTransform relativeShapeTransform(btMatrix3x3::getIdentity(), trans);
 
   // bullet places the heightfield such that the origin is in the
@@ -1150,9 +1068,9 @@ createBulletCollisionShapeFromHeightmap(
   btVector3 min;
   btVector3 max;
   heightFieldShape->getAabb(btTransform::getIdentity(), min, max);
-  dtdbg << "DART Bullet heightfield AABB: min = {"
-        << min.x() << ", " << min.y() << ", " << min.z() << "}, max = {"
-        << max.x() << ", " << max.y() << ", " << max.z() << "}"
+  dtdbg << "DART Bullet heightfield AABB: min = {" << min.x() << ", " << min.y()
+        << ", " << min.z() << "}, max = {" << max.x() << ", " << max.y() << ", "
+        << max.z() << "}"
         << " (will be translated by z=" << trans.z() << ")" << std::endl;
 
   return std::make_unique<BulletCollisionShape>(
