@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011-2019, The DART development contributors
+ * Copyright (c) 2011-2021, The DART development contributors
  * All rights reserved.
  *
  * The list of contributors can be found at:
@@ -48,7 +48,7 @@ MakeCloneable<Base, Mixin>::MakeCloneable()
 
 //==============================================================================
 template <class Base, class Mixin>
-template <typename ... Args>
+template <typename... Args>
 MakeCloneable<Base, Mixin>::MakeCloneable(Args&&... args)
   : Mixin(std::forward<Args>(args)...)
 {
@@ -57,8 +57,7 @@ MakeCloneable<Base, Mixin>::MakeCloneable(Args&&... args)
 
 //==============================================================================
 template <class Base, class Mixin>
-MakeCloneable<Base, Mixin>::MakeCloneable(const Mixin& mixin)
-  : Mixin(mixin)
+MakeCloneable<Base, Mixin>::MakeCloneable(const Mixin& mixin) : Mixin(mixin)
 {
   // Do nothing
 }
@@ -137,20 +136,25 @@ void MakeCloneable<Base, Mixin>::copy(const Base& other)
 }
 
 //==============================================================================
-template <class Base, class OwnerT, class DataT,
-          void (*setData)(OwnerT*, const DataT&),
-          DataT (*getData)(const OwnerT*)>
+template <
+    class Base,
+    class OwnerT,
+    class DataT,
+    void (*setData)(OwnerT*, const DataT&),
+    DataT (*getData)(const OwnerT*)>
 ProxyCloneable<Base, OwnerT, DataT, setData, getData>::ProxyCloneable()
-  : mOwner(nullptr),
-    mData(std::make_unique<Data>())
+  : mOwner(nullptr), mData(std::make_unique<Data>())
 {
   // Do nothing
 }
 
 //==============================================================================
-template <class Base, class OwnerT, class DataT,
-          void (*setData)(OwnerT*, const DataT&),
-          DataT (*getData)(const OwnerT*)>
+template <
+    class Base,
+    class OwnerT,
+    class DataT,
+    void (*setData)(OwnerT*, const DataT&),
+    DataT (*getData)(const OwnerT*)>
 ProxyCloneable<Base, OwnerT, DataT, setData, getData>::ProxyCloneable(
     OwnerT* owner)
   : mOwner(owner)
@@ -159,9 +163,12 @@ ProxyCloneable<Base, OwnerT, DataT, setData, getData>::ProxyCloneable(
 }
 
 //==============================================================================
-template <class Base, class OwnerT, class DataT,
-          void (*setData)(OwnerT*, const DataT&),
-          DataT (*getData)(const OwnerT*)>
+template <
+    class Base,
+    class OwnerT,
+    class DataT,
+    void (*setData)(OwnerT*, const DataT&),
+    DataT (*getData)(const OwnerT*)>
 template <typename... Args>
 ProxyCloneable<Base, OwnerT, DataT, setData, getData>::ProxyCloneable(
     OwnerT* owner, Args&&... args)
@@ -171,34 +178,41 @@ ProxyCloneable<Base, OwnerT, DataT, setData, getData>::ProxyCloneable(
 }
 
 //==============================================================================
-template <class Base, class OwnerT, class DataT,
-          void (*setData)(OwnerT*, const DataT&),
-          DataT (*getData)(const OwnerT*)>
+template <
+    class Base,
+    class OwnerT,
+    class DataT,
+    void (*setData)(OwnerT*, const DataT&),
+    DataT (*getData)(const OwnerT*)>
 template <typename... Args>
 ProxyCloneable<Base, OwnerT, DataT, setData, getData>::ProxyCloneable(
     Args&&... args)
-  : mOwner(nullptr),
-    mData(std::make_unique<Data>(std::forward<Args>(args)...))
+  : mOwner(nullptr), mData(std::make_unique<Data>(std::forward<Args>(args)...))
 {
   // Do nothing
 }
 
 //==============================================================================
-template <class Base, class OwnerT, class DataT,
-          void (*setData)(OwnerT*, const DataT&),
-          DataT (*getData)(const OwnerT*)>
+template <
+    class Base,
+    class OwnerT,
+    class DataT,
+    void (*setData)(OwnerT*, const DataT&),
+    DataT (*getData)(const OwnerT*)>
 ProxyCloneable<Base, OwnerT, DataT, setData, getData>::ProxyCloneable(
     const ProxyCloneable& other)
-  : mOwner(nullptr),
-    mData(nullptr)
+  : mOwner(nullptr), mData(nullptr)
 {
   set(other);
 }
 
 //==============================================================================
-template <class Base, class OwnerT, class DataT,
-          void (*setData)(OwnerT*, const DataT&),
-          DataT (*getData)(const OwnerT*)>
+template <
+    class Base,
+    class OwnerT,
+    class DataT,
+    void (*setData)(OwnerT*, const DataT&),
+    DataT (*getData)(const OwnerT*)>
 ProxyCloneable<Base, OwnerT, DataT, setData, getData>::ProxyCloneable(
     ProxyCloneable&& other)
   : mOwner(nullptr)
@@ -207,10 +221,13 @@ ProxyCloneable<Base, OwnerT, DataT, setData, getData>::ProxyCloneable(
 }
 
 //==============================================================================
-template <class Base, class OwnerT, class DataT,
-          void (*setData)(OwnerT*, const DataT&),
-          DataT (*getData)(const OwnerT*)>
-auto ProxyCloneable<Base, OwnerT, DataT, setData, getData>::operator =(
+template <
+    class Base,
+    class OwnerT,
+    class DataT,
+    void (*setData)(OwnerT*, const DataT&),
+    DataT (*getData)(const OwnerT*)>
+auto ProxyCloneable<Base, OwnerT, DataT, setData, getData>::operator=(
     const Data& data) -> ProxyCloneable&
 {
   set(data);
@@ -218,10 +235,13 @@ auto ProxyCloneable<Base, OwnerT, DataT, setData, getData>::operator =(
 }
 
 //==============================================================================
-template <class Base, class OwnerT, class DataT,
-          void (*setData)(OwnerT*, const DataT&),
-          DataT (*getData)(const OwnerT*)>
-auto ProxyCloneable<Base, OwnerT, DataT, setData, getData>::operator =(
+template <
+    class Base,
+    class OwnerT,
+    class DataT,
+    void (*setData)(OwnerT*, const DataT&),
+    DataT (*getData)(const OwnerT*)>
+auto ProxyCloneable<Base, OwnerT, DataT, setData, getData>::operator=(
     Data&& data) -> ProxyCloneable&
 {
   set(data);
@@ -229,10 +249,13 @@ auto ProxyCloneable<Base, OwnerT, DataT, setData, getData>::operator =(
 }
 
 //==============================================================================
-template <class Base, class OwnerT, class DataT,
-          void (*setData)(OwnerT*, const DataT&),
-          DataT (*getData)(const OwnerT*)>
-auto ProxyCloneable<Base, OwnerT, DataT, setData, getData>::operator =(
+template <
+    class Base,
+    class OwnerT,
+    class DataT,
+    void (*setData)(OwnerT*, const DataT&),
+    DataT (*getData)(const OwnerT*)>
+auto ProxyCloneable<Base, OwnerT, DataT, setData, getData>::operator=(
     const ProxyCloneable& other) -> ProxyCloneable&
 {
   mOwner = other.mOwner;
@@ -241,10 +264,13 @@ auto ProxyCloneable<Base, OwnerT, DataT, setData, getData>::operator =(
 }
 
 //==============================================================================
-template <class Base, class OwnerT, class DataT,
-          void (*setData)(OwnerT*, const DataT&),
-          DataT (*getData)(const OwnerT*)>
-auto ProxyCloneable<Base, OwnerT, DataT, setData, getData>::operator =(
+template <
+    class Base,
+    class OwnerT,
+    class DataT,
+    void (*setData)(OwnerT*, const DataT&),
+    DataT (*getData)(const OwnerT*)>
+auto ProxyCloneable<Base, OwnerT, DataT, setData, getData>::operator=(
     ProxyCloneable&& other) -> ProxyCloneable&
 {
   mOwner = other.mOwner;
@@ -253,13 +279,16 @@ auto ProxyCloneable<Base, OwnerT, DataT, setData, getData>::operator =(
 }
 
 //==============================================================================
-template <class Base, class OwnerT, class DataT,
-          void (*setData)(OwnerT*, const DataT&),
-          DataT (*getData)(const OwnerT*)>
+template <
+    class Base,
+    class OwnerT,
+    class DataT,
+    void (*setData)(OwnerT*, const DataT&),
+    DataT (*getData)(const OwnerT*)>
 void ProxyCloneable<Base, OwnerT, DataT, setData, getData>::set(
     const Data& data)
 {
-  if(mOwner)
+  if (mOwner)
   {
     (*setData)(mOwner, data);
     return;
@@ -269,13 +298,15 @@ void ProxyCloneable<Base, OwnerT, DataT, setData, getData>::set(
 }
 
 //==============================================================================
-template <class Base, class OwnerT, class DataT,
-          void (*setData)(OwnerT*, const DataT&),
-          DataT (*getData)(const OwnerT*)>
-void ProxyCloneable<Base, OwnerT, DataT, setData, getData>::set(
-    Data&& data)
+template <
+    class Base,
+    class OwnerT,
+    class DataT,
+    void (*setData)(OwnerT*, const DataT&),
+    DataT (*getData)(const OwnerT*)>
+void ProxyCloneable<Base, OwnerT, DataT, setData, getData>::set(Data&& data)
 {
-  if(mOwner)
+  if (mOwner)
   {
     (*setData)(mOwner, data);
     return;
@@ -285,9 +316,12 @@ void ProxyCloneable<Base, OwnerT, DataT, setData, getData>::set(
 }
 
 //==============================================================================
-template <class Base, class OwnerT, class DataT,
-          void (*setData)(OwnerT*, const DataT&),
-          DataT (*getData)(const OwnerT*)>
+template <
+    class Base,
+    class OwnerT,
+    class DataT,
+    void (*setData)(OwnerT*, const DataT&),
+    DataT (*getData)(const OwnerT*)>
 void ProxyCloneable<Base, OwnerT, DataT, setData, getData>::set(
     const ProxyCloneable& other)
 {
@@ -295,9 +329,12 @@ void ProxyCloneable<Base, OwnerT, DataT, setData, getData>::set(
 }
 
 //==============================================================================
-template <class Base, class OwnerT, class DataT,
-          void (*setData)(OwnerT*, const DataT&),
-          DataT (*getData)(const OwnerT*)>
+template <
+    class Base,
+    class OwnerT,
+    class DataT,
+    void (*setData)(OwnerT*, const DataT&),
+    DataT (*getData)(const OwnerT*)>
 void ProxyCloneable<Base, OwnerT, DataT, setData, getData>::set(
     ProxyCloneable&& other)
 {
@@ -305,49 +342,65 @@ void ProxyCloneable<Base, OwnerT, DataT, setData, getData>::set(
 }
 
 //==============================================================================
-template <class Base, class OwnerT, class DataT,
-          void (*setData)(OwnerT*, const DataT&),
-          DataT (*getData)(const OwnerT*)>
+template <
+    class Base,
+    class OwnerT,
+    class DataT,
+    void (*setData)(OwnerT*, const DataT&),
+    DataT (*getData)(const OwnerT*)>
 auto ProxyCloneable<Base, OwnerT, DataT, setData, getData>::get() const -> Data
 {
-  if(mOwner)
+  if (mOwner)
     return (*getData)(mOwner);
 
   return *mData;
 }
 
 //==============================================================================
-template <class Base, class OwnerT, class DataT,
-          void (*setData)(OwnerT*, const DataT&),
-          DataT (*getData)(const OwnerT*)>
+template <
+    class Base,
+    class OwnerT,
+    class DataT,
+    void (*setData)(OwnerT*, const DataT&),
+    DataT (*getData)(const OwnerT*)>
 OwnerT* ProxyCloneable<Base, OwnerT, DataT, setData, getData>::getOwner()
 {
   return mOwner;
 }
 
 //==============================================================================
-template <class Base, class OwnerT, class DataT,
-          void (*setData)(OwnerT*, const DataT&),
-          DataT (*getData)(const OwnerT*)>
-const OwnerT* ProxyCloneable<Base, OwnerT, DataT, setData, getData>::getOwner() const
+template <
+    class Base,
+    class OwnerT,
+    class DataT,
+    void (*setData)(OwnerT*, const DataT&),
+    DataT (*getData)(const OwnerT*)>
+const OwnerT* ProxyCloneable<Base, OwnerT, DataT, setData, getData>::getOwner()
+    const
 {
   return mOwner;
 }
 
 //==============================================================================
-template <class Base, class OwnerT, class DataT,
-          void (*setData)(OwnerT*, const DataT&),
-          DataT (*getData)(const OwnerT*)>
-std::unique_ptr<Base> ProxyCloneable<
-    Base, OwnerT, DataT, setData, getData>::clone() const
+template <
+    class Base,
+    class OwnerT,
+    class DataT,
+    void (*setData)(OwnerT*, const DataT&),
+    DataT (*getData)(const OwnerT*)>
+std::unique_ptr<Base>
+ProxyCloneable<Base, OwnerT, DataT, setData, getData>::clone() const
 {
   return std::make_unique<ProxyCloneable>(get());
 }
 
 //==============================================================================
-template <class Base, class OwnerT, class DataT,
-          void (*setData)(OwnerT*, const DataT&),
-          DataT (*getData)(const OwnerT*)>
+template <
+    class Base,
+    class OwnerT,
+    class DataT,
+    void (*setData)(OwnerT*, const DataT&),
+    DataT (*getData)(const OwnerT*)>
 void ProxyCloneable<Base, OwnerT, DataT, setData, getData>::copy(
     const Base& other)
 {
@@ -356,16 +409,14 @@ void ProxyCloneable<Base, OwnerT, DataT, setData, getData>::copy(
 
 //==============================================================================
 template <typename MapType>
-CloneableMap<MapType>::CloneableMap(
-    const CloneableMap& otherHolder)
+CloneableMap<MapType>::CloneableMap(const CloneableMap& otherHolder)
 {
   copy(otherHolder);
 }
 
 //==============================================================================
 template <typename MapType>
-CloneableMap<MapType>::CloneableMap(
-    CloneableMap&& otherHolder)
+CloneableMap<MapType>::CloneableMap(CloneableMap&& otherHolder)
 {
   *this = std::move(otherHolder);
 }
@@ -405,8 +456,7 @@ CloneableMap<MapType>& CloneableMap<MapType>::operator=(
 
 //==============================================================================
 template <typename MapType>
-CloneableMap<MapType>& CloneableMap<MapType>::operator=(
-    const MapType& otherMap)
+CloneableMap<MapType>& CloneableMap<MapType>::operator=(const MapType& otherMap)
 {
   copy(otherMap);
   return *this;
@@ -414,8 +464,7 @@ CloneableMap<MapType>& CloneableMap<MapType>::operator=(
 
 //==============================================================================
 template <typename MapType>
-CloneableMap<MapType>& CloneableMap<MapType>::operator=(
-    MapType&& otherHolder)
+CloneableMap<MapType>& CloneableMap<MapType>::operator=(MapType&& otherHolder)
 {
   mMap = std::move(otherHolder);
 
@@ -436,28 +485,28 @@ void CloneableMap<MapType>::copy(const MapType& otherMap, bool merge)
   typename MapType::iterator receiver = mMap.begin();
   typename MapType::const_iterator sender = otherMap.begin();
 
-  while( otherMap.end() != sender )
+  while (otherMap.end() != sender)
   {
-    if( mMap.end() == receiver )
+    if (mMap.end() == receiver)
     {
       // If we've reached the end of this CloneableMapHolder's map, then we
       // should just add each entry
       mMap[sender->first] = sender->second->clone();
       ++sender;
     }
-    else if( receiver->first == sender->first )
+    else if (receiver->first == sender->first)
     {
-      if(sender->second)
+      if (sender->second)
       {
         // If the sender has an object, we should copy it.
-        if(receiver->second)
+        if (receiver->second)
           // We should copy instead of cloning the incoming object when possible
           // so we can avoid the memory allocation overhead of cloning.
           receiver->second->copy(*sender->second);
         else
           receiver->second = sender->second->clone();
       }
-      else if(!merge)
+      else if (!merge)
       {
         // If the sender has no object, we should clear this one.
         receiver->second = nullptr;
@@ -466,9 +515,9 @@ void CloneableMap<MapType>::copy(const MapType& otherMap, bool merge)
       ++receiver;
       ++sender;
     }
-    else if( receiver->first < sender->first )
+    else if (receiver->first < sender->first)
     {
-      if(!merge)
+      if (!merge)
       {
         // Clear this entry in the map, because it does not have an analog in
         // the map that we are copying
@@ -478,7 +527,7 @@ void CloneableMap<MapType>::copy(const MapType& otherMap, bool merge)
     }
     else
     {
-      if(sender->second)
+      if (sender->second)
       {
         // If receiver has a higher value, then the receiving map does not
         // contain an entry for this entry of the sending map, and therefore the
@@ -489,9 +538,9 @@ void CloneableMap<MapType>::copy(const MapType& otherMap, bool merge)
     }
   }
 
-  if(!merge)
+  if (!merge)
   {
-    while( mMap.end() != receiver )
+    while (mMap.end() != receiver)
     {
       mMap.erase(receiver++);
     }
@@ -550,7 +599,7 @@ CloneableVector<T>::CloneableVector(const CloneableVector& other)
 
 //==============================================================================
 template <typename T>
-CloneableVector<T>& CloneableVector<T>::operator =(const CloneableVector& other)
+CloneableVector<T>& CloneableVector<T>::operator=(const CloneableVector& other)
 {
   copy(other);
   return this;
@@ -558,15 +607,15 @@ CloneableVector<T>& CloneableVector<T>::operator =(const CloneableVector& other)
 
 //==============================================================================
 template <typename T>
-std::unique_ptr< CloneableVector<T> > CloneableVector<T>::clone() const
+std::unique_ptr<CloneableVector<T>> CloneableVector<T>::clone() const
 {
   std::vector<T> clonedVector;
   clonedVector.reserve(mVector.size());
 
-  for(const T& entry : mVector)
+  for (const T& entry : mVector)
     clonedVector.push_back(entry->clone());
 
-  return std::make_unique< CloneableVector<T> >( std::move(clonedVector) );
+  return std::make_unique<CloneableVector<T>>(std::move(clonedVector));
 }
 
 //==============================================================================
@@ -576,11 +625,11 @@ void CloneableVector<T>::copy(const CloneableVector<T>& anotherVector)
   const std::vector<T>& other = anotherVector.getVector();
   mVector.resize(other.size());
 
-  for(std::size_t i=0; i < other.size(); ++i)
+  for (std::size_t i = 0; i < other.size(); ++i)
   {
-    if(mVector[i] && other[i])
+    if (mVector[i] && other[i])
       mVector[i]->copy(*other[i]);
-    else if(other[i])
+    else if (other[i])
       mVector[i] = other[i]->clone();
     else
       mVector[i] = nullptr;
