@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011-2019, The DART development contributors
+ * Copyright (c) 2011-2021, The DART development contributors
  * All rights reserved.
  *
  * The list of contributors can be found at:
@@ -32,25 +32,26 @@
 
 #include "dart/constraint/ConstraintSolver.hpp"
 
-#include "dart/common/Console.hpp"
-#include "dart/collision/CollisionObject.hpp"
-#include "dart/collision/CollisionGroup.hpp"
+#include <algorithm>
+
 #include "dart/collision/CollisionFilter.hpp"
+#include "dart/collision/CollisionGroup.hpp"
+#include "dart/collision/CollisionObject.hpp"
 #include "dart/collision/Contact.hpp"
-#include "dart/collision/fcl/FCLCollisionDetector.hpp"
 #include "dart/collision/dart/DARTCollisionDetector.hpp"
-#include "dart/dynamics/BodyNode.hpp"
-#include "dart/dynamics/SoftBodyNode.hpp"
-#include "dart/dynamics/Joint.hpp"
-#include "dart/dynamics/Skeleton.hpp"
+#include "dart/collision/fcl/FCLCollisionDetector.hpp"
+#include "dart/common/Console.hpp"
 #include "dart/constraint/ConstrainedGroup.hpp"
 #include "dart/constraint/ContactConstraint.hpp"
-#include "dart/constraint/SoftContactConstraint.hpp"
-#include "dart/constraint/JointLimitConstraint.hpp"
-#include "dart/constraint/ServoMotorConstraint.hpp"
-#include "dart/constraint/MimicMotorConstraint.hpp"
+#include "dart/constraint/JointConstraint.hpp"
 #include "dart/constraint/JointCoulombFrictionConstraint.hpp"
 #include "dart/constraint/LCPSolver.hpp"
+#include "dart/constraint/MimicMotorConstraint.hpp"
+#include "dart/constraint/SoftContactConstraint.hpp"
+#include "dart/dynamics/BodyNode.hpp"
+#include "dart/dynamics/Joint.hpp"
+#include "dart/dynamics/Skeleton.hpp"
+#include "dart/dynamics/SoftBodyNode.hpp"
 
 namespace dart {
 namespace constraint {
@@ -61,15 +62,14 @@ using namespace dynamics;
 ConstraintSolver::ConstraintSolver(double timeStep)
   : mCollisionDetector(collision::FCLCollisionDetector::create()),
     mCollisionGroup(mCollisionDetector->createCollisionGroupAsSharedPtr()),
-    mCollisionOption(
-      collision::CollisionOption(
+    mCollisionOption(collision::CollisionOption(
         true, 1000u, std::make_shared<collision::BodyNodeCollisionFilter>())),
     mTimeStep(timeStep)
 {
   assert(timeStep > 0.0);
 
   auto cd = std::static_pointer_cast<collision::FCLCollisionDetector>(
-        mCollisionDetector);
+      mCollisionDetector);
 
   cd->setPrimitiveShapeType(collision::FCLCollisionDetector::MESH);
   // TODO(JS): Consider using FCL's primitive shapes once FCL addresses
@@ -81,13 +81,12 @@ ConstraintSolver::ConstraintSolver(double timeStep)
 ConstraintSolver::ConstraintSolver()
   : mCollisionDetector(collision::FCLCollisionDetector::create()),
     mCollisionGroup(mCollisionDetector->createCollisionGroupAsSharedPtr()),
-    mCollisionOption(
-      collision::CollisionOption(
+    mCollisionOption(collision::CollisionOption(
         true, 1000u, std::make_shared<collision::BodyNodeCollisionFilter>())),
     mTimeStep(0.001)
 {
   auto cd = std::static_pointer_cast<collision::FCLCollisionDetector>(
-        mCollisionDetector);
+      mCollisionDetector);
 
   cd->setPrimitiveShapeType(collision::FCLCollisionDetector::MESH);
   // TODO(JS): Consider using FCL's primitive shapes once FCL addresses
@@ -98,7 +97,8 @@ ConstraintSolver::ConstraintSolver()
 //==============================================================================
 void ConstraintSolver::addSkeleton(const SkeletonPtr& skeleton)
 {
-  assert(skeleton
+  assert(
+      skeleton
       && "Null pointer skeleton is now allowed to add to ConstraintSover.");
 
   if (containSkeleton(skeleton))
@@ -131,7 +131,8 @@ const std::vector<SkeletonPtr>& ConstraintSolver::getSkeletons() const
 //==============================================================================
 void ConstraintSolver::removeSkeleton(const SkeletonPtr& skeleton)
 {
-  assert(skeleton
+  assert(
+      skeleton
       && "Null pointer skeleton is now allowed to add to ConstraintSover.");
 
   if (!containSkeleton(skeleton))
@@ -142,8 +143,8 @@ void ConstraintSolver::removeSkeleton(const SkeletonPtr& skeleton)
   }
 
   mCollisionGroup->removeShapeFramesOf(skeleton.get());
-  mSkeletons.erase(remove(mSkeletons.begin(), mSkeletons.end(), skeleton),
-                   mSkeletons.end());
+  mSkeletons.erase(
+      remove(mSkeletons.begin(), mSkeletons.end(), skeleton), mSkeletons.end());
   mConstrainedGroups.reserve(mSkeletons.size());
 }
 
@@ -189,9 +190,9 @@ void ConstraintSolver::removeConstraint(const ConstraintBasePtr& constraint)
     return;
   }
 
-  mManualConstraints.erase(remove(mManualConstraints.begin(),
-                                  mManualConstraints.end(), constraint),
-                           mManualConstraints.end());
+  mManualConstraints.erase(
+      remove(mManualConstraints.begin(), mManualConstraints.end(), constraint),
+      mManualConstraints.end());
 }
 
 //==============================================================================
@@ -262,12 +263,12 @@ void ConstraintSolver::setCollisionDetector(
     collision::CollisionDetector* collisionDetector)
 {
   setCollisionDetector(
-    std::unique_ptr<collision::CollisionDetector>(collisionDetector));
+      std::unique_ptr<collision::CollisionDetector>(collisionDetector));
 }
 
 //==============================================================================
 void ConstraintSolver::setCollisionDetector(
-  const std::shared_ptr<collision::CollisionDetector>& collisionDetector)
+    const std::shared_ptr<collision::CollisionDetector>& collisionDetector)
 {
   if (!collisionDetector)
   {
@@ -295,8 +296,8 @@ collision::CollisionDetectorPtr ConstraintSolver::getCollisionDetector()
 }
 
 //==============================================================================
-collision::ConstCollisionDetectorPtr
-ConstraintSolver::getCollisionDetector() const
+collision::ConstCollisionDetectorPtr ConstraintSolver::getCollisionDetector()
+    const
 {
   return mCollisionDetector;
 }
@@ -332,8 +333,8 @@ collision::CollisionResult& ConstraintSolver::getLastCollisionResult()
 }
 
 //==============================================================================
-const collision::CollisionResult&
-ConstraintSolver::getLastCollisionResult() const
+const collision::CollisionResult& ConstraintSolver::getLastCollisionResult()
+    const
 {
   return mCollisionResult;
 }
@@ -364,9 +365,9 @@ void ConstraintSolver::solve()
   for (auto& skeleton : mSkeletons)
   {
     skeleton->clearConstraintImpulses();
-DART_SUPPRESS_DEPRECATED_BEGIN
+    DART_SUPPRESS_DEPRECATED_BEGIN
     skeleton->clearCollidingBodies();
-DART_SUPPRESS_DEPRECATED_END
+    DART_SUPPRESS_DEPRECATED_END
   }
 
   // Update constraints and collect active constraints
@@ -393,10 +394,12 @@ void ConstraintSolver::setFromOtherConstraintSolver(
 //==============================================================================
 bool ConstraintSolver::containSkeleton(const ConstSkeletonPtr& _skeleton) const
 {
-  assert(_skeleton != nullptr && "Not allowed to insert null pointer skeleton.");
+  assert(
+      _skeleton != nullptr && "Not allowed to insert null pointer skeleton.");
 
   for (std::vector<SkeletonPtr>::const_iterator it = mSkeletons.begin();
-       it != mSkeletons.end(); ++it)
+       it != mSkeletons.end();
+       ++it)
   {
     if ((*it) == _skeleton)
       return true;
@@ -422,15 +425,17 @@ bool ConstraintSolver::checkAndAddSkeleton(const SkeletonPtr& skeleton)
 }
 
 //==============================================================================
-bool ConstraintSolver::containConstraint(const ConstConstraintBasePtr& constraint) const
+bool ConstraintSolver::containConstraint(
+    const ConstConstraintBasePtr& constraint) const
 {
-  return std::find(mManualConstraints.begin(),
-                   mManualConstraints.end(),
-                   constraint) != mManualConstraints.end();
+  return std::find(
+             mManualConstraints.begin(), mManualConstraints.end(), constraint)
+         != mManualConstraints.end();
 }
 
 //==============================================================================
-bool ConstraintSolver::checkAndAddConstraint(const ConstraintBasePtr& constraint)
+bool ConstraintSolver::checkAndAddConstraint(
+    const ConstraintBasePtr& constraint)
 {
   if (!containConstraint(constraint))
   {
@@ -474,6 +479,29 @@ void ConstraintSolver::updateConstraints()
   // Destroy previous soft contact constraints
   mSoftContactConstraints.clear();
 
+  // Create a mapping of contact pairs to the number of contacts between them
+  using ContactPair
+      = std::pair<collision::CollisionObject*, collision::CollisionObject*>;
+
+  // Compare contact pairs while ignoring their order in the pair.
+  struct ContactPairCompare
+  {
+    ContactPair getSortedPair(const ContactPair& a) const
+    {
+      if (a.first < a.second)
+        return std::make_pair(a.second, a.first);
+      return a;
+    }
+
+    bool operator()(const ContactPair& a, const ContactPair& b) const
+    {
+      // Sort each pair and then do a lexicographical comparison
+      return getSortedPair(a) < getSortedPair(b);
+    }
+  };
+
+  std::map<ContactPair, size_t, ContactPairCompare> contactPairMap;
+
   // Create new contact constraints
   for (auto i = 0u; i < mCollisionResult.getNumContacts(); ++i)
   {
@@ -488,14 +516,14 @@ void ConstraintSolver::updateConstraints()
 
     // Set colliding bodies
     auto shapeFrame1 = const_cast<dynamics::ShapeFrame*>(
-          contact.collisionObject1->getShapeFrame());
+        contact.collisionObject1->getShapeFrame());
     auto shapeFrame2 = const_cast<dynamics::ShapeFrame*>(
-          contact.collisionObject2->getShapeFrame());
+        contact.collisionObject2->getShapeFrame());
 
-DART_SUPPRESS_DEPRECATED_BEGIN
+    DART_SUPPRESS_DEPRECATED_BEGIN
     shapeFrame1->asShapeNode()->getBodyNodePtr()->setColliding(true);
     shapeFrame2->asShapeNode()->getBodyNodePtr()->setColliding(true);
-DART_SUPPRESS_DEPRECATED_END
+    DART_SUPPRESS_DEPRECATED_END
 
     // If penetration depth is negative, then the collision isn't really
     // happening and the contact point should be ignored.
@@ -507,18 +535,39 @@ DART_SUPPRESS_DEPRECATED_END
     if (isSoftContact(contact))
     {
       mSoftContactConstraints.push_back(
-            std::make_shared<SoftContactConstraint>(contact, mTimeStep));
+          std::make_shared<SoftContactConstraint>(contact, mTimeStep));
     }
     else
     {
+      // Increment the count of contacts between the two collision objects
+      ++contactPairMap[std::make_pair(
+          contact.collisionObject1, contact.collisionObject2)];
+
       mContactConstraints.push_back(
-            std::make_shared<ContactConstraint>(contact, mTimeStep));
+          std::make_shared<ContactConstraint>(contact, mTimeStep));
     }
   }
 
   // Add the new contact constraints to dynamic constraint list
   for (const auto& contactConstraint : mContactConstraints)
   {
+    // update the slip compliances of the contact constraints based on the
+    // number of contacts between the collision objects.
+    auto& contact = contactConstraint->getContact();
+    std::size_t numContacts = 1;
+    auto it = contactPairMap.find(
+        std::make_pair(contact.collisionObject1, contact.collisionObject2));
+    if (it != contactPairMap.end())
+      numContacts = it->second;
+
+    // The slip compliance acts like a damper at each contact point so the total
+    // damping for each collision is multiplied by the number of contact points
+    // (numContacts). To eliminate this dependence on numContacts, the inverse
+    // damping is multiplied by numContacts.
+    contactConstraint->setPrimarySlipCompliance(
+        contactConstraint->getPrimarySlipCompliance() * numContacts);
+    contactConstraint->setSecondarySlipCompliance(
+        contactConstraint->getSecondarySlipCompliance() * numContacts);
     contactConstraint->update();
 
     if (contactConstraint->isActive())
@@ -538,8 +587,7 @@ DART_SUPPRESS_DEPRECATED_END
   // Update automatic constraints: joint constraints
   //----------------------------------------------------------------------------
   // Destroy previous joint constraints
-  mJointLimitConstraints.clear();
-  mServoMotorConstraints.clear();
+  mJointConstraints.clear();
   mMimicMotorConstraints.clear();
   mJointCoulombFrictionConstraints.clear();
 
@@ -560,33 +608,31 @@ DART_SUPPRESS_DEPRECATED_END
         if (joint->getCoulombFriction(j) != 0.0)
         {
           mJointCoulombFrictionConstraints.push_back(
-                std::make_shared<JointCoulombFrictionConstraint>(joint));
+              std::make_shared<JointCoulombFrictionConstraint>(joint));
           break;
         }
       }
 
-      if (joint->isPositionLimitEnforced())
+      if (joint->areLimitsEnforced()
+          || joint->getActuatorType() == dynamics::Joint::SERVO)
       {
-        mJointLimitConstraints.push_back(
-              std::make_shared<JointLimitConstraint>(joint));
+        mJointConstraints.push_back(std::make_shared<JointConstraint>(joint));
       }
 
-      if (joint->getActuatorType() == dynamics::Joint::SERVO)
+      if (joint->getActuatorType() == dynamics::Joint::MIMIC
+          && joint->getMimicJoint())
       {
-        mServoMotorConstraints.push_back(
-              std::make_shared<ServoMotorConstraint>(joint));
-      }
-
-      if (joint->getActuatorType() == dynamics::Joint::MIMIC && joint->getMimicJoint())
-      {
-        mMimicMotorConstraints.push_back(
-              std::make_shared<MimicMotorConstraint>(joint, joint->getMimicJoint(), joint->getMimicMultiplier(), joint->getMimicOffset()));
+        mMimicMotorConstraints.push_back(std::make_shared<MimicMotorConstraint>(
+            joint,
+            joint->getMimicJoint(),
+            joint->getMimicMultiplier(),
+            joint->getMimicOffset()));
       }
     }
   }
 
   // Add active joint limit
-  for (auto& jointLimitConstraint : mJointLimitConstraints)
+  for (auto& jointLimitConstraint : mJointConstraints)
   {
     jointLimitConstraint->update();
 
@@ -594,14 +640,6 @@ DART_SUPPRESS_DEPRECATED_END
       mActiveConstraints.push_back(jointLimitConstraint);
   }
 
-  for (auto& servoMotorConstraint : mServoMotorConstraints)
-  {
-    servoMotorConstraint->update();
-
-    if (servoMotorConstraint->isActive())
-      mActiveConstraints.push_back(servoMotorConstraint);
-  }
-
   for (auto& mimicMotorConstraint : mMimicMotorConstraints)
   {
     mimicMotorConstraint->update();
@@ -693,14 +731,14 @@ bool ConstraintSolver::isSoftContact(const collision::Contact& contact) const
   auto* bodyNode1 = shapeNode1->getBodyNodePtr().get();
   auto* bodyNode2 = shapeNode2->getBodyNodePtr().get();
 
-  auto bodyNode1IsSoft =
-      dynamic_cast<const dynamics::SoftBodyNode*>(bodyNode1) != nullptr;
+  auto bodyNode1IsSoft
+      = dynamic_cast<const dynamics::SoftBodyNode*>(bodyNode1) != nullptr;
 
-  auto bodyNode2IsSoft =
-      dynamic_cast<const dynamics::SoftBodyNode*>(bodyNode2) != nullptr;
+  auto bodyNode2IsSoft
+      = dynamic_cast<const dynamics::SoftBodyNode*>(bodyNode2) != nullptr;
 
   return bodyNode1IsSoft || bodyNode2IsSoft;
 }
 
-}  // namespace constraint
-}  // namespace dart
+} // namespace constraint
+} // namespace dart
