@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011-2019, The DART development contributors
+ * Copyright (c) 2011-2021, The DART development contributors
  * All rights reserved.
  *
  * The list of contributors can be found at:
@@ -34,45 +34,55 @@
 
 #include <iostream>
 
-#include "dart/external/odelcpsolver/lcp.h"
-
+#include "dart/collision/CollisionObject.hpp"
 #include "dart/common/Console.hpp"
 #include "dart/dynamics/BodyNode.hpp"
 #include "dart/dynamics/PointMass.hpp"
-#include "dart/dynamics/SoftBodyNode.hpp"
-#include "dart/dynamics/Skeleton.hpp"
 #include "dart/dynamics/Shape.hpp"
+#include "dart/dynamics/Skeleton.hpp"
+#include "dart/dynamics/SoftBodyNode.hpp"
 #include "dart/dynamics/SoftMeshShape.hpp"
-#include "dart/collision/CollisionObject.hpp"
+#include "dart/external/odelcpsolver/lcp.h"
 
 #define DART_EPSILON 1e-6
 #define DART_ERROR_ALLOWANCE 0.0
-#define DART_ERP     0.01
+#define DART_ERP 0.01
 #define DART_MAX_ERV 1e+1
-#define DART_CFM     1e-5
+#define DART_CFM 1e-5
 // #define DART_MAX_NUMBER_OF_CONTACTS 32
 
 #define DART_RESTITUTION_COEFF_THRESHOLD 1e-3
-#define DART_FRICTION_COEFF_THRESHOLD    1e-3
+#define DART_FRICTION_COEFF_THRESHOLD 1e-3
 #define DART_BOUNCING_VELOCITY_THRESHOLD 1e-1
-#define DART_MAX_BOUNCING_VELOCITY       1e+2
-#define DART_CONTACT_CONSTRAINT_EPSILON  1e-6
+#define DART_MAX_BOUNCING_VELOCITY 1e+2
+#define DART_CONTACT_CONSTRAINT_EPSILON 1e-6
 
 namespace dart {
 namespace constraint {
 
-double SoftContactConstraint::mErrorAllowance            = DART_ERROR_ALLOWANCE;
-double SoftContactConstraint::mErrorReductionParameter   = DART_ERP;
+double SoftContactConstraint::mErrorAllowance = DART_ERROR_ALLOWANCE;
+double SoftContactConstraint::mErrorReductionParameter = DART_ERP;
 double SoftContactConstraint::mMaxErrorReductionVelocity = DART_MAX_ERV;
-double SoftContactConstraint::mConstraintForceMixing     = DART_CFM;
+double SoftContactConstraint::mConstraintForceMixing = DART_CFM;
+
+constexpr double DART_DEFAULT_FRICTION_COEFF = 1.0;
+constexpr double DART_DEFAULT_RESTITUTION_COEFF = 0.0;
 
 //==============================================================================
 SoftContactConstraint::SoftContactConstraint(
     collision::Contact& contact, double timeStep)
   : ConstraintBase(),
     mTimeStep(timeStep),
-    mBodyNode1(const_cast<dynamics::ShapeFrame*>(contact.collisionObject1->getShapeFrame())->asShapeNode()->getBodyNodePtr().get()),
-    mBodyNode2(const_cast<dynamics::ShapeFrame*>(contact.collisionObject2->getShapeFrame())->asShapeNode()->getBodyNodePtr().get()),
+    mBodyNode1(const_cast<dynamics::ShapeFrame*>(
+                   contact.collisionObject1->getShapeFrame())
+                   ->asShapeNode()
+                   ->getBodyNodePtr()
+                   .get()),
+    mBodyNode2(const_cast<dynamics::ShapeFrame*>(
+                   contact.collisionObject2->getShapeFrame())
+                   ->asShapeNode()
+                   ->getBodyNodePtr()
+                   .get()),
     mSoftBodyNode1(dynamic_cast<dynamics::SoftBodyNode*>(mBodyNode1)),
     mSoftBodyNode2(dynamic_cast<dynamics::SoftBodyNode*>(mBodyNode2)),
     mPointMass1(nullptr),
@@ -105,8 +115,8 @@ SoftContactConstraint::SoftContactConstraint(
     if (contact.collisionObject1->getShape()->getType()
         == dynamics::SoftMeshShape::getStaticType())
     {
-      mPointMass1 = selectCollidingPointMass(mSoftBodyNode1, contact.point,
-                                             contact.triID1);
+      mPointMass1 = selectCollidingPointMass(
+          mSoftBodyNode1, contact.point, contact.triID1);
       mPointMass1->setColliding(true);
     }
   }
@@ -115,17 +125,25 @@ SoftContactConstraint::SoftContactConstraint(
     if (contact.collisionObject2->getShape()->getType()
         == dynamics::SoftMeshShape::getStaticType())
     {
-      mPointMass2 = selectCollidingPointMass(mSoftBodyNode2, contact.point,
-                                             contact.triID2);
+      mPointMass2 = selectCollidingPointMass(
+          mSoftBodyNode2, contact.point, contact.triID2);
       mPointMass2->setColliding(true);
     }
   }
 
+  const auto* shapeNodeA = const_cast<dynamics::ShapeFrame*>(
+                               contact.collisionObject1->getShapeFrame())
+                               ->asShapeNode();
+  const auto* shapeNodeB = const_cast<dynamics::ShapeFrame*>(
+                               contact.collisionObject2->getShapeFrame())
+                               ->asShapeNode();
+
   //----------------------------------------------------------------------------
   // Bounce
   //----------------------------------------------------------------------------
-  mRestitutionCoeff = mBodyNode1->getRestitutionCoeff()
-                      * mBodyNode2->getRestitutionCoeff();
+  const double restitutionCoeffA = computeRestitutionCoefficient(shapeNodeA);
+  const double restitutionCoeffB = computeRestitutionCoefficient(shapeNodeB);
+  mRestitutionCoeff = restitutionCoeffA * restitutionCoeffB;
   if (mRestitutionCoeff > DART_RESTITUTION_COEFF_THRESHOLD)
     mIsBounceOn = true;
   else
@@ -137,8 +155,12 @@ SoftContactConstraint::SoftContactConstraint(
   // TODO(JS): Assume the frictional coefficient can be changed during
   //           simulation steps.
   // Update mFrictionalCoff
-  mFrictionCoeff = std::min(mBodyNode1->getFrictionCoeff(),
-                            mBodyNode2->getFrictionCoeff());
+  const double frictionCoeffA = computeFrictionCoefficient(shapeNodeA);
+  const double frictionCoeffB = computeFrictionCoefficient(shapeNodeB);
+
+  // TODO(JS): Consider providing various ways of the combined friction or
+  // allowing to override this method by a custom method
+  mFrictionCoeff = std::min(frictionCoeffA, frictionCoeffB);
   if (mFrictionCoeff > DART_FRICTION_COEFF_THRESHOLD)
   {
     mIsFrictionOn = true;
@@ -154,7 +176,8 @@ SoftContactConstraint::SoftContactConstraint(
   // Compute local contact Jacobians expressed in body frame
   if (mIsFrictionOn)
   {
-    // Set the dimension of this constraint. 1 is for Normal direction constraint.
+    // Set the dimension of this constraint. 1 is for Normal direction
+    // constraint.
     // TODO(JS): Assumed that the number of contact is not static.
     // TODO(JS): Adjust following code once use of mNumFrictionConeBases is
     //           implemented.
@@ -182,11 +205,12 @@ SoftContactConstraint::SoftContactConstraint(
 
       assert(std::abs(ct->normal.dot(D.col(0))) < DART_EPSILON);
       assert(std::abs(ct->normal.dot(D.col(1))) < DART_EPSILON);
-//      if (D.col(0).dot(D.col(1)) > 0.0)
-//        std::cout << "D.col(0).dot(D.col(1): " << D.col(0).dot(D.col(1)) << std::endl;
+      //      if (D.col(0).dot(D.col(1)) > 0.0)
+      //        std::cout << "D.col(0).dot(D.col(1): " << D.col(0).dot(D.col(1))
+      //        << std::endl;
       assert(std::abs(D.col(0).dot(D.col(1))) < DART_EPSILON);
 
-//      std::cout << "D: " << std::endl << D << std::endl;
+      //      std::cout << "D: " << std::endl << D << std::endl;
 
       // Jacobian for normal contact
       bodyDirection1.noalias()
@@ -194,10 +218,8 @@ SoftContactConstraint::SoftContactConstraint(
       bodyDirection2.noalias()
           = mBodyNode2->getTransform().linear().transpose() * -ct->normal;
 
-      bodyPoint1.noalias()
-          = mBodyNode1->getTransform().inverse() * ct->point;
-      bodyPoint2.noalias()
-          = mBodyNode2->getTransform().inverse() * ct->point;
+      bodyPoint1.noalias() = mBodyNode1->getTransform().inverse() * ct->point;
+      bodyPoint2.noalias() = mBodyNode2->getTransform().inverse() * ct->point;
 
       mJacobians1[idx].head<3>() = bodyPoint1.cross(bodyDirection1);
       mJacobians2[idx].head<3>() = bodyPoint2.cross(bodyDirection2);
@@ -213,12 +235,13 @@ SoftContactConstraint::SoftContactConstraint(
       bodyDirection2.noalias()
           = mBodyNode2->getTransform().linear().transpose() * -D.col(0);
 
-//      bodyPoint1.noalias()
-//          = mBodyNode1->getWorldTransform().inverse() * ct->point;
-//      bodyPoint2.noalias()
-//          = mBodyNode2->getWorldTransform().inverse() * ct->point;
+      //      bodyPoint1.noalias()
+      //          = mBodyNode1->getWorldTransform().inverse() * ct->point;
+      //      bodyPoint2.noalias()
+      //          = mBodyNode2->getWorldTransform().inverse() * ct->point;
 
-//      std::cout << "bodyDirection2: " << std::endl << bodyDirection2 << std::endl;
+      //      std::cout << "bodyDirection2: " << std::endl << bodyDirection2 <<
+      //      std::endl;
 
       mJacobians1[idx].head<3>() = bodyPoint1.cross(bodyDirection1);
       mJacobians2[idx].head<3>() = bodyPoint2.cross(bodyDirection2);
@@ -234,12 +257,13 @@ SoftContactConstraint::SoftContactConstraint(
       bodyDirection2.noalias()
           = mBodyNode2->getTransform().linear().transpose() * -D.col(1);
 
-//      bodyPoint1.noalias()
-//          = mBodyNode1->getWorldTransform().inverse() * ct->point;
-//      bodyPoint2.noalias()
-//          = mBodyNode2->getWorldTransform().inverse() * ct->point;
+      //      bodyPoint1.noalias()
+      //          = mBodyNode1->getWorldTransform().inverse() * ct->point;
+      //      bodyPoint2.noalias()
+      //          = mBodyNode2->getWorldTransform().inverse() * ct->point;
 
-//      std::cout << "bodyDirection2: " << std::endl << bodyDirection2 << std::endl;
+      //      std::cout << "bodyDirection2: " << std::endl << bodyDirection2 <<
+      //      std::endl;
 
       mJacobians1[idx].head<3>() = bodyPoint1.cross(bodyDirection1);
       mJacobians2[idx].head<3>() = bodyPoint2.cross(bodyDirection2);
@@ -273,10 +297,8 @@ SoftContactConstraint::SoftContactConstraint(
       bodyDirection2.noalias()
           = mBodyNode2->getTransform().linear().transpose() * -ct->normal;
 
-      bodyPoint1.noalias()
-          = mBodyNode1->getTransform().inverse() * ct->point;
-      bodyPoint2.noalias()
-          = mBodyNode2->getTransform().inverse() * ct->point;
+      bodyPoint1.noalias() = mBodyNode1->getTransform().inverse() * ct->point;
+      bodyPoint2.noalias() = mBodyNode2->getTransform().inverse() * ct->point;
 
       mJacobians1[i].head<3>().noalias() = bodyPoint1.cross(bodyDirection1);
       mJacobians2[i].head<3>().noalias() = bodyPoint2.cross(bodyDirection2);
@@ -289,12 +311,23 @@ SoftContactConstraint::SoftContactConstraint(
   //----------------------------------------------------------------------------
   // Union finding
   //----------------------------------------------------------------------------
-//  uniteSkeletons();
+  //  uniteSkeletons();
 }
 
 //==============================================================================
-SoftContactConstraint::~SoftContactConstraint()
+SoftContactConstraint::~SoftContactConstraint() {}
+
+//==============================================================================
+const std::string& SoftContactConstraint::getType() const
 {
+  return getStaticType();
+}
+
+//==============================================================================
+const std::string& SoftContactConstraint::getStaticType()
+{
+  static const std::string name = "SoftContactConstraint";
+  return name;
 }
 
 //==============================================================================
@@ -372,7 +405,8 @@ void SoftContactConstraint::setConstraintForceMixing(double _cfm)
   if (_cfm < 1e-9)
   {
     dtwarn << "Constraint force mixing parameter[" << _cfm
-           << "] is lower than 1e-9. " << "It is set to 1e-9." << std::endl;
+           << "] is lower than 1e-9. "
+           << "It is set to 1e-9." << std::endl;
     mConstraintForceMixing = 1e-9;
   }
 
@@ -386,8 +420,7 @@ double SoftContactConstraint::getConstraintForceMixing()
 }
 
 //==============================================================================
-void SoftContactConstraint::setFrictionDirection(
-    const Eigen::Vector3d& _dir)
+void SoftContactConstraint::setFrictionDirection(const Eigen::Vector3d& _dir)
 {
   mFirstFrictionalDirection = _dir.normalized();
 }
@@ -433,25 +466,26 @@ void SoftContactConstraint::getInformation(ConstraintInfo* _info)
 
       // Upper and lower bounds of tangential direction-1 impulsive force
       _info->lo[index + 1] = -mFrictionCoeff;
-      _info->hi[index + 1] =  mFrictionCoeff;
+      _info->hi[index + 1] = mFrictionCoeff;
       _info->findex[index + 1] = index;
 
       // Upper and lower bounds of tangential direction-2 impulsive force
       _info->lo[index + 2] = -mFrictionCoeff;
-      _info->hi[index + 2] =  mFrictionCoeff;
+      _info->hi[index + 2] = mFrictionCoeff;
       _info->findex[index + 2] = index;
 
-//      std::cout << "_frictionalCoff: " << _frictionalCoff << std::endl;
+      //      std::cout << "_frictionalCoff: " << _frictionalCoff << std::endl;
 
-//      std::cout << "_lcp->ub[_idx + 1]: " << _lcp->ub[_idx + 1] << std::endl;
-//      std::cout << "_lcp->ub[_idx + 2]: " << _lcp->ub[_idx + 2] << std::endl;
+      //      std::cout << "_lcp->ub[_idx + 1]: " << _lcp->ub[_idx + 1] <<
+      //      std::endl; std::cout << "_lcp->ub[_idx + 2]: " << _lcp->ub[_idx +
+      //      2] << std::endl;
 
       //------------------------------------------------------------------------
       // Bouncing
       //------------------------------------------------------------------------
       // A. Penetration correction
-      double bouncingVelocity = mContacts[i]->penetrationDepth
-                                - mErrorAllowance;
+      double bouncingVelocity
+          = mContacts[i]->penetrationDepth - mErrorAllowance;
       if (bouncingVelocity < 0.0)
       {
         bouncingVelocity = 0.0;
@@ -484,10 +518,10 @@ void SoftContactConstraint::getInformation(ConstraintInfo* _info)
       }
 
       //
-//      _lcp->b[_idx] = _lcp->b[_idx] * 1.1;
-//      std::cout << "_lcp->b[_idx]: " << _lcp->b[_idx] << std::endl;
+      //      _lcp->b[_idx] = _lcp->b[_idx] * 1.1;
+      //      std::cout << "_lcp->b[_idx]: " << _lcp->b[_idx] << std::endl;
       _info->b[index] += bouncingVelocity;
-//      std::cout << "_lcp->b[_idx]: " << _lcp->b[_idx] << std::endl;
+      //      std::cout << "_lcp->b[_idx]: " << _lcp->b[_idx] << std::endl;
 
       // TODO(JS): Initial guess
       // x
@@ -518,8 +552,8 @@ void SoftContactConstraint::getInformation(ConstraintInfo* _info)
       // Bouncing
       //------------------------------------------------------------------------
       // A. Penetration correction
-      double bouncingVelocity = mContacts[i]->penetrationDepth
-                                - DART_ERROR_ALLOWANCE;
+      double bouncingVelocity
+          = mContacts[i]->penetrationDepth - DART_ERROR_ALLOWANCE;
       if (bouncingVelocity < 0.0)
       {
         bouncingVelocity = 0.0;
@@ -552,10 +586,10 @@ void SoftContactConstraint::getInformation(ConstraintInfo* _info)
       }
 
       //
-//      _lcp->b[_idx] = _lcp->b[_idx] * 1.1;
-//      std::cout << "_lcp->b[_idx]: " << _lcp->b[_idx] << std::endl;
+      //      _lcp->b[_idx] = _lcp->b[_idx] * 1.1;
+      //      std::cout << "_lcp->b[_idx]: " << _lcp->b[_idx] << std::endl;
       _info->b[i] += bouncingVelocity;
-//      std::cout << "_lcp->b[_idx]: " << _lcp->b[_idx] << std::endl;
+      //      std::cout << "_lcp->b[_idx]: " << _lcp->b[_idx] << std::endl;
 
       // TODO(JS): Initial guess
       // x
@@ -581,28 +615,28 @@ void SoftContactConstraint::applyUnitImpulse(std::size_t _idx)
     if (mPointMass1)
     {
       mBodyNode1->getSkeleton()->updateBiasImpulse(
-            mSoftBodyNode1, mPointMass1, mJacobians1[_idx].tail<3>());
+          mSoftBodyNode1, mPointMass1, mJacobians1[_idx].tail<3>());
     }
     else
     {
       if (mBodyNode1->isReactive())
       {
-        mBodyNode1->getSkeleton()->updateBiasImpulse(mBodyNode1,
-                                                     mJacobians1[_idx]);
+        mBodyNode1->getSkeleton()->updateBiasImpulse(
+            mBodyNode1, mJacobians1[_idx]);
       }
     }
 
     if (mPointMass2)
     {
       mBodyNode2->getSkeleton()->updateBiasImpulse(
-            mSoftBodyNode2, mPointMass2, mJacobians2[_idx].tail<3>());
+          mSoftBodyNode2, mPointMass2, mJacobians2[_idx].tail<3>());
     }
     else
     {
       if (mBodyNode2->isReactive())
       {
-        mBodyNode2->getSkeleton()->updateBiasImpulse(mBodyNode2,
-                                                       mJacobians2[_idx]);
+        mBodyNode2->getSkeleton()->updateBiasImpulse(
+            mBodyNode2, mJacobians2[_idx]);
       }
     }
 
@@ -615,7 +649,7 @@ void SoftContactConstraint::applyUnitImpulse(std::size_t _idx)
     {
       mBodyNode1->getSkeleton()->clearConstraintImpulses();
       mBodyNode1->getSkeleton()->updateBiasImpulse(
-            mSoftBodyNode1, mPointMass1, mJacobians1[_idx].tail<3>());
+          mSoftBodyNode1, mPointMass1, mJacobians1[_idx].tail<3>());
       mBodyNode1->getSkeleton()->updateVelocityChange();
     }
     else
@@ -623,8 +657,8 @@ void SoftContactConstraint::applyUnitImpulse(std::size_t _idx)
       if (mBodyNode1->isReactive())
       {
         mBodyNode1->getSkeleton()->clearConstraintImpulses();
-        mBodyNode1->getSkeleton()->updateBiasImpulse(mBodyNode1,
-                                                     mJacobians1[_idx]);
+        mBodyNode1->getSkeleton()->updateBiasImpulse(
+            mBodyNode1, mJacobians1[_idx]);
         mBodyNode1->getSkeleton()->updateVelocityChange();
       }
     }
@@ -633,7 +667,7 @@ void SoftContactConstraint::applyUnitImpulse(std::size_t _idx)
     {
       mBodyNode2->getSkeleton()->clearConstraintImpulses();
       mBodyNode2->getSkeleton()->updateBiasImpulse(
-            mSoftBodyNode2, mPointMass2, mJacobians2[_idx].tail<3>());
+          mSoftBodyNode2, mPointMass2, mJacobians2[_idx].tail<3>());
       mBodyNode2->getSkeleton()->updateVelocityChange();
     }
     else
@@ -641,8 +675,8 @@ void SoftContactConstraint::applyUnitImpulse(std::size_t _idx)
       if (mBodyNode2->isReactive())
       {
         mBodyNode2->getSkeleton()->clearConstraintImpulses();
-        mBodyNode2->getSkeleton()->updateBiasImpulse(mBodyNode2,
-                                                     mJacobians2[_idx]);
+        mBodyNode2->getSkeleton()->updateBiasImpulse(
+            mBodyNode2, mJacobians2[_idx]);
         mBodyNode2->getSkeleton()->updateVelocityChange();
       }
     }
@@ -665,7 +699,7 @@ void SoftContactConstraint::getVelocityChange(double* _vel, bool _withCfm)
       if (mPointMass1)
       {
         _vel[i] += mJacobians1[i].tail<3>().dot(
-                     mPointMass1->getBodyVelocityChange());
+            mPointMass1->getBodyVelocityChange());
       }
       else
       {
@@ -679,7 +713,7 @@ void SoftContactConstraint::getVelocityChange(double* _vel, bool _withCfm)
       if (mPointMass2)
       {
         _vel[i] += mJacobians2[i].tail<3>().dot(
-                     mPointMass2->getBodyVelocityChange());
+            mPointMass2->getBodyVelocityChange());
       }
       else
       {
@@ -693,8 +727,8 @@ void SoftContactConstraint::getVelocityChange(double* _vel, bool _withCfm)
   // varaible in ODE
   if (_withCfm)
   {
-    _vel[mAppliedImpulseIndex] += _vel[mAppliedImpulseIndex]
-                                     * mConstraintForceMixing;
+    _vel[mAppliedImpulseIndex]
+        += _vel[mAppliedImpulseIndex] * mConstraintForceMixing;
   }
 }
 
@@ -732,13 +766,14 @@ void SoftContactConstraint::applyImpulse(double* _lambda)
 
     for (std::size_t i = 0; i < mContacts.size(); ++i)
     {
-//      std::cout << "_lambda1: " << _lambda[_idx] << std::endl;
-//      std::cout << "_lambda2: " << _lambda[_idx + 1] << std::endl;
-//      std::cout << "_lambda3: " << _lambda[_idx + 2] << std::endl;
+      //      std::cout << "_lambda1: " << _lambda[_idx] << std::endl;
+      //      std::cout << "_lambda2: " << _lambda[_idx + 1] << std::endl;
+      //      std::cout << "_lambda3: " << _lambda[_idx + 2] << std::endl;
 
-//      std::cout << "imp1: " << mJacobians2[i * 3 + 0] * _lambda[_idx] << std::endl;
-//      std::cout << "imp2: " << mJacobians2[i * 3 + 1] * _lambda[_idx + 1] << std::endl;
-//      std::cout << "imp3: " << mJacobians2[i * 3 + 2] * _lambda[_idx + 2] << std::endl;
+      //      std::cout << "imp1: " << mJacobians2[i * 3 + 0] * _lambda[_idx] <<
+      //      std::endl; std::cout << "imp2: " << mJacobians2[i * 3 + 1] *
+      //      _lambda[_idx + 1] << std::endl; std::cout << "imp3: " <<
+      //      mJacobians2[i * 3 + 2] * _lambda[_idx + 2] << std::endl;
 
       assert(!math::isNan(_lambda[index]));
 
@@ -746,11 +781,11 @@ void SoftContactConstraint::applyImpulse(double* _lambda)
       mContacts[i]->force = mContacts[i]->normal * _lambda[index] / mTimeStep;
 
       // Normal impulsive force
-//      mContacts[i]->lambda[0] = _lambda[_idx];
+      //      mContacts[i]->lambda[0] = _lambda[_idx];
       if (mPointMass1)
       {
-        mPointMass1->addConstraintImpulse(mJacobians1[index].tail<3>()
-                                          * _lambda[index], true);
+        mPointMass1->addConstraintImpulse(
+            mJacobians1[index].tail<3>() * _lambda[index], true);
       }
       else
       {
@@ -760,15 +795,15 @@ void SoftContactConstraint::applyImpulse(double* _lambda)
 
       if (mPointMass2)
       {
-        mPointMass2->addConstraintImpulse(mJacobians2[index].tail<3>()
-                                          * _lambda[index], true);
+        mPointMass2->addConstraintImpulse(
+            mJacobians2[index].tail<3>() * _lambda[index], true);
       }
       else
       {
         if (mBodyNode2->isReactive())
           mBodyNode2->addConstraintImpulse(mJacobians2[index] * _lambda[index]);
       }
-//      std::cout << "_lambda: " << _lambda[_idx] << std::endl;
+      //      std::cout << "_lambda: " << _lambda[_idx] << std::endl;
       index++;
 
       assert(!math::isNan(_lambda[index]));
@@ -778,11 +813,11 @@ void SoftContactConstraint::applyImpulse(double* _lambda)
       mContacts[i]->force += D.col(0) * _lambda[index] / mTimeStep;
 
       // Tangential direction-1 impulsive force
-//      mContacts[i]->lambda[1] = _lambda[_idx];
+      //      mContacts[i]->lambda[1] = _lambda[_idx];
       if (mPointMass1)
       {
-        mPointMass1->addConstraintImpulse(mJacobians1[index].tail<3>()
-                                          * _lambda[index], true);
+        mPointMass1->addConstraintImpulse(
+            mJacobians1[index].tail<3>() * _lambda[index], true);
       }
       else
       {
@@ -792,15 +827,15 @@ void SoftContactConstraint::applyImpulse(double* _lambda)
 
       if (mPointMass2)
       {
-        mPointMass2->addConstraintImpulse(mJacobians2[index].tail<3>()
-                                          * _lambda[index], true);
+        mPointMass2->addConstraintImpulse(
+            mJacobians2[index].tail<3>() * _lambda[index], true);
       }
       else
       {
         if (mBodyNode2->isReactive())
           mBodyNode2->addConstraintImpulse(mJacobians2[index] * _lambda[index]);
       }
-//      std::cout << "_lambda: " << _lambda[_idx] << std::endl;
+      //      std::cout << "_lambda: " << _lambda[_idx] << std::endl;
       index++;
 
       assert(!math::isNan(_lambda[index]));
@@ -809,11 +844,11 @@ void SoftContactConstraint::applyImpulse(double* _lambda)
       mContacts[i]->force += D.col(1) * _lambda[index] / mTimeStep;
 
       // Tangential direction-2 impulsive force
-//      mContacts[i]->lambda[2] = _lambda[_idx];
+      //      mContacts[i]->lambda[2] = _lambda[_idx];
       if (mPointMass1)
       {
-        mPointMass1->addConstraintImpulse(mJacobians1[index].tail<3>()
-                                          * _lambda[index], true);
+        mPointMass1->addConstraintImpulse(
+            mJacobians1[index].tail<3>() * _lambda[index], true);
       }
       else
       {
@@ -823,15 +858,15 @@ void SoftContactConstraint::applyImpulse(double* _lambda)
 
       if (mPointMass2)
       {
-        mPointMass2->addConstraintImpulse(mJacobians2[index].tail<3>()
-                                          * _lambda[index], true);
+        mPointMass2->addConstraintImpulse(
+            mJacobians2[index].tail<3>() * _lambda[index], true);
       }
       else
       {
         if (mBodyNode2->isReactive())
           mBodyNode2->addConstraintImpulse(mJacobians2[index] * _lambda[index]);
       }
-//      std::cout << "_lambda: " << _lambda[_idx] << std::endl;
+      //      std::cout << "_lambda: " << _lambda[_idx] << std::endl;
       index++;
     }
   }
@@ -843,12 +878,12 @@ void SoftContactConstraint::applyImpulse(double* _lambda)
     for (std::size_t i = 0; i < mContacts.size(); ++i)
     {
       // Normal impulsive force
-//			pContactPts[i]->lambda[0] = _lambda[i];
+      //			pContactPts[i]->lambda[0] = _lambda[i];
 
       if (mPointMass1)
       {
-        mPointMass1->addConstraintImpulse(mJacobians1[i].tail<3>()
-                                          * _lambda[i], true);
+        mPointMass1->addConstraintImpulse(
+            mJacobians1[i].tail<3>() * _lambda[i], true);
       }
       else
       {
@@ -858,8 +893,8 @@ void SoftContactConstraint::applyImpulse(double* _lambda)
 
       if (mPointMass2)
       {
-        mPointMass2->addConstraintImpulse(mJacobians2[i].tail<3>()
-                                          * _lambda[i], true);
+        mPointMass2->addConstraintImpulse(
+            mJacobians2[i].tail<3>() * _lambda[i], true);
       }
       else
       {
@@ -892,7 +927,7 @@ void SoftContactConstraint::getRelVelocity(double* _vel)
     else
       _vel[i] -= mJacobians2[i].dot(mBodyNode2->getSpatialVelocity());
 
-//    std::cout << "_relVel[i + _idx]: " << _relVel[i + _idx] << std::endl;
+    //    std::cout << "_relVel[i + _idx]: " << _relVel[i + _idx] << std::endl;
   }
 }
 
@@ -902,6 +937,46 @@ bool SoftContactConstraint::isActive() const
   return mActive;
 }
 
+//==============================================================================
+double SoftContactConstraint::computeFrictionCoefficient(
+    const dynamics::ShapeNode* shapeNode)
+{
+  assert(shapeNode);
+
+  auto dynamicAspect = shapeNode->getDynamicsAspect();
+
+  if (dynamicAspect == nullptr)
+  {
+    dtwarn << "[ContactConstraint] Attempt to extract friction coefficient "
+           << "from a ShapeNode that doesn't have DynamicAspect. The default "
+           << "value (" << DART_DEFAULT_FRICTION_COEFF << ") will be used "
+           << "instead.\n";
+    return DART_DEFAULT_FRICTION_COEFF;
+  }
+
+  return dynamicAspect->getFrictionCoeff();
+}
+
+//==============================================================================
+double SoftContactConstraint::computeRestitutionCoefficient(
+    const dynamics::ShapeNode* shapeNode)
+{
+  assert(shapeNode);
+
+  auto dynamicAspect = shapeNode->getDynamicsAspect();
+
+  if (dynamicAspect == nullptr)
+  {
+    dtwarn << "[ContactConstraint] Attempt to extract restitution coefficient "
+           << "from a ShapeNode that doesn't have DynamicAspect. The default "
+           << "value (" << DART_DEFAULT_RESTITUTION_COEFF << ") will be used "
+           << "instead.\n";
+    return DART_DEFAULT_RESTITUTION_COEFF;
+  }
+
+  return dynamicAspect->getRestitutionCoeff();
+}
+
 //==============================================================================
 dynamics::SkeletonPtr SoftContactConstraint::getRootSkeleton() const
 {
@@ -945,14 +1020,15 @@ void SoftContactConstraint::uniteSkeletons()
 //==============================================================================
 void SoftContactConstraint::updateFirstFrictionalDirection()
 {
-//  std::cout << "SoftContactConstraintTEST::_updateFirstFrictionalDirection(): "
-//            << "Not finished implementation."
-//            << std::endl;
+  //  std::cout <<
+  //  "SoftContactConstraintTEST::_updateFirstFrictionalDirection(): "
+  //            << "Not finished implementation."
+  //            << std::endl;
 
   // TODO(JS): Not implemented
   // Refer to:
   // https://github.com/erwincoumans/bullet3/blob/master/src/BulletDynamics/ConstraintSolver/btSequentialImpulseConstraintSolver.cpp#L910
-//  mFirstFrictionalDirection;
+  //  mFirstFrictionalDirection;
 }
 
 //==============================================================================
@@ -963,7 +1039,7 @@ Eigen::MatrixXd SoftContactConstraint::getTangentBasisMatrixODE(
 
   // TODO(JS): Use mNumFrictionConeBases
   // Check if the number of bases is even number.
-//  bool isEvenNumBases = mNumFrictionConeBases % 2 ? true : false;
+  //  bool isEvenNumBases = mNumFrictionConeBases % 2 ? true : false;
 
   Eigen::MatrixXd T(Eigen::MatrixXd::Zero(3, 2));
 
@@ -991,9 +1067,7 @@ Eigen::MatrixXd SoftContactConstraint::getTangentBasisMatrixODE(
 //==============================================================================
 template <typename PointMassT, typename SoftBodyNodeT>
 static PointMassT selectCollidingPointMassT(
-    SoftBodyNodeT _softBodyNode,
-    const Eigen::Vector3d& _point,
-    int _faceId)
+    SoftBodyNodeT _softBodyNode, const Eigen::Vector3d& _point, int _faceId)
 {
   PointMassT pointMass = nullptr;
 
@@ -1035,9 +1109,9 @@ const dynamics::PointMass* SoftContactConstraint::selectCollidingPointMass(
     const Eigen::Vector3d& _point,
     int _faceId) const
 {
-  return selectCollidingPointMassT<const dynamics::PointMass*,
-                                   const dynamics::SoftBodyNode*>(
-        _softBodyNode, _point, _faceId);
+  return selectCollidingPointMassT<
+      const dynamics::PointMass*,
+      const dynamics::SoftBodyNode*>(_softBodyNode, _point, _faceId);
 }
 
 //==============================================================================
@@ -1046,10 +1120,10 @@ dynamics::PointMass* SoftContactConstraint::selectCollidingPointMass(
     const Eigen::Vector3d& _point,
     int _faceId) const
 {
-  return selectCollidingPointMassT<dynamics::PointMass*,
-                                   dynamics::SoftBodyNode*>(
-        _softBodyNode, _point, _faceId);
+  return selectCollidingPointMassT<
+      dynamics::PointMass*,
+      dynamics::SoftBodyNode*>(_softBodyNode, _point, _faceId);
 }
 
-}  // namespace constraint
-}  // namespace dart
+} // namespace constraint
+} // namespace dart
