@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011-2019, The DART development contributors
+ * Copyright (c) 2011-2021, The DART development contributors
  * All rights reserved.
  *
  * The list of contributors can be found at:
@@ -30,19 +30,22 @@
  *   POSSIBILITY OF SUCH DAMAGE.
  */
 
-#include "dart/common/Console.hpp"
 #include "dart/dynamics/Group.hpp"
+
+#include "dart/common/Console.hpp"
 #include "dart/dynamics/BodyNode.hpp"
-#include "dart/dynamics/Joint.hpp"
 #include "dart/dynamics/DegreeOfFreedom.hpp"
+#include "dart/dynamics/Joint.hpp"
 
 namespace dart {
 namespace dynamics {
 
 //==============================================================================
-GroupPtr Group::create(const std::string& _name,
-                       const std::vector<BodyNode*>& _bodyNodes,
-                       bool _includeJoints, bool _includeDofs)
+GroupPtr Group::create(
+    const std::string& _name,
+    const std::vector<BodyNode*>& _bodyNodes,
+    bool _includeJoints,
+    bool _includeDofs)
 {
   GroupPtr group(new Group(_name, _bodyNodes, _includeJoints, _includeDofs));
   group->mPtr = group;
@@ -50,9 +53,11 @@ GroupPtr Group::create(const std::string& _name,
 }
 
 //==============================================================================
-GroupPtr Group::create(const std::string& _name,
-                       const std::vector<DegreeOfFreedom*>& _dofs,
-                       bool _includeBodyNodes, bool _includeJoints)
+GroupPtr Group::create(
+    const std::string& _name,
+    const std::vector<DegreeOfFreedom*>& _dofs,
+    bool _includeBodyNodes,
+    bool _includeJoints)
 {
   GroupPtr group(new Group(_name, _dofs, _includeBodyNodes, _includeJoints));
   group->mPtr = group;
@@ -60,8 +65,8 @@ GroupPtr Group::create(const std::string& _name,
 }
 
 //==============================================================================
-GroupPtr Group::create(const std::string& _name,
-                       const MetaSkeletonPtr& _metaSkeleton)
+GroupPtr Group::create(
+    const std::string& _name, const MetaSkeletonPtr& _metaSkeleton)
 {
   GroupPtr group(new Group(_name, _metaSkeleton));
   group->mPtr = group;
@@ -146,7 +151,7 @@ MetaSkeletonPtr Group::cloneMetaSkeleton(const std::string& cloneName) const
 //==============================================================================
 void Group::swapBodyNodeIndices(std::size_t _index1, std::size_t _index2)
 {
-  if(_index1 >= mBodyNodes.size() || _index2 >= mBodyNodes.size())
+  if (_index1 >= mBodyNodes.size() || _index2 >= mBodyNodes.size())
   {
     dterr << "[Group::swapBodyNodeIndices] Trying to swap out-of-bound indices "
           << "for the Group named [" << getName() << "] (" << this << ")! "
@@ -159,10 +164,10 @@ void Group::swapBodyNodeIndices(std::size_t _index1, std::size_t _index2)
   BodyNode* bn1 = mBodyNodes[_index1];
   BodyNode* bn2 = mBodyNodes[_index2];
 
-  std::unordered_map<const BodyNode*, IndexMap>::iterator it1 =
-      mIndexMap.find(bn1);
+  std::unordered_map<const BodyNode*, IndexMap>::iterator it1
+      = mIndexMap.find(bn1);
 
-  if(it1 == mIndexMap.end())
+  if (it1 == mIndexMap.end())
   {
     dterr << "[Group::swapBodyNodeIndices] Unable to find BodyNode ["
           << bn1->getName() << "] (" << bn1 << ") in the index map of the "
@@ -172,10 +177,10 @@ void Group::swapBodyNodeIndices(std::size_t _index1, std::size_t _index2)
     return;
   }
 
-  std::unordered_map<const BodyNode*, IndexMap>::iterator it2 =
-      mIndexMap.find(bn2);
+  std::unordered_map<const BodyNode*, IndexMap>::iterator it2
+      = mIndexMap.find(bn2);
 
-  if(it2 == mIndexMap.end())
+  if (it2 == mIndexMap.end())
   {
     dterr << "[Group::swapBodyNodeIndices] Unable to find BodyNode ["
           << bn2->getName() << "] (" << bn2 << ") in the index map of the "
@@ -196,7 +201,7 @@ void Group::swapBodyNodeIndices(std::size_t _index1, std::size_t _index2)
 //==============================================================================
 void Group::swapDofIndices(std::size_t _index1, std::size_t _index2)
 {
-  if(_index1 >= mDofs.size() || _index2 >= mDofs.size())
+  if (_index1 >= mDofs.size() || _index2 >= mDofs.size())
   {
     dterr << "[Group::swapDofIndices] Trying to swap out-of-bound indices for "
           << "the Group named [" << getName() << "] (" << this << ")! "
@@ -209,10 +214,10 @@ void Group::swapDofIndices(std::size_t _index1, std::size_t _index2)
   DegreeOfFreedom* dof1 = mDofs[_index1];
   DegreeOfFreedom* dof2 = mDofs[_index2];
 
-  std::unordered_map<const BodyNode*, IndexMap>::iterator it1 =
-      mIndexMap.find(dof1->getChildBodyNode());
+  std::unordered_map<const BodyNode*, IndexMap>::iterator it1
+      = mIndexMap.find(dof1->getChildBodyNode());
 
-  if(it1 == mIndexMap.end())
+  if (it1 == mIndexMap.end())
   {
     dterr << "[Group::swapDofIndices] Unable to find DegreeOfFreedom ["
           << dof1->getName() << "] (" << dof1 << ") in the index map of the "
@@ -222,10 +227,10 @@ void Group::swapDofIndices(std::size_t _index1, std::size_t _index2)
     return;
   }
 
-  std::unordered_map<const BodyNode*, IndexMap>::iterator it2 =
-      mIndexMap.find(dof2->getChildBodyNode());
+  std::unordered_map<const BodyNode*, IndexMap>::iterator it2
+      = mIndexMap.find(dof2->getChildBodyNode());
 
-  if(it2 == mIndexMap.end())
+  if (it2 == mIndexMap.end())
   {
     dterr << "[Group::swapDofIndices] Unable to find DegreeOfFreedom ["
           << dof2->getName() << "] (" << dof2 << ") in the index map of the "
@@ -250,9 +255,9 @@ void Group::swapDofIndices(std::size_t _index1, std::size_t _index2)
 //==============================================================================
 bool Group::addComponent(BodyNode* _bn, bool _warning)
 {
-  if(nullptr == _bn)
+  if (nullptr == _bn)
   {
-    if(_warning)
+    if (_warning)
     {
       dtwarn << "[Group::addComponent] Attempting to add a nullptr component "
              << "to the Group [" << getName() << "] (" << this << ")\n";
@@ -266,10 +271,10 @@ bool Group::addComponent(BodyNode* _bn, bool _warning)
 
   added |= addBodyNode(_bn, false);
 
-  for(std::size_t i=0; i < _bn->getParentJoint()->getNumDofs(); ++i)
+  for (std::size_t i = 0; i < _bn->getParentJoint()->getNumDofs(); ++i)
     added |= addDof(_bn->getParentJoint()->getDof(i), false);
 
-  if(_warning && !added)
+  if (_warning && !added)
   {
     dtwarn << "[Group::addComponent] The BodyNode named [" << _bn->getName()
            << "] (" << _bn << ") and all of its parent DegreesOfFreedom are "
@@ -281,11 +286,11 @@ bool Group::addComponent(BodyNode* _bn, bool _warning)
 }
 
 //==============================================================================
-bool Group::addComponents(const std::vector<BodyNode*>& _bodyNodes,
-                          bool _warning)
+bool Group::addComponents(
+    const std::vector<BodyNode*>& _bodyNodes, bool _warning)
 {
   bool added = false;
-  for(BodyNode* bn : _bodyNodes)
+  for (BodyNode* bn : _bodyNodes)
     added |= addComponent(bn, _warning);
 
   return added;
@@ -294,9 +299,9 @@ bool Group::addComponents(const std::vector<BodyNode*>& _bodyNodes,
 //==============================================================================
 bool Group::removeComponent(BodyNode* _bn, bool _warning)
 {
-  if(nullptr == _bn)
+  if (nullptr == _bn)
   {
-    if(_warning)
+    if (_warning)
     {
       dtwarn << "[Group::removeComponent] Attempting to remove a nullptr "
              << "component from the Group [" << getName() << "] (" << this
@@ -311,10 +316,10 @@ bool Group::removeComponent(BodyNode* _bn, bool _warning)
 
   removed |= removeBodyNode(_bn, false);
 
-  for(std::size_t i=0; i < _bn->getParentJoint()->getNumDofs(); ++i)
+  for (std::size_t i = 0; i < _bn->getParentJoint()->getNumDofs(); ++i)
     removed |= removeDof(_bn->getParentJoint()->getDof(i), false);
 
-  if(_warning && !removed)
+  if (_warning && !removed)
   {
     dtwarn << "[Group::removeComponent] The BodyNode named [" << _bn->getName()
            << "] (" << _bn << ") and its parent DegreesOfFreedom were not in "
@@ -326,11 +331,11 @@ bool Group::removeComponent(BodyNode* _bn, bool _warning)
 }
 
 //==============================================================================
-bool Group::removeComponents(const std::vector<BodyNode*>& _bodyNodes,
-                             bool _warning)
+bool Group::removeComponents(
+    const std::vector<BodyNode*>& _bodyNodes, bool _warning)
 {
   bool removed = false;
-  for(BodyNode* bn : _bodyNodes)
+  for (BodyNode* bn : _bodyNodes)
     removed |= removeComponent(bn, _warning);
 
   return removed;
@@ -339,9 +344,9 @@ bool Group::removeComponents(const std::vector<BodyNode*>& _bodyNodes,
 //==============================================================================
 bool Group::addBodyNode(BodyNode* _bn, bool _warning)
 {
-  if(nullptr == _bn)
+  if (nullptr == _bn)
   {
-    if(_warning)
+    if (_warning)
     {
       dtwarn << "[Group::addBodyNode] Attempting to add a nullptr BodyNode "
              << "to the Group [" << getName() << "] (" << this << ")\n";
@@ -351,9 +356,9 @@ bool Group::addBodyNode(BodyNode* _bn, bool _warning)
     return false;
   }
 
-  if(INVALID_INDEX != getIndexOf(_bn, false))
+  if (INVALID_INDEX != getIndexOf(_bn, false))
   {
-    if(_warning)
+    if (_warning)
     {
       dtwarn << "[Group::addBodyNode] The BodyNode named [" << _bn->getName()
              << "] (" << _bn << ") is already in the Group [" << getName()
@@ -369,11 +374,11 @@ bool Group::addBodyNode(BodyNode* _bn, bool _warning)
 }
 
 //==============================================================================
-bool Group::addBodyNodes(const std::vector<BodyNode*>& _bodyNodes,
-                         bool _warning)
+bool Group::addBodyNodes(
+    const std::vector<BodyNode*>& _bodyNodes, bool _warning)
 {
   bool added = false;
-  for(BodyNode* bn : _bodyNodes)
+  for (BodyNode* bn : _bodyNodes)
     added |= addBodyNode(bn, _warning);
 
   return added;
@@ -382,9 +387,9 @@ bool Group::addBodyNodes(const std::vector<BodyNode*>& _bodyNodes,
 //==============================================================================
 bool Group::removeBodyNode(BodyNode* _bn, bool _warning)
 {
-  if(nullptr == _bn)
+  if (nullptr == _bn)
   {
-    if(_warning)
+    if (_warning)
     {
       dtwarn << "[Group::removeBodyNode] Attempting to remove a nullptr "
              << "BodyNode from the Group [" << getName() << "] (" << this
@@ -395,9 +400,9 @@ bool Group::removeBodyNode(BodyNode* _bn, bool _warning)
     return false;
   }
 
-  if(INVALID_INDEX == getIndexOf(_bn, false))
+  if (INVALID_INDEX == getIndexOf(_bn, false))
   {
-    if(_warning)
+    if (_warning)
     {
       dtwarn << "[Group::removeBodyNode] The BodyNode named [" << _bn->getName()
              << "] (" << _bn << ") is NOT in the Group [" << getName() << "] ("
@@ -413,11 +418,11 @@ bool Group::removeBodyNode(BodyNode* _bn, bool _warning)
 }
 
 //==============================================================================
-bool Group::removeBodyNodes(const std::vector<BodyNode*>& _bodyNodes,
-                            bool _warning)
+bool Group::removeBodyNodes(
+    const std::vector<BodyNode*>& _bodyNodes, bool _warning)
 {
   bool removed = false;
-  for(BodyNode* bn : _bodyNodes)
+  for (BodyNode* bn : _bodyNodes)
     removed |= removeBodyNode(bn, _warning);
 
   return removed;
@@ -426,9 +431,9 @@ bool Group::removeBodyNodes(const std::vector<BodyNode*>& _bodyNodes,
 //==============================================================================
 bool Group::addJoint(Joint* _joint, bool _addDofs, bool _warning)
 {
-  if(nullptr == _joint)
+  if (nullptr == _joint)
   {
-    if(_warning)
+    if (_warning)
     {
       dtwarn << "[Group::addJoint] Attempting to add a nullptr Joint to the "
              << "Group [" << getName() << "] (" << this << ")\n";
@@ -439,21 +444,21 @@ bool Group::addJoint(Joint* _joint, bool _addDofs, bool _warning)
   }
 
   bool added = false;
-  if(INVALID_INDEX == getIndexOf(_joint, false))
+  if (INVALID_INDEX == getIndexOf(_joint, false))
   {
     registerJoint(_joint);
     added = true;
   }
 
-  if(_addDofs)
+  if (_addDofs)
   {
-    for(std::size_t i=0; i < _joint->getNumDofs(); ++i)
+    for (std::size_t i = 0; i < _joint->getNumDofs(); ++i)
       added |= addDof(_joint->getDof(i), false, false);
   }
 
-  if(!added && _warning)
+  if (!added && _warning)
   {
-    if(_addDofs)
+    if (_addDofs)
     {
       dtwarn << "[Group::addJoint] The Joint named [" << _joint->getName()
              << "] (" << _joint << ") and all its DOFs are already in the "
@@ -473,11 +478,11 @@ bool Group::addJoint(Joint* _joint, bool _addDofs, bool _warning)
 }
 
 //==============================================================================
-bool Group::addJoints(const std::vector<Joint*>& _joints,
-                      bool _addDofs, bool _warning)
+bool Group::addJoints(
+    const std::vector<Joint*>& _joints, bool _addDofs, bool _warning)
 {
   bool added = false;
-  for(Joint* joint : _joints)
+  for (Joint* joint : _joints)
     added |= addJoint(joint, _addDofs, _warning);
 
   return added;
@@ -486,9 +491,9 @@ bool Group::addJoints(const std::vector<Joint*>& _joints,
 //==============================================================================
 bool Group::removeJoint(Joint* _joint, bool _removeDofs, bool _warning)
 {
-  if(nullptr == _joint)
+  if (nullptr == _joint)
   {
-    if(_warning)
+    if (_warning)
     {
       dtwarn << "[Group::removeJoint] Attempting to remove a nullptr Joint "
              << "from the Group [" << getName() << "] (" << this << ")\n";
@@ -502,21 +507,21 @@ bool Group::removeJoint(Joint* _joint, bool _removeDofs, bool _warning)
   JointPtr hold(_joint);
 
   bool removed = false;
-  if(INVALID_INDEX != getIndexOf(_joint, false))
+  if (INVALID_INDEX != getIndexOf(_joint, false))
   {
     unregisterJoint(_joint->getChildBodyNode());
     removed = true;
   }
 
-  if(_removeDofs)
+  if (_removeDofs)
   {
-    for(std::size_t i=0; i < _joint->getNumDofs(); ++i)
+    for (std::size_t i = 0; i < _joint->getNumDofs(); ++i)
       removed |= removeDof(_joint->getDof(i), false, false);
   }
 
-  if(!removed && _warning)
+  if (!removed && _warning)
   {
-    if(_removeDofs)
+    if (_removeDofs)
     {
       dtwarn << "[Group::removeJoint] The Joint named [" << _joint->getName()
              << "] (" << _joint << ") and its DOFs were NOT in the Group ["
@@ -540,7 +545,7 @@ bool Group::removeJoints(
     const std::vector<Joint*>& _joints, bool _removeDofs, bool _warning)
 {
   bool removed = false;
-  for(Joint* joint : _joints)
+  for (Joint* joint : _joints)
     removed |= removeJoint(joint, _removeDofs, _warning);
 
   return removed;
@@ -549,9 +554,9 @@ bool Group::removeJoints(
 //==============================================================================
 bool Group::addDof(DegreeOfFreedom* _dof, bool _addJoint, bool _warning)
 {
-  if(nullptr == _dof)
+  if (nullptr == _dof)
   {
-    if(_warning)
+    if (_warning)
     {
       dtwarn << "[Group::addDof] Attempting to add a nullptr DegreeOfFreedom "
              << "to the Group [" << getName() << "] (" << this << ")\n";
@@ -562,18 +567,18 @@ bool Group::addDof(DegreeOfFreedom* _dof, bool _addJoint, bool _warning)
   }
 
   bool added = false;
-  if(INVALID_INDEX == getIndexOf(_dof, false))
+  if (INVALID_INDEX == getIndexOf(_dof, false))
   {
     registerDegreeOfFreedom(_dof);
     added = true;
   }
 
-  if(_addJoint)
+  if (_addJoint)
     added |= addJoint(_dof->getJoint(), false, false);
 
-  if(!added && _warning)
+  if (!added && _warning)
   {
-    if(_addJoint)
+    if (_addJoint)
     {
       dtwarn << "[Group::addDof] The DegreeOfFreedom named [" << _dof->getName()
              << "] (" << _dof << ") and its Joint are already in the Group ["
@@ -593,11 +598,11 @@ bool Group::addDof(DegreeOfFreedom* _dof, bool _addJoint, bool _warning)
 }
 
 //==============================================================================
-bool Group::addDofs(const std::vector<DegreeOfFreedom*>& _dofs,
-                    bool _addJoint, bool _warning)
+bool Group::addDofs(
+    const std::vector<DegreeOfFreedom*>& _dofs, bool _addJoint, bool _warning)
 {
   bool added = false;
-  for(DegreeOfFreedom* dof : _dofs)
+  for (DegreeOfFreedom* dof : _dofs)
     added |= addDof(dof, _addJoint, _warning);
 
   return added;
@@ -606,13 +611,13 @@ bool Group::addDofs(const std::vector<DegreeOfFreedom*>& _dofs,
 //==============================================================================
 bool Group::removeDof(DegreeOfFreedom* _dof, bool _cleanupJoint, bool _warning)
 {
-  if(nullptr == _dof)
+  if (nullptr == _dof)
   {
-    if(_warning)
+    if (_warning)
     {
       dtwarn << "[Group::removeDof] Attempting to remove a nullptr "
-             << "DegreeOfFreedom from the Group [" << getName() << "] ("
-             << this << ")\n";
+             << "DegreeOfFreedom from the Group [" << getName() << "] (" << this
+             << ")\n";
       assert(false);
     }
 
@@ -624,20 +629,21 @@ bool Group::removeDof(DegreeOfFreedom* _dof, bool _cleanupJoint, bool _warning)
   DegreeOfFreedomPtr hold(_dof);
 
   bool removed = false;
-  if(INVALID_INDEX != getIndexOf(_dof, false))
+  if (INVALID_INDEX != getIndexOf(_dof, false))
   {
-    unregisterDegreeOfFreedom(_dof->getChildBodyNode(), _dof->getIndexInJoint());
+    unregisterDegreeOfFreedom(
+        _dof->getChildBodyNode(), _dof->getIndexInJoint());
     removed = true;
   }
 
-  if(_cleanupJoint)
+  if (_cleanupJoint)
   {
     // Check whether any DOFs belonging to the Joint are remaining in the Group
     bool performCleanup = true;
     Joint* joint = _dof->getJoint();
-    for(std::size_t i=0; i < joint->getNumDofs(); ++i)
+    for (std::size_t i = 0; i < joint->getNumDofs(); ++i)
     {
-      if(getIndexOf(joint->getDof(i), false) == INVALID_INDEX)
+      if (getIndexOf(joint->getDof(i), false) == INVALID_INDEX)
       {
         performCleanup = false;
         break;
@@ -645,13 +651,13 @@ bool Group::removeDof(DegreeOfFreedom* _dof, bool _cleanupJoint, bool _warning)
     }
 
     // Remove the Joint if none of its DOFs remain
-    if(performCleanup)
+    if (performCleanup)
       removed |= removeJoint(joint, false, false);
   }
 
-  if(!removed && _warning)
+  if (!removed && _warning)
   {
-    if(_cleanupJoint)
+    if (_cleanupJoint)
     {
       dtwarn << "[Group::removeDof] The DegreeOfFreedom named ["
              << _dof->getName() << "] (" << _dof << ") and its Joint were NOT "
@@ -671,36 +677,40 @@ bool Group::removeDof(DegreeOfFreedom* _dof, bool _cleanupJoint, bool _warning)
 }
 
 //==============================================================================
-bool Group::removeDofs(const std::vector<DegreeOfFreedom*>& _dofs,
-                       bool _cleanupJoint, bool _warning)
+bool Group::removeDofs(
+    const std::vector<DegreeOfFreedom*>& _dofs,
+    bool _cleanupJoint,
+    bool _warning)
 {
   bool removed = false;
-  for(DegreeOfFreedom* dof : _dofs)
+  for (DegreeOfFreedom* dof : _dofs)
     removed |= removeDof(dof, _cleanupJoint, _warning);
 
   return removed;
 }
 
 //==============================================================================
-Group::Group(const std::string& _name,
-             const std::vector<BodyNode*>& _bodyNodes,
-             bool _includeJoints, bool _includeDofs)
+Group::Group(
+    const std::string& _name,
+    const std::vector<BodyNode*>& _bodyNodes,
+    bool _includeJoints,
+    bool _includeDofs)
 {
   setName(_name);
   addBodyNodes(_bodyNodes);
 
-  if(_includeDofs || _includeJoints)
+  if (_includeDofs || _includeJoints)
   {
-    for(std::size_t i=0; i < _bodyNodes.size(); ++i)
+    for (std::size_t i = 0; i < _bodyNodes.size(); ++i)
     {
       Joint* joint = _bodyNodes[i]->getParentJoint();
 
-      if(_includeJoints)
+      if (_includeJoints)
         addJoint(joint, false);
 
-      if(_includeDofs)
+      if (_includeDofs)
       {
-        for(std::size_t j=0; j < joint->getNumDofs(); ++j)
+        for (std::size_t j = 0; j < joint->getNumDofs(); ++j)
           addDof(joint->getDof(j));
       }
     }
@@ -708,16 +718,18 @@ Group::Group(const std::string& _name,
 }
 
 //==============================================================================
-Group::Group(const std::string& _name,
-             const std::vector<DegreeOfFreedom*>& _dofs,
-             bool _includeBodyNodes, bool _includeJoints)
+Group::Group(
+    const std::string& _name,
+    const std::vector<DegreeOfFreedom*>& _dofs,
+    bool _includeBodyNodes,
+    bool _includeJoints)
 {
   setName(_name);
   addDofs(_dofs, _includeJoints);
 
-  if(_includeBodyNodes)
+  if (_includeBodyNodes)
   {
-    for(std::size_t i=0; i < _dofs.size(); ++i)
+    for (std::size_t i = 0; i < _dofs.size(); ++i)
     {
       DegreeOfFreedom* dof = _dofs[i];
       addBodyNode(dof->getChildBodyNode(), false);
@@ -726,20 +738,19 @@ Group::Group(const std::string& _name,
 }
 
 //==============================================================================
-Group::Group(const std::string& _name,
-             const MetaSkeletonPtr& _metaSkeleton)
+Group::Group(const std::string& _name, const MetaSkeletonPtr& _metaSkeleton)
 {
   setName(_name);
 
-  if(_metaSkeleton)
+  if (_metaSkeleton)
   {
-    for(std::size_t i=0; i < _metaSkeleton->getNumBodyNodes(); ++i)
+    for (std::size_t i = 0; i < _metaSkeleton->getNumBodyNodes(); ++i)
       addBodyNode(_metaSkeleton->getBodyNode(i));
 
-    for(std::size_t i=0; i < _metaSkeleton->getNumJoints(); ++i)
+    for (std::size_t i = 0; i < _metaSkeleton->getNumJoints(); ++i)
       addJoint(_metaSkeleton->getJoint(i), false);
 
-    for(std::size_t i=0; i < _metaSkeleton->getNumDofs(); ++i)
+    for (std::size_t i = 0; i < _metaSkeleton->getNumDofs(); ++i)
       addDof(_metaSkeleton->getDof(i), false);
   }
 }
