@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011-2019, The DART development contributors
+ * Copyright (c) 2011-2021, The DART development contributors
  * All rights reserved.
  *
  * The list of contributors can be found at:
@@ -35,16 +35,17 @@
 #include <string>
 
 #include "dart/common/Console.hpp"
-#include "dart/math/Helpers.hpp"
 #include "dart/dynamics/BodyNode.hpp"
 #include "dart/dynamics/DegreeOfFreedom.hpp"
 #include "dart/dynamics/Skeleton.hpp"
+#include "dart/math/Helpers.hpp"
 
 namespace dart {
 namespace dynamics {
 
 //==============================================================================
-const Joint::ActuatorType Joint::DefaultActuatorType = detail::DefaultActuatorType;
+const Joint::ActuatorType Joint::DefaultActuatorType
+    = detail::DefaultActuatorType;
 // These declarations are needed for linking to work
 constexpr Joint::ActuatorType Joint::FORCE;
 constexpr Joint::ActuatorType Joint::PASSIVE;
@@ -84,16 +85,14 @@ JointProperties::JointProperties(
 Joint::ExtendedProperties::ExtendedProperties(
     const Properties& standardProperties,
     const CompositeProperties& aspectProperties)
-  : Properties(standardProperties),
-    mCompositeProperties(aspectProperties)
+  : Properties(standardProperties), mCompositeProperties(aspectProperties)
 {
   // Do nothing
 }
 
 //==============================================================================
 Joint::ExtendedProperties::ExtendedProperties(
-    Properties&& standardProperties,
-    CompositeProperties&& aspectProperties)
+    Properties&& standardProperties, CompositeProperties&& aspectProperties)
   : Properties(std::move(standardProperties)),
     mCompositeProperties(std::move(aspectProperties))
 {
@@ -118,9 +117,12 @@ void Joint::setAspectProperties(const AspectProperties& properties)
   setName(properties.mName);
   setTransformFromParentBodyNode(properties.mT_ParentBodyToJoint);
   setTransformFromChildBodyNode(properties.mT_ChildBodyToJoint);
-  setPositionLimitEnforced(properties.mIsPositionLimitEnforced);
+  setLimitEnforcement(properties.mIsPositionLimitEnforced);
   setActuatorType(properties.mActuatorType);
-  setMimicJoint(properties.mMimicJoint, properties.mMimicMultiplier, properties.mMimicOffset);
+  setMimicJoint(
+      properties.mMimicJoint,
+      properties.mMimicMultiplier,
+      properties.mMimicOffset);
 }
 
 //==============================================================================
@@ -132,7 +134,7 @@ const Joint::Properties& Joint::getJointProperties() const
 //==============================================================================
 void Joint::copy(const Joint& _otherJoint)
 {
-  if(this == &_otherJoint)
+  if (this == &_otherJoint)
     return;
 
   setProperties(_otherJoint.getJointProperties());
@@ -141,7 +143,7 @@ void Joint::copy(const Joint& _otherJoint)
 //==============================================================================
 void Joint::copy(const Joint* _otherJoint)
 {
-  if(nullptr == _otherJoint)
+  if (nullptr == _otherJoint)
     return;
 
   copy(*_otherJoint);
@@ -164,8 +166,8 @@ const std::string& Joint::setName(const std::string& _name, bool _renameDofs)
     return mAspectProperties.mName;
   }
 
-  const SkeletonPtr& skel = mChildBodyNode?
-        mChildBodyNode->getSkeleton() : nullptr;
+  const SkeletonPtr& skel
+      = mChildBodyNode ? mChildBodyNode->getSkeleton() : nullptr;
   if (skel)
   {
     skel->mNameMgrForJoints.removeName(mAspectProperties.mName);
@@ -203,7 +205,8 @@ Joint::ActuatorType Joint::getActuatorType() const
 }
 
 //==============================================================================
-void Joint::setMimicJoint(const Joint* _mimicJoint, double _mimicMultiplier, double _mimicOffset)
+void Joint::setMimicJoint(
+    const Joint* _mimicJoint, double _mimicMultiplier, double _mimicOffset)
 {
   mAspectProperties.mMimicJoint = _mimicJoint;
   mAspectProperties.mMimicMultiplier = _mimicMultiplier;
@@ -242,8 +245,7 @@ bool Joint::isKinematic() const
     case VELOCITY:
     case LOCKED:
       return true;
-    default:
-    {
+    default: {
       dterr << "Unsupported actuator type." << std::endl;
       return false;
     }
@@ -286,13 +288,13 @@ const BodyNode* Joint::getParentBodyNode() const
 //==============================================================================
 SkeletonPtr Joint::getSkeleton()
 {
-  return mChildBodyNode? mChildBodyNode->getSkeleton() : nullptr;
+  return mChildBodyNode ? mChildBodyNode->getSkeleton() : nullptr;
 }
 
 //==============================================================================
 std::shared_ptr<const Skeleton> Joint::getSkeleton() const
 {
-  return mChildBodyNode? mChildBodyNode->getSkeleton() : nullptr;
+  return mChildBodyNode ? mChildBodyNode->getSkeleton() : nullptr;
 }
 
 //==============================================================================
@@ -340,7 +342,7 @@ const math::Jacobian Joint::getLocalJacobianTimeDeriv() const
 //==============================================================================
 const Eigen::Isometry3d& Joint::getRelativeTransform() const
 {
-  if(mNeedTransformUpdate)
+  if (mNeedTransformUpdate)
   {
     updateRelativeTransform();
     mNeedTransformUpdate = false;
@@ -352,7 +354,7 @@ const Eigen::Isometry3d& Joint::getRelativeTransform() const
 //==============================================================================
 const Eigen::Vector6d& Joint::getRelativeSpatialVelocity() const
 {
-  if(mNeedSpatialVelocityUpdate)
+  if (mNeedSpatialVelocityUpdate)
   {
     updateRelativeSpatialVelocity();
     mNeedSpatialVelocityUpdate = false;
@@ -364,7 +366,7 @@ const Eigen::Vector6d& Joint::getRelativeSpatialVelocity() const
 //==============================================================================
 const Eigen::Vector6d& Joint::getRelativeSpatialAcceleration() const
 {
-  if(mNeedSpatialAccelerationUpdate)
+  if (mNeedSpatialAccelerationUpdate)
   {
     updateRelativeSpatialAcceleration();
     mNeedSpatialAccelerationUpdate = false;
@@ -376,7 +378,7 @@ const Eigen::Vector6d& Joint::getRelativeSpatialAcceleration() const
 //==============================================================================
 const Eigen::Vector6d& Joint::getRelativePrimaryAcceleration() const
 {
-  if(mNeedPrimaryAccelerationUpdate)
+  if (mNeedPrimaryAccelerationUpdate)
   {
     updateRelativePrimaryAcceleration();
     mNeedPrimaryAccelerationUpdate = false;
@@ -386,13 +388,71 @@ const Eigen::Vector6d& Joint::getRelativePrimaryAcceleration() const
 }
 
 //==============================================================================
-void Joint::setPositionLimitEnforced(bool _isPositionLimitEnforced)
+Eigen::Vector6d Joint::getWrenchToChildBodyNode(
+    const Frame* withRespectTo) const
 {
-  mAspectProperties.mIsPositionLimitEnforced = _isPositionLimitEnforced;
+  const BodyNode* childBodyNode = getChildBodyNode();
+  if (!childBodyNode)
+  {
+    return Eigen::Vector6d::Zero();
+  }
+
+  const Eigen::Vector6d& F2 = childBodyNode->getBodyForce();
+  const BodyNode* parentBodyNode = getParentBodyNode();
+
+  if (withRespectTo == nullptr)
+  {
+    // (Default) Wrench applying to the child body node, where the reference
+    // frame is the joint frame
+    return math::dAdT(getTransformFromChildBodyNode(), -F2);
+  }
+  else if (withRespectTo == childBodyNode)
+  {
+    // Wrench applying to the child body node, where the reference frame is the
+    // child body frame
+    return -F2;
+  }
+  else if (withRespectTo == parentBodyNode)
+  {
+    // Wrench applying to the child body node, where the reference frame is the
+    // parent body frame
+    return math::dAdInvT(getRelativeTransform(), -F2);
+  }
+  else
+  {
+    // Wrench applying to the child body node, where the reference frame is an
+    // arbitrary frame
+    return math::dAdT(withRespectTo->getTransform(childBodyNode), -F2);
+  }
+}
+
+//==============================================================================
+Eigen::Vector6d Joint::getWrenchToParentBodyNode(
+    const Frame* withRespectTo) const
+{
+  return -getWrenchToChildBodyNode(withRespectTo);
+}
+
+//==============================================================================
+void Joint::setPositionLimitEnforced(bool enforced)
+{
+  setLimitEnforcement(enforced);
+}
+
+//==============================================================================
+void Joint::setLimitEnforcement(bool enforced)
+{
+  mAspectProperties.mIsPositionLimitEnforced = enforced;
 }
 
 //==============================================================================
 bool Joint::isPositionLimitEnforced() const
+{
+  return areLimitsEnforced();
+}
+
+//==============================================================================
+bool Joint::areLimitsEnforced() const
 {
   return mAspectProperties.mIsPositionLimitEnforced;
 }
@@ -419,12 +479,12 @@ std::size_t Joint::getTreeIndex() const
 bool Joint::checkSanity(bool _printWarnings) const
 {
   bool sane = true;
-  for(std::size_t i=0; i < getNumDofs(); ++i)
+  for (std::size_t i = 0; i < getNumDofs(); ++i)
   {
-    if(getInitialPosition(i) < getPositionLowerLimit(i)
-       || getPositionUpperLimit(i) < getInitialPosition(i))
+    if (getInitialPosition(i) < getPositionLowerLimit(i)
+        || getPositionUpperLimit(i) < getInitialPosition(i))
     {
-      if(_printWarnings)
+      if (_printWarnings)
       {
         dtwarn << "[Joint::checkSanity] Initial position of index " << i << " ["
                << getDofName(i) << "] in Joint [" << getName() << "] is "
@@ -441,10 +501,10 @@ bool Joint::checkSanity(bool _printWarnings) const
       sane = false;
     }
 
-    if(getInitialVelocity(i) < getVelocityLowerLimit(i)
-       || getVelocityUpperLimit(i) < getInitialVelocity(i))
+    if (getInitialVelocity(i) < getVelocityLowerLimit(i)
+        || getVelocityUpperLimit(i) < getInitialVelocity(i))
     {
-      if(_printWarnings)
+      if (_printWarnings)
       {
         dtwarn << "[Joint::checkSanity] Initial velocity of index " << i << " ["
                << getDofName(i) << "] is Joint [" << getName() << "] is "
@@ -566,7 +626,7 @@ void Joint::updateArticulatedInertia() const
 }
 
 //==============================================================================
-//Eigen::VectorXd Joint::getDampingForces() const
+// Eigen::VectorXd Joint::getDampingForces() const
 //{
 //  int numDofs = getNumDofs();
 //  Eigen::VectorXd dampingForce(numDofs);
@@ -578,7 +638,7 @@ void Joint::updateArticulatedInertia() const
 //}
 
 //==============================================================================
-//Eigen::VectorXd Joint::getSpringForces(double _timeStep) const
+// Eigen::VectorXd Joint::getSpringForces(double _timeStep) const
 //{
 //  int dof = getNumDofs();
 //  Eigen::VectorXd springForce(dof);
@@ -602,7 +662,7 @@ void Joint::notifyPositionUpdate()
 //==============================================================================
 void Joint::notifyPositionUpdated()
 {
-  if(mChildBodyNode)
+  if (mChildBodyNode)
   {
     mChildBodyNode->dirtyTransform();
     mChildBodyNode->dirtyJacobian();
@@ -618,7 +678,7 @@ void Joint::notifyPositionUpdated()
   mNeedSpatialAccelerationUpdate = true;
 
   SkeletonPtr skel = getSkeleton();
-  if(skel)
+  if (skel)
   {
     std::size_t tree = mChildBodyNode->mTreeIndex;
     skel->dirtyArticulatedInertia(tree);
@@ -636,7 +696,7 @@ void Joint::notifyVelocityUpdate()
 //==============================================================================
 void Joint::notifyVelocityUpdated()
 {
-  if(mChildBodyNode)
+  if (mChildBodyNode)
   {
     mChildBodyNode->dirtyVelocity();
     mChildBodyNode->dirtyJacobianDeriv();
@@ -657,12 +717,12 @@ void Joint::notifyAccelerationUpdate()
 //==============================================================================
 void Joint::notifyAccelerationUpdated()
 {
-  if(mChildBodyNode)
+  if (mChildBodyNode)
     mChildBodyNode->dirtyAcceleration();
 
   mNeedSpatialAccelerationUpdate = true;
   mNeedPrimaryAccelerationUpdate = true;
 }
 
-}  // namespace dynamics
-}  // namespace dart
+} // namespace dynamics
+} // namespace dart
