@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011-2019, The DART development contributors
+ * Copyright (c) 2011-2021, The DART development contributors
  * All rights reserved.
  *
  * The list of contributors can be found at:
@@ -30,10 +30,11 @@
  *   POSSIBILITY OF SUCH DAMAGE.
  */
 
+#include "dart/dynamics/Linkage.hpp"
+
 #include <algorithm>
 #include <unordered_set>
 
-#include "dart/dynamics/Linkage.hpp"
 #include "dart/dynamics/FreeJoint.hpp"
 
 namespace dart {
@@ -44,9 +45,9 @@ std::vector<BodyNode*> Linkage::Criteria::satisfy() const
 {
   std::vector<BodyNode*> bns;
 
-  if(nullptr == mStart.mNode.lock())
+  if (nullptr == mStart.mNode.lock())
   {
-    if(mTargets.size() == 0)
+    if (mTargets.size() == 0)
       return bns;
 
     refreshTerminalMap();
@@ -54,10 +55,10 @@ std::vector<BodyNode*> Linkage::Criteria::satisfy() const
     // If a start node is not given, then we must treat the root node of each
     // target as if it is a start node.
 
-    for(std::size_t i=0; i<mTargets.size(); ++i)
+    for (std::size_t i = 0; i < mTargets.size(); ++i)
     {
       const Target& target = mTargets[i];
-      if(nullptr == target.mNode.lock())
+      if (nullptr == target.mNode.lock())
         continue;
 
       BodyNode* target_bn = target.mNode.lock();
@@ -75,11 +76,11 @@ std::vector<BodyNode*> Linkage::Criteria::satisfy() const
   {
     refreshTerminalMap();
 
-    if(EXCLUDE != mStart.mPolicy)
+    if (EXCLUDE != mStart.mPolicy)
       bns.push_back(mStart.mNode.lock());
     expansionPolicy(mStart.mNode.lock(), mStart.mPolicy, bns);
 
-    for(std::size_t i=0; i<mTargets.size(); ++i)
+    for (std::size_t i = 0; i < mTargets.size(); ++i)
     {
       expandToTarget(mStart, mTargets[i], bns);
     }
@@ -90,12 +91,12 @@ std::vector<BodyNode*> Linkage::Criteria::satisfy() const
   final_bns.reserve(bns.size());
   std::unordered_set<BodyNode*> unique_bns;
   unique_bns.reserve(bns.size());
-  for(BodyNode* bn : bns)
+  for (BodyNode* bn : bns)
   {
-    if(nullptr == bn)
+    if (nullptr == bn)
       continue;
 
-    if( unique_bns.find(bn) != unique_bns.end() )
+    if (unique_bns.find(bn) != unique_bns.end())
       continue;
 
     final_bns.push_back(bn);
@@ -106,20 +107,16 @@ std::vector<BodyNode*> Linkage::Criteria::satisfy() const
 }
 
 //==============================================================================
-Linkage::Criteria::Target::Target(BodyNode* _target,
-                                  ExpansionPolicy _policy,
-                                  bool _chain)
-  : mNode(_target),
-    mPolicy(_policy),
-    mChain(_chain)
+Linkage::Criteria::Target::Target(
+    BodyNode* _target, ExpansionPolicy _policy, bool _chain)
+  : mNode(_target), mPolicy(_policy), mChain(_chain)
 {
   // Do nothing
 }
 
 //==============================================================================
 Linkage::Criteria::Terminal::Terminal(BodyNode* _terminal, bool _inclusive)
-  : mTerminal(_terminal),
-    mInclusive(_inclusive)
+  : mTerminal(_terminal), mInclusive(_inclusive)
 {
   // Do nothing
 }
@@ -138,14 +135,14 @@ Linkage::Criteria::Criteria(
 
   if (!includeUpstreamParentJoint)
   {
-    if(endPoint.mNode.lock() &&
-       endPoint.mNode.lock()->descendsFrom(mStart.mNode.lock()))
+    if (endPoint.mNode.lock()
+        && endPoint.mNode.lock()->descendsFrom(mStart.mNode.lock()))
     {
       mStart.mPolicy = Linkage::Criteria::EXCLUDE;
     }
 
-    if (mStart.mNode.lock() &&
-       mStart.mNode.lock()->descendsFrom(endPoint.mNode.lock()))
+    if (mStart.mNode.lock()
+        && mStart.mNode.lock()->descendsFrom(endPoint.mNode.lock()))
     {
       endPoint.mPolicy = Linkage::Criteria::EXCLUDE;
     }
@@ -158,7 +155,7 @@ Linkage::Criteria::Criteria(
 void Linkage::Criteria::refreshTerminalMap() const
 {
   mMapOfTerminals.clear();
-  for(std::size_t i=0; i<mTerminals.size(); ++i)
+  for (std::size_t i = 0; i < mTerminals.size(); ++i)
   {
     mMapOfTerminals[mTerminals[i].mTerminal.lock()] = mTerminals[i].mInclusive;
   }
@@ -170,23 +167,23 @@ void Linkage::Criteria::expansionPolicy(
     Linkage::Criteria::ExpansionPolicy _policy,
     std::vector<BodyNode*>& _bns) const
 {
-  if(EXCLUDE != _policy)
+  if (EXCLUDE != _policy)
   {
     // If the _start is a terminal, we quit before expanding
-    std::unordered_map<BodyNode*, bool>::const_iterator check_start =
-        mMapOfTerminals.find(_start);
-    if( check_start != mMapOfTerminals.end() )
+    std::unordered_map<BodyNode*, bool>::const_iterator check_start
+        = mMapOfTerminals.find(_start);
+    if (check_start != mMapOfTerminals.end())
     {
       bool inclusive = check_start->second;
-      if(inclusive)
+      if (inclusive)
         _bns.push_back(_start);
       return;
     }
   }
 
-  if(DOWNSTREAM == _policy)
+  if (DOWNSTREAM == _policy)
     expandDownstream(_start, _bns, EXCLUDE != _policy);
-  else if(UPSTREAM == _policy)
+  else if (UPSTREAM == _policy)
     expandUpstream(_start, _bns, EXCLUDE != _policy);
 }
 
@@ -194,27 +191,30 @@ void Linkage::Criteria::expansionPolicy(
 struct Recording
 {
   Recording(BodyNode* _node = nullptr, int _count = 0)
-    : mNode(_node), mCount(_count) { }
+    : mNode(_node), mCount(_count)
+  {
+  }
 
   BodyNode* mNode;
   int mCount;
 };
 
 //==============================================================================
-void stepToNextChild(std::vector<Recording>& _recorder,
-                     std::vector<BodyNode*>& _bns,
-                     Recording& _r,
-                     const std::unordered_map<BodyNode*, bool>& _terminalMap,
-                     int _initValue)
+void stepToNextChild(
+    std::vector<Recording>& _recorder,
+    std::vector<BodyNode*>& _bns,
+    Recording& _r,
+    const std::unordered_map<BodyNode*, bool>& _terminalMap,
+    int _initValue)
 {
   BodyNode* bn = _r.mNode->getChildBodyNode(_r.mCount);
-  std::unordered_map<BodyNode*, bool>::const_iterator it =
-      _terminalMap.find(bn);
+  std::unordered_map<BodyNode*, bool>::const_iterator it
+      = _terminalMap.find(bn);
 
-  if(it != _terminalMap.end())
+  if (it != _terminalMap.end())
   {
     bool inclusive = it->second;
-    if(inclusive)
+    if (inclusive)
       _bns.push_back(bn);
 
     ++_r.mCount;
@@ -226,19 +226,20 @@ void stepToNextChild(std::vector<Recording>& _recorder,
 }
 
 //==============================================================================
-void stepToParent(std::vector<Recording>& _recorder,
-                  std::vector<BodyNode*>& _bns,
-                  Recording& _r,
-                  const std::unordered_map<BodyNode*, bool>& _terminalMap)
+void stepToParent(
+    std::vector<Recording>& _recorder,
+    std::vector<BodyNode*>& _bns,
+    Recording& _r,
+    const std::unordered_map<BodyNode*, bool>& _terminalMap)
 {
   BodyNode* bn = _r.mNode->getParentBodyNode();
-  std::unordered_map<BodyNode*, bool>::const_iterator it =
-      _terminalMap.find(bn);
+  std::unordered_map<BodyNode*, bool>::const_iterator it
+      = _terminalMap.find(bn);
 
-  if(it != _terminalMap.end())
+  if (it != _terminalMap.end())
   {
     bool inclusive = it->second;
-    if(inclusive)
+    if (inclusive)
       _bns.push_back(bn);
 
     ++_r.mCount;
@@ -256,21 +257,21 @@ void Linkage::Criteria::expandDownstream(
   std::vector<Recording> recorder;
   recorder.reserve(_start->getSkeleton()->getNumBodyNodes());
 
-  if(_includeStart)
+  if (_includeStart)
     _bns.push_back(_start);
   recorder.push_back(Recording(_start, 0));
 
-  while(recorder.size() > 0)
+  while (recorder.size() > 0)
   {
     Recording& r = recorder.back();
-    if(r.mCount < static_cast<int>(r.mNode->getNumChildBodyNodes()))
+    if (r.mCount < static_cast<int>(r.mNode->getNumChildBodyNodes()))
     {
       stepToNextChild(recorder, _bns, r, mMapOfTerminals, 0);
     }
     else
     {
       recorder.pop_back();
-      if(recorder.size() > 0)
+      if (recorder.size() > 0)
         ++recorder.back().mCount;
     }
   }
@@ -283,25 +284,27 @@ void Linkage::Criteria::expandUpstream(
   std::vector<Recording> recorder;
   recorder.reserve(_start->getSkeleton()->getNumBodyNodes());
 
-  if(_includeStart)
+  if (_includeStart)
     _bns.push_back(_start);
   recorder.push_back(Recording(_start, -1));
 
-  while(recorder.size() > 0)
+  while (recorder.size() > 0)
   {
     Recording& r = recorder.back();
 
-    if(r.mCount == -1)
+    if (r.mCount == -1)
     {
       // -1 means we need to take a step upstream
 
-      if(r.mNode->getParentBodyNode() == nullptr)
+      if (r.mNode->getParentBodyNode() == nullptr)
       {
         // If the parent is a nullptr, we have reached the root
         ++r.mCount;
       }
-      else if(recorder.size() == 1 ||
-              r.mNode->getParentBodyNode() != recorder[recorder.size()-2].mNode)
+      else if (
+          recorder.size() == 1
+          || r.mNode->getParentBodyNode()
+                 != recorder[recorder.size() - 2].mNode)
       {
         // Go toward this node if we did not originally come from this node
         // or if we're at the first iteration
@@ -313,18 +316,19 @@ void Linkage::Criteria::expandUpstream(
         ++r.mCount;
       }
     }
-    else if(r.mCount < static_cast<int>(r.mNode->getNumChildBodyNodes()))
+    else if (r.mCount < static_cast<int>(r.mNode->getNumChildBodyNodes()))
     {
       // Greater than -1 means we need to add the children
 
-      if(recorder.size()==1)
+      if (recorder.size() == 1)
       {
         // If we've arrived back at the bottom of the queue, we're finished,
         // because we don't want to go downstream of the starting BodyNode
         break;
       }
-      else if( r.mNode->getChildBodyNode(r.mCount)
-               != recorder[recorder.size()-2].mNode)
+      else if (
+          r.mNode->getChildBodyNode(r.mCount)
+          != recorder[recorder.size() - 2].mNode)
       {
         // Go toward this node if we did not originally come from this node
         stepToNextChild(recorder, _bns, r, mMapOfTerminals, -1);
@@ -340,7 +344,7 @@ void Linkage::Criteria::expandUpstream(
       // If we've iterated through all the children of this node, pop it
       recorder.pop_back();
       // Move on to the next child
-      if(recorder.size() > 0)
+      if (recorder.size() > 0)
         ++recorder.back().mCount;
     }
   }
@@ -357,12 +361,12 @@ void Linkage::Criteria::expandToTarget(
   std::vector<BodyNode*> newBns;
   newBns.reserve(start_bn->getSkeleton()->getNumBodyNodes());
 
-  if(target_bn == nullptr || start_bn->descendsFrom(target_bn))
+  if (target_bn == nullptr || start_bn->descendsFrom(target_bn))
   {
     newBns = climbToTarget(start_bn, target_bn);
     trimBodyNodes(newBns, _target.mChain, true);
   }
-  else if(target_bn->descendsFrom(start_bn))
+  else if (target_bn->descendsFrom(start_bn))
   {
     newBns = climbToTarget(target_bn, start_bn);
     std::reverse(newBns.begin(), newBns.end());
@@ -374,21 +378,21 @@ void Linkage::Criteria::expandToTarget(
   }
 
   // Remove the start BodyNode if it's supposed to be excluded
-  if(EXCLUDE == _start.mPolicy &&
-     newBns.size() > 0 && newBns.front() == start_bn)
+  if (EXCLUDE == _start.mPolicy && newBns.size() > 0
+      && newBns.front() == start_bn)
   {
     newBns.erase(newBns.begin());
   }
 
   // Remove the target BodyNode if it's supposed to be excluded
-  if(EXCLUDE == _target.mPolicy &&
-     newBns.size() > 0 && newBns.back() == target_bn)
+  if (EXCLUDE == _target.mPolicy && newBns.size() > 0
+      && newBns.back() == target_bn)
   {
     newBns.pop_back();
   }
 
   // If we have successfully reached the target, expand from there
-  if(!newBns.empty() && newBns.back() == _target.mNode.lock())
+  if (!newBns.empty() && newBns.back() == _target.mNode.lock())
     expansionPolicy(_target.mNode.lock(), _target.mPolicy, newBns);
 
   _bns.insert(_bns.end(), newBns.begin(), newBns.end());
@@ -403,9 +407,10 @@ std::vector<BodyNode*> Linkage::Criteria::climbToTarget(
 
   BodyNode* bn = _start;
 
-  BodyNode* finalBn = nullptr==_target? nullptr : _target->getParentBodyNode();
+  BodyNode* finalBn
+      = nullptr == _target ? nullptr : _target->getParentBodyNode();
 
-  while( bn != finalBn && bn != nullptr )
+  while (bn != finalBn && bn != nullptr)
   {
     newBns.push_back(bn);
     bn = bn->getParentBodyNode();
@@ -416,15 +421,14 @@ std::vector<BodyNode*> Linkage::Criteria::climbToTarget(
 
 //==============================================================================
 std::vector<BodyNode*> Linkage::Criteria::climbToCommonRoot(
-    const Target& _start, const Target& _target,
-    bool _chain) const
+    const Target& _start, const Target& _target, bool _chain) const
 {
   BodyNode* start_bn = _start.mNode.lock();
   BodyNode* target_bn = _target.mNode.lock();
   BodyNode* root = start_bn->getParentBodyNode();
-  while(root != nullptr)
+  while (root != nullptr)
   {
-    if(target_bn->descendsFrom(root))
+    if (target_bn->descendsFrom(root))
       break;
 
     root = root->getParentBodyNode();
@@ -433,7 +437,7 @@ std::vector<BodyNode*> Linkage::Criteria::climbToCommonRoot(
   std::vector<BodyNode*> bnStart = climbToTarget(start_bn, root);
   trimBodyNodes(bnStart, _chain, true);
 
-  if(root != nullptr && bnStart.back() != root)
+  if (root != nullptr && bnStart.back() != root)
   {
     // We did not reach the common root, so we should stop here
     return bnStart;
@@ -452,19 +456,19 @@ std::vector<BodyNode*> Linkage::Criteria::climbToCommonRoot(
 }
 
 //==============================================================================
-void Linkage::Criteria::trimBodyNodes(std::vector<BodyNode *>& _bns,
-                                      bool _chain, bool _movingUpstream) const
+void Linkage::Criteria::trimBodyNodes(
+    std::vector<BodyNode*>& _bns, bool _chain, bool _movingUpstream) const
 {
   std::vector<BodyNode*>::iterator it = _bns.begin();
-  while( it != _bns.end() )
+  while (it != _bns.end())
   {
-    std::unordered_map<BodyNode*, bool>::const_iterator terminal =
-        mMapOfTerminals.find(*it);
+    std::unordered_map<BodyNode*, bool>::const_iterator terminal
+        = mMapOfTerminals.find(*it);
 
-    if( terminal != mMapOfTerminals.end() )
+    if (terminal != mMapOfTerminals.end())
     {
       bool inclusive = terminal->second;
-      if(inclusive)
+      if (inclusive)
         ++it;
 
       break;
@@ -472,13 +476,13 @@ void Linkage::Criteria::trimBodyNodes(std::vector<BodyNode *>& _bns,
 
     ++it;
 
-    if( it != _bns.end() && _chain)
+    if (it != _bns.end() && _chain)
     {
       // If this BodyNode has multiple children, cut off any BodyNodes that
       // follow it
-      if( (*it)->getNumChildBodyNodes() > 1 )
+      if ((*it)->getNumChildBodyNodes() > 1)
       {
-        if(_movingUpstream)
+        if (_movingUpstream)
         {
           break;
         }
@@ -489,9 +493,9 @@ void Linkage::Criteria::trimBodyNodes(std::vector<BodyNode *>& _bns,
         }
       }
 
-      if( dynamic_cast<FreeJoint*>( (*it)->getParentJoint() ) )
+      if (dynamic_cast<FreeJoint*>((*it)->getParentJoint()))
       {
-        if(_movingUpstream)
+        if (_movingUpstream)
         {
           ++it;
           break;
@@ -508,7 +512,7 @@ void Linkage::Criteria::trimBodyNodes(std::vector<BodyNode *>& _bns,
 }
 
 //==============================================================================
-LinkagePtr Linkage::create(const Criteria &_criteria, const std::string& _name)
+LinkagePtr Linkage::create(const Criteria& _criteria, const std::string& _name)
 {
   LinkagePtr linkage(new Linkage(_criteria, _name));
   linkage->mPtr = linkage;
@@ -517,8 +521,7 @@ LinkagePtr Linkage::create(const Criteria &_criteria, const std::string& _name)
 
 //==============================================================================
 Linkage::Criteria::Target createTargetFromClone(
-    Skeleton& skelClone,
-    const Linkage::Criteria::Target& target)
+    Skeleton& skelClone, const Linkage::Criteria::Target& target)
 {
   BodyNodePtr bodyNodePtr = target.mNode.lock();
   assert(bodyNodePtr);
@@ -532,8 +535,7 @@ Linkage::Criteria::Target createTargetFromClone(
 
 //==============================================================================
 Linkage::Criteria::Terminal createTerminalFromClone(
-    Skeleton& skelClone,
-    const Linkage::Criteria::Terminal& terminal)
+    Skeleton& skelClone, const Linkage::Criteria::Terminal& terminal)
 {
   BodyNodePtr bodyNodePtr = terminal.mTerminal.lock();
   assert(bodyNodePtr);
@@ -596,10 +598,10 @@ MetaSkeletonPtr Linkage::cloneMetaSkeleton(const std::string& cloneName) const
 //==============================================================================
 bool Linkage::isAssembled() const
 {
-  for(std::size_t i=0; i<mParentBodyNodes.size(); ++i)
+  for (std::size_t i = 0; i < mParentBodyNodes.size(); ++i)
   {
     const BodyNode* bn = mBodyNodes[i];
-    if(bn->getParentBodyNode() != mParentBodyNodes[i].lock())
+    if (bn->getParentBodyNode() != mParentBodyNodes[i].lock())
       return false;
   }
 
@@ -609,7 +611,7 @@ bool Linkage::isAssembled() const
 //==============================================================================
 void Linkage::reassemble()
 {
-  for(std::size_t i=0; i<mBodyNodes.size(); ++i)
+  for (std::size_t i = 0; i < mBodyNodes.size(); ++i)
   {
     BodyNode* bn = mBodyNodes[i];
     bn->moveTo(mParentBodyNodes[i].lock());
@@ -620,10 +622,10 @@ void Linkage::reassemble()
 void Linkage::satisfyCriteria()
 {
   std::vector<BodyNode*> bns = mCriteria.satisfy();
-  while(getNumBodyNodes() > 0)
+  while (getNumBodyNodes() > 0)
     unregisterComponent(mBodyNodes.back());
 
-  for(BodyNode* bn : bns)
+  for (BodyNode* bn : bns)
   {
     registerComponent(bn);
   }
@@ -644,7 +646,7 @@ void Linkage::update()
 {
   mParentBodyNodes.clear();
   mParentBodyNodes.reserve(mBodyNodes.size());
-  for(std::size_t i=0; i<mBodyNodes.size(); ++i)
+  for (std::size_t i = 0; i < mBodyNodes.size(); ++i)
   {
     mParentBodyNodes.push_back(mBodyNodes[i]->getParentBodyNode());
   }
