@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011-2019, The DART development contributors
+ * Copyright (c) 2011-2021, The DART development contributors
  * All rights reserved.
  *
  * The list of contributors can be found at:
@@ -33,9 +33,9 @@
 #include "dart/dynamics/ZeroDofJoint.hpp"
 
 #include "dart/common/Console.hpp"
-#include "dart/math/Helpers.hpp"
 #include "dart/dynamics/BodyNode.hpp"
 #include "dart/dynamics/Skeleton.hpp"
+#include "dart/math/Helpers.hpp"
 
 namespace dart {
 namespace dynamics {
@@ -78,7 +78,8 @@ const DegreeOfFreedom* ZeroDofJoint::getDof(std::size_t) const
 }
 
 //==============================================================================
-const std::string& ZeroDofJoint::setDofName(std::size_t, const std::string &, bool)
+const std::string& ZeroDofJoint::setDofName(
+    std::size_t, const std::string&, bool)
 {
   return emptyString;
 }
@@ -169,8 +170,7 @@ void ZeroDofJoint::setPosition(std::size_t, double)
 //==============================================================================
 double ZeroDofJoint::getPosition(std::size_t _index) const
 {
-  dterr << "getPosition index[" << _index << "] out of range"
-    << std::endl;
+  dterr << "getPosition index[" << _index << "] out of range" << std::endl;
 
   return 0.0;
 }
@@ -188,8 +188,8 @@ Eigen::VectorXd ZeroDofJoint::getPositions() const
 }
 
 //==============================================================================
-void ZeroDofJoint::setPositionLowerLimit(std::size_t /*_index*/,
-                                         double /*_position*/)
+void ZeroDofJoint::setPositionLowerLimit(
+    std::size_t /*_index*/, double /*_position*/)
 {
   // Do nothing
 }
@@ -214,8 +214,8 @@ Eigen::VectorXd ZeroDofJoint::getPositionLowerLimits() const
 }
 
 //==============================================================================
-void ZeroDofJoint::setPositionUpperLimit(std::size_t /*_index*/,
-                                         double /*_position*/)
+void ZeroDofJoint::setPositionUpperLimit(
+    std::size_t /*_index*/, double /*_position*/)
 {
   // Do nothing
 }
@@ -258,7 +258,8 @@ void ZeroDofJoint::resetPositions()
 }
 
 //==============================================================================
-void ZeroDofJoint::setInitialPosition(std::size_t /*_index*/, double /*_initial*/)
+void ZeroDofJoint::setInitialPosition(
+    std::size_t /*_index*/, double /*_initial*/)
 {
   // Do nothing
 }
@@ -306,8 +307,8 @@ Eigen::VectorXd ZeroDofJoint::getVelocities() const
 }
 
 //==============================================================================
-void ZeroDofJoint::setVelocityLowerLimit(std::size_t /*_index*/,
-                                         double /*_velocity*/)
+void ZeroDofJoint::setVelocityLowerLimit(
+    std::size_t /*_index*/, double /*_velocity*/)
 {
   // Do nothing
 }
@@ -319,7 +320,8 @@ double ZeroDofJoint::getVelocityLowerLimit(std::size_t /*_index*/) const
 }
 
 //==============================================================================
-void ZeroDofJoint::setVelocityLowerLimits(const Eigen::VectorXd& /*lowerLimits*/)
+void ZeroDofJoint::setVelocityLowerLimits(
+    const Eigen::VectorXd& /*lowerLimits*/)
 {
   // Do nothing
 }
@@ -331,8 +333,8 @@ Eigen::VectorXd ZeroDofJoint::getVelocityLowerLimits() const
 }
 
 //==============================================================================
-void ZeroDofJoint::setVelocityUpperLimit(std::size_t /*_index*/,
-                                         double /*_velocity*/)
+void ZeroDofJoint::setVelocityUpperLimit(
+    std::size_t /*_index*/, double /*_velocity*/)
 {
   // Do nothing
 }
@@ -344,7 +346,8 @@ double ZeroDofJoint::getVelocityUpperLimit(std::size_t /*_index*/) const
 }
 
 //==============================================================================
-void ZeroDofJoint::setVelocityUpperLimits(const Eigen::VectorXd& /*upperLimits*/)
+void ZeroDofJoint::setVelocityUpperLimits(
+    const Eigen::VectorXd& /*upperLimits*/)
 {
   // Do nothing
 }
@@ -368,7 +371,8 @@ void ZeroDofJoint::resetVelocities()
 }
 
 //==============================================================================
-void ZeroDofJoint::setInitialVelocity(std::size_t /*_index*/, double /*_initial*/)
+void ZeroDofJoint::setInitialVelocity(
+    std::size_t /*_index*/, double /*_initial*/)
 {
   // Do nothing
 }
@@ -392,7 +396,8 @@ Eigen::VectorXd ZeroDofJoint::getInitialVelocities() const
 }
 
 //==============================================================================
-void ZeroDofJoint::setAcceleration(std::size_t /*_index*/, double /*_acceleration*/)
+void ZeroDofJoint::setAcceleration(
+    std::size_t /*_index*/, double /*_acceleration*/)
 {
   // Do nothing
 }
@@ -422,8 +427,8 @@ void ZeroDofJoint::resetAccelerations()
 }
 
 //==============================================================================
-void ZeroDofJoint::setAccelerationLowerLimit(std::size_t /*_index*/,
-                                             double /*_acceleration*/)
+void ZeroDofJoint::setAccelerationLowerLimit(
+    std::size_t /*_index*/, double /*_acceleration*/)
 {
   // Do nothing
 }
@@ -435,7 +440,8 @@ double ZeroDofJoint::getAccelerationLowerLimit(std::size_t /*_index*/) const
 }
 
 //==============================================================================
-void ZeroDofJoint::setAccelerationLowerLimits(const Eigen::VectorXd& /*lowerLimits*/)
+void ZeroDofJoint::setAccelerationLowerLimits(
+    const Eigen::VectorXd& /*lowerLimits*/)
 {
   // Do nothing
 }
@@ -447,8 +453,8 @@ Eigen::VectorXd ZeroDofJoint::getAccelerationLowerLimits() const
 }
 
 //==============================================================================
-void ZeroDofJoint::setAccelerationUpperLimit(std::size_t /*_index*/,
-                                             double /*_acceleration*/)
+void ZeroDofJoint::setAccelerationUpperLimit(
+    std::size_t /*_index*/, double /*_acceleration*/)
 {
   // Do nothing
 }
@@ -460,7 +466,8 @@ double ZeroDofJoint::getAccelerationUpperLimit(std::size_t /*_index*/) const
 }
 
 //==============================================================================
-void ZeroDofJoint::setAccelerationUpperLimits(const Eigen::VectorXd& /*upperLimits*/)
+void ZeroDofJoint::setAccelerationUpperLimits(
+    const Eigen::VectorXd& /*upperLimits*/)
 {
   // Do nothing
 }
@@ -550,8 +557,8 @@ Eigen::VectorXd ZeroDofJoint::getForceUpperLimits() const
 }
 
 //==============================================================================
-void ZeroDofJoint::setVelocityChange(std::size_t /*_index*/,
-                                     double /*_velocityChange*/)
+void ZeroDofJoint::setVelocityChange(
+    std::size_t /*_index*/, double /*_velocityChange*/)
 {
   // Do nothing
 }
@@ -569,7 +576,8 @@ void ZeroDofJoint::resetVelocityChanges()
 }
 
 //==============================================================================
-void ZeroDofJoint::setConstraintImpulse(std::size_t /*_index*/, double /*_impulse*/)
+void ZeroDofJoint::setConstraintImpulse(
+    std::size_t /*_index*/, double /*_impulse*/)
 {
   // Do nothing
 }
@@ -600,8 +608,7 @@ void ZeroDofJoint::integrateVelocities(double /*_dt*/)
 
 //==============================================================================
 Eigen::VectorXd ZeroDofJoint::getPositionDifferences(
-    const Eigen::VectorXd& /*_q2*/,
-    const Eigen::VectorXd& /*_q1*/) const
+    const Eigen::VectorXd& /*_q2*/, const Eigen::VectorXd& /*_q1*/) const
 {
   return Eigen::VectorXd::Zero(0);
 }
@@ -643,7 +650,8 @@ double ZeroDofJoint::getDampingCoefficient(std::size_t /*_index*/) const
 }
 
 //==============================================================================
-void ZeroDofJoint::setCoulombFriction(std::size_t /*_index*/, double /*_friction*/)
+void ZeroDofJoint::setCoulombFriction(
+    std::size_t /*_index*/, double /*_friction*/)
 {
   // Do nothing
 }
@@ -732,13 +740,12 @@ void ZeroDofJoint::addAccelerationTo(Eigen::Vector6d& /*_acc*/)
 
 //==============================================================================
 void ZeroDofJoint::addChildArtInertiaTo(
-    Eigen::Matrix6d& _parentArtInertia,
-    const Eigen::Matrix6d& _childArtInertia)
+    Eigen::Matrix6d& _parentArtInertia, const Eigen::Matrix6d& _childArtInertia)
 {
   // Add child body's articulated inertia to parent body's articulated inertia.
   // Note that mT should be updated.
-  _parentArtInertia += math::transformInertia(getRelativeTransform().inverse(),
-                                              _childArtInertia);
+  _parentArtInertia += math::transformInertia(
+      getRelativeTransform().inverse(), _childArtInertia);
 }
 
 //==============================================================================
@@ -747,8 +754,8 @@ void ZeroDofJoint::addChildArtInertiaImplicitTo(
 {
   // Add child body's articulated inertia to parent body's articulated inertia.
   // Note that mT should be updated.
-  _parentArtInertia += math::transformInertia(getRelativeTransform().inverse(),
-                                              _childArtInertia);
+  _parentArtInertia += math::transformInertia(
+      getRelativeTransform().inverse(), _childArtInertia);
 }
 
 //==============================================================================
@@ -760,8 +767,7 @@ void ZeroDofJoint::updateInvProjArtInertia(
 
 //==============================================================================
 void ZeroDofJoint::updateInvProjArtInertiaImplicit(
-    const Eigen::Matrix6d& /*_artInertia*/,
-    double /*_timeStep*/)
+    const Eigen::Matrix6d& /*_artInertia*/, double /*_timeStep*/)
 {
   // Do nothing
 }
@@ -775,8 +781,9 @@ void ZeroDofJoint::addChildBiasForceTo(
 {
   // Add child body's bias force to parent body's bias force. Note that mT
   // should be updated.
-  _parentBiasForce += math::dAdInvT(getRelativeTransform(), _childBiasForce
-                                    + _childArtInertia*_childPartialAcc);
+  _parentBiasForce += math::dAdInvT(
+      getRelativeTransform(),
+      _childBiasForce + _childArtInertia * _childPartialAcc);
 }
 
 //==============================================================================
@@ -787,12 +794,13 @@ void ZeroDofJoint::addChildBiasImpulseTo(
 {
   // Add child body's bias force to parent body's bias impulse. Note that mT
   // should be updated.
-  _parentBiasImpulse += math::dAdInvT(getRelativeTransform(), _childBiasImpulse);
+  _parentBiasImpulse
+      += math::dAdInvT(getRelativeTransform(), _childBiasImpulse);
 }
 
 //==============================================================================
-void ZeroDofJoint::updateTotalForce(const Eigen::Vector6d& /*_bodyForce*/,
-                                    double /*_timeStep*/)
+void ZeroDofJoint::updateTotalForce(
+    const Eigen::Vector6d& /*_bodyForce*/, double /*_timeStep*/)
 {
   // Do nothing
 }
@@ -810,8 +818,9 @@ void ZeroDofJoint::resetTotalImpulses()
 }
 
 //==============================================================================
-void ZeroDofJoint::updateAcceleration(const Eigen::Matrix6d& /*_artInertia*/,
-                                      const Eigen::Vector6d& /*_spatialAcc*/)
+void ZeroDofJoint::updateAcceleration(
+    const Eigen::Matrix6d& /*_artInertia*/,
+    const Eigen::Vector6d& /*_spatialAcc*/)
 {
   // Do nothing
 }
@@ -825,19 +834,21 @@ void ZeroDofJoint::updateVelocityChange(
 }
 
 //==============================================================================
-void ZeroDofJoint::updateForceID(const Eigen::Vector6d& /*_bodyForce*/,
-                                 double /*_timeStep*/,
-                                 bool /*_withDampingForces*/,
-                                 bool /*_withSpringForces*/)
+void ZeroDofJoint::updateForceID(
+    const Eigen::Vector6d& /*_bodyForce*/,
+    double /*_timeStep*/,
+    bool /*_withDampingForces*/,
+    bool /*_withSpringForces*/)
 {
   // Do nothing
 }
 
 //==============================================================================
-void ZeroDofJoint::updateForceFD(const Eigen::Vector6d& /*_bodyForce*/,
-                                 double /*_timeStep*/,
-                                 bool /*_withDampingForces*/,
-                                 bool /*_withSpringForces*/)
+void ZeroDofJoint::updateForceFD(
+    const Eigen::Vector6d& /*_bodyForce*/,
+    double /*_timeStep*/,
+    bool /*_withDampingForces*/,
+    bool /*_withSpringForces*/)
 {
   // Do nothing
 }
@@ -919,5 +930,5 @@ Eigen::VectorXd ZeroDofJoint::getSpatialToGeneralized(
   return Eigen::VectorXd::Zero(0);
 }
 
-}  // namespace dynamics
-}  // namespace dart
+} // namespace dynamics
+} // namespace dart
