@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011-2019, The DART development contributors
+ * Copyright (c) 2011-2021, The DART development contributors
  * All rights reserved.
  *
  * The list of contributors can be found at:
@@ -31,18 +31,16 @@
  */
 
 #include "dart/gui/osg/DragAndDrop.hpp"
+
+#include "dart/dynamics/BodyNode.hpp"
+#include "dart/dynamics/DegreeOfFreedom.hpp"
+#include "dart/dynamics/Joint.hpp"
+#include "dart/dynamics/MeshShape.hpp"
+#include "dart/dynamics/SimpleFrame.hpp"
 #include "dart/gui/osg/DefaultEventHandler.hpp"
-#include "dart/gui/osg/Viewer.hpp"
 #include "dart/gui/osg/InteractiveFrame.hpp"
 #include "dart/gui/osg/MouseEventHandler.hpp"
-
-#include "dart/dynamics/SimpleFrame.hpp"
-#include "dart/dynamics/MeshShape.hpp"
-#include "dart/dynamics/BodyNode.hpp"
-#include "dart/dynamics/Joint.hpp"
-#include "dart/dynamics/DegreeOfFreedom.hpp"
-#include "dart/dynamics/MeshShape.hpp"
-
+#include "dart/gui/osg/Viewer.hpp"
 #include "dart/math/Helpers.hpp"
 
 namespace dart {
@@ -78,15 +76,15 @@ dart::dynamics::Entity* DragAndDrop::getEntity() const
 //==============================================================================
 void DragAndDrop::update()
 {
-  if(nullptr == mEntity)
+  if (nullptr == mEntity)
     return;
 
-  osg::MouseButtonEvent event =
-      mViewer->getDefaultEventHandler()->getButtonEvent(LEFT_MOUSE);
+  osg::MouseButtonEvent event
+      = mViewer->getDefaultEventHandler()->getButtonEvent(LEFT_MOUSE);
 
-  if(mAmMoving)
+  if (mAmMoving)
   {
-    if(osg::BUTTON_RELEASE == event)
+    if (osg::BUTTON_RELEASE == event)
     {
       mAmMoving = false;
       release();
@@ -96,15 +94,15 @@ void DragAndDrop::update()
   }
   else // not moving
   {
-    if(osg::BUTTON_PUSH == event)
+    if (osg::BUTTON_PUSH == event)
     {
-      const std::vector<osg::PickInfo>& picks =
-          mViewer->getDefaultEventHandler()->getButtonPicks(
-            osg::LEFT_MOUSE, osg::BUTTON_PUSH);
+      const std::vector<osg::PickInfo>& picks
+          = mViewer->getDefaultEventHandler()->getButtonPicks(
+              osg::LEFT_MOUSE, osg::BUTTON_PUSH);
 
-      for(const osg::PickInfo& pick : picks)
+      for (const osg::PickInfo& pick : picks)
       {
-        if(pick.frame == mEntity)
+        if (pick.frame == mEntity)
         {
           mAmMoving = true;
           mPickedPosition = pick.position;
@@ -115,7 +113,7 @@ void DragAndDrop::update()
         // The picks are always ordered from closest to furthest. If the closest
         // pick is not our Entity, then something is blocking the way, so if we
         // are obstructable, then we should quit.
-        if(mAmObstructable)
+        if (mAmObstructable)
           return;
       }
     }
@@ -144,7 +142,7 @@ void DragAndDrop::release()
 Eigen::Vector3d DragAndDrop::getConstrainedDx() const
 {
   return mViewer->getDefaultEventHandler()->getDeltaCursor(
-        mPickedPosition, mConstraintType, mVector);
+      mPickedPosition, mConstraintType, mVector);
 }
 
 //==============================================================================
@@ -153,10 +151,10 @@ Eigen::AngleAxisd DragAndDrop::getConstrainedRotation() const
   Eigen::Vector3d v1 = mPickedPosition - mPivot;
   Eigen::Vector3d v2;
 
-  if(LINE_CONSTRAINT == mConstraintType || PLANE_CONSTRAINT == mConstraintType)
+  if (LINE_CONSTRAINT == mConstraintType || PLANE_CONSTRAINT == mConstraintType)
   {
     v2 = mViewer->getDefaultEventHandler()->getDeltaCursor(
-          mPickedPosition, PLANE_CONSTRAINT, mVector)
+             mPickedPosition, PLANE_CONSTRAINT, mVector)
          + mPickedPosition - mPivot;
   }
   else
@@ -165,19 +163,19 @@ Eigen::AngleAxisd DragAndDrop::getConstrainedRotation() const
          + mPickedPosition - mPivot;
   }
 
-  if(v1.norm() == 0 || v2.norm() == 0 || v1.cross(v2).norm() == 0)
-    return Eigen::AngleAxisd(0, Eigen::Vector3d(1,0,0));
+  if (v1.norm() == 0 || v2.norm() == 0 || v1.cross(v2).norm() == 0)
+    return Eigen::AngleAxisd(0, Eigen::Vector3d(1, 0, 0));
 
   v1.normalize();
   v2.normalize();
 
   Eigen::Vector3d axis = v1.cross(v2);
-  if(LINE_CONSTRAINT == mConstraintType || PLANE_CONSTRAINT == mConstraintType)
+  if (LINE_CONSTRAINT == mConstraintType || PLANE_CONSTRAINT == mConstraintType)
   {
-    if(axis.dot(mVector) == 0)
-      return Eigen::AngleAxisd(0, Eigen::Vector3d(1,0,0));
+    if (axis.dot(mVector) == 0)
+      return Eigen::AngleAxisd(0, Eigen::Vector3d(1, 0, 0));
 
-    axis = axis.dot(mVector)*mVector;
+    axis = axis.dot(mVector) * mVector;
   }
 
   axis.normalize();
@@ -240,18 +238,17 @@ void DragAndDrop::setRotationModKey(
 void DragAndDrop::handleDestructionNotification(
     const dart::common::Subject* subscription)
 {
-  if(mEntity == subscription)
+  if (mEntity == subscription)
     mViewer->disableDragAndDrop(this);
 
-  if(mViewer == subscription)
+  if (mViewer == subscription)
     delete this;
 }
 
 //==============================================================================
-SimpleFrameDnD::SimpleFrameDnD(Viewer* viewer,
-                               dart::dynamics::SimpleFrame* frame)
-  : DragAndDrop(viewer, frame),
-    mFrame(frame)
+SimpleFrameDnD::SimpleFrameDnD(
+    Viewer* viewer, dart::dynamics::SimpleFrame* frame)
+  : DragAndDrop(viewer, frame), mFrame(frame)
 {
   // Do nothing
 }
@@ -267,11 +264,11 @@ void SimpleFrameDnD::move()
 {
   Eigen::Isometry3d tf(Eigen::Isometry3d::Identity());
 
-  bool modkey_down = (mViewer->getDefaultEventHandler()->getModKeyMask()
-                      & mRotationModKey);
+  bool modkey_down
+      = (mViewer->getDefaultEventHandler()->getModKeyMask() & mRotationModKey);
 
-  if(  ((RotationOption::HOLD_MODKEY==mRotationOption) && modkey_down)
-      || RotationOption::ALWAYS_ON==mRotationOption )
+  if (((RotationOption::HOLD_MODKEY == mRotationOption) && modkey_down)
+      || RotationOption::ALWAYS_ON == mRotationOption)
   {
     // Rotate
 
@@ -291,10 +288,10 @@ void SimpleFrameDnD::move()
   }
 
   dart::dynamics::Frame* parent = mFrame->getParentFrame();
-  if(parent->isWorld())
+  if (parent->isWorld())
     mFrame->setRelativeTransform(tf);
   else
-    mFrame->setRelativeTransform( parent->getWorldTransform().inverse()*tf );
+    mFrame->setRelativeTransform(parent->getWorldTransform().inverse() * tf);
 }
 
 //==============================================================================
@@ -309,8 +306,7 @@ SimpleFrameShapeDnD::SimpleFrameShapeDnD(
     Viewer* viewer,
     dart::dynamics::SimpleFrame* frame,
     dart::dynamics::Shape* shape)
-  : SimpleFrameDnD(viewer, frame),
-    mShape(shape)
+  : SimpleFrameDnD(viewer, frame), mShape(shape)
 {
   // Do nothing
 }
@@ -327,30 +323,30 @@ void SimpleFrameShapeDnD::update()
   // This is almost identical to the original DragAndDrop::update() except that
   // it also checks that the picked shape matches
 
-  if(nullptr == mFrame || nullptr == mShape)
+  if (nullptr == mFrame || nullptr == mShape)
     return;
 
-  osg::MouseButtonEvent event =
-      mViewer->getDefaultEventHandler()->getButtonEvent(LEFT_MOUSE);
+  osg::MouseButtonEvent event
+      = mViewer->getDefaultEventHandler()->getButtonEvent(LEFT_MOUSE);
 
-  if(mAmMoving)
+  if (mAmMoving)
   {
-    if(osg::BUTTON_RELEASE == event)
+    if (osg::BUTTON_RELEASE == event)
       mAmMoving = false;
 
     move();
   }
   else
   {
-    if(osg::BUTTON_PUSH == event)
+    if (osg::BUTTON_PUSH == event)
     {
-      const std::vector<osg::PickInfo>& picks =
-          mViewer->getDefaultEventHandler()->getButtonPicks(
-            osg::LEFT_MOUSE, osg::BUTTON_PUSH);
+      const std::vector<osg::PickInfo>& picks
+          = mViewer->getDefaultEventHandler()->getButtonPicks(
+              osg::LEFT_MOUSE, osg::BUTTON_PUSH);
 
-      for(const osg::PickInfo& pick : picks)
+      for (const osg::PickInfo& pick : picks)
       {
-        if(pick.frame == mFrame && pick.shape.get() == mShape)
+        if (pick.frame == mFrame && pick.shape.get() == mShape)
         {
           mAmMoving = true;
           mPickedPosition = pick.position;
@@ -358,7 +354,7 @@ void SimpleFrameShapeDnD::update()
           return;
         }
 
-        if(mAmObstructable)
+        if (mAmObstructable)
           return;
       }
     }
@@ -371,7 +367,7 @@ void SimpleFrameShapeDnD::handleDestructionNotification(
 {
   DragAndDrop::handleDestructionNotification(subscription);
 
-  if(mShape == subscription)
+  if (mShape == subscription)
     mViewer->disableDragAndDrop(this);
 }
 
@@ -379,44 +375,43 @@ void SimpleFrameShapeDnD::handleDestructionNotification(
 class InteractiveFrameMouseEvent : public MouseEventHandler
 {
 public:
-
-  InteractiveFrameMouseEvent(InteractiveFrame* frame) :
-    mFrame(frame), mHighlighting(false)
+  InteractiveFrameMouseEvent(InteractiveFrame* frame)
+    : mFrame(frame), mHighlighting(false)
   {
     addSubject(mFrame);
   }
 
   void update() override
   {
-    if(!mFrame)
+    if (!mFrame)
       return;
 
-    if(!mEventHandler)
+    if (!mEventHandler)
       return;
 
-    if(mHighlighting)
+    if (mHighlighting)
     {
       MouseButtonEvent event = mEventHandler->getButtonEvent(LEFT_MOUSE);
       bool stop_highlighting = false;
 
-      if(BUTTON_RELEASE == event || BUTTON_NOTHING == event)
+      if (BUTTON_RELEASE == event || BUTTON_NOTHING == event)
       {
         const std::vector<PickInfo>& picks = mEventHandler->getMovePicks();
-        if(picks.size() > 0)
+        if (picks.size() > 0)
         {
           const PickInfo& pick = picks[0];
-          if(pick.frame->getParentFrame() != mFrame->getTool(
-               (InteractiveTool::Type)mTool, mCoordinate))
+          if (pick.frame->getParentFrame()
+              != mFrame->getTool((InteractiveTool::Type)mTool, mCoordinate))
             stop_highlighting = true;
         }
         else
           stop_highlighting = true;
       }
 
-      if(stop_highlighting)
+      if (stop_highlighting)
       {
-        for(std::size_t s=0; s < InteractiveTool::NUM_TYPES; ++s)
-          for(std::size_t c=0; c<3; ++c)
+        for (std::size_t s = 0; s < InteractiveTool::NUM_TYPES; ++s)
+          for (std::size_t c = 0; c < 3; ++c)
             mFrame->getTool((InteractiveTool::Type)s, c)->resetAlpha();
         mHighlighting = false;
       }
@@ -425,21 +420,21 @@ public:
     {
       MouseButtonEvent event = mEventHandler->getButtonEvent(LEFT_MOUSE);
 
-      if(BUTTON_NOTHING != event && BUTTON_RELEASE != event)
+      if (BUTTON_NOTHING != event && BUTTON_RELEASE != event)
         return;
 
       const std::vector<PickInfo> picks = mEventHandler->getMovePicks();
-      if(picks.size() == 0)
+      if (picks.size() == 0)
         return;
 
       const PickInfo& pick = picks[0];
 
-      for(std::size_t s=0; s < (std::size_t)InteractiveTool::NUM_TYPES; ++s)
+      for (std::size_t s = 0; s < (std::size_t)InteractiveTool::NUM_TYPES; ++s)
       {
-        for(std::size_t c=0; c<3; ++c)
+        for (std::size_t c = 0; c < 3; ++c)
         {
-          if(mFrame->getTool((InteractiveTool::Type)s, c) ==
-             pick.frame->getParentFrame())
+          if (mFrame->getTool((InteractiveTool::Type)s, c)
+              == pick.frame->getParentFrame())
           {
             mHighlighting = true;
             mTool = s;
@@ -447,17 +442,17 @@ public:
             break;
           }
         }
-        if(mHighlighting)
+        if (mHighlighting)
           break;
       }
 
-      if(mHighlighting)
+      if (mHighlighting)
       {
-        for(std::size_t s=0; s < InteractiveTool::NUM_TYPES; ++s)
+        for (std::size_t s = 0; s < InteractiveTool::NUM_TYPES; ++s)
         {
-          for(std::size_t c=0; c<3; ++c)
+          for (std::size_t c = 0; c < 3; ++c)
           {
-            if(s == (std::size_t)mTool && c == mCoordinate)
+            if (s == (std::size_t)mTool && c == mCoordinate)
               mFrame->getTool((InteractiveTool::Type)s, c)->setAlpha(1.0);
             else
               mFrame->getTool((InteractiveTool::Type)s, c)->setAlpha(0.3);
@@ -468,10 +463,9 @@ public:
   }
 
 protected:
-
   void handleDestructionNotification(const Subject* _subject) override
   {
-    if(_subject == mFrame)
+    if (_subject == mFrame)
     {
       delete this;
       return;
@@ -491,9 +485,8 @@ protected:
 class InteractiveToolDnD : public SimpleFrameDnD
 {
 public:
-
-  InteractiveToolDnD(Viewer* viewer, InteractiveFrame* frame,
-                     InteractiveTool* tool)
+  InteractiveToolDnD(
+      Viewer* viewer, InteractiveFrame* frame, InteractiveTool* tool)
     : SimpleFrameDnD(viewer, frame)
   {
     addSubject(tool);
@@ -502,15 +495,15 @@ public:
 
   void update() override
   {
-    if(nullptr == mEntity)
+    if (nullptr == mEntity)
       return;
 
-    osg::MouseButtonEvent event =
-        mViewer->getDefaultEventHandler()->getButtonEvent(LEFT_MOUSE);
+    osg::MouseButtonEvent event
+        = mViewer->getDefaultEventHandler()->getButtonEvent(LEFT_MOUSE);
 
-    if(mAmMoving)
+    if (mAmMoving)
     {
-      if(osg::BUTTON_RELEASE == event)
+      if (osg::BUTTON_RELEASE == event)
       {
         mAmMoving = false;
         release();
@@ -520,15 +513,15 @@ public:
     }
     else // not moving
     {
-      if(osg::BUTTON_PUSH == event)
+      if (osg::BUTTON_PUSH == event)
       {
-        const std::vector<osg::PickInfo>& picks =
-            mViewer->getDefaultEventHandler()->getButtonPicks(
-              osg::LEFT_MOUSE, osg::BUTTON_PUSH);
+        const std::vector<osg::PickInfo>& picks
+            = mViewer->getDefaultEventHandler()->getButtonPicks(
+                osg::LEFT_MOUSE, osg::BUTTON_PUSH);
 
-        for(const osg::PickInfo& pick : picks)
+        for (const osg::PickInfo& pick : picks)
         {
-          if(pick.frame->getParentFrame() == mEntity)
+          if (pick.frame->getParentFrame() == mEntity)
           {
             mAmMoving = true;
             mPickedPosition = pick.position;
@@ -536,10 +529,10 @@ public:
             return;
           }
 
-          // The picks are always ordered from closest to furthest. If the closest
-          // pick is not our Entity, then something is blocking the way, so if we
-          // are obstructable, then we should quit.
-          if(mAmObstructable)
+          // The picks are always ordered from closest to furthest. If the
+          // closest pick is not our Entity, then something is blocking the way,
+          // so if we are obstructable, then we should quit.
+          if (mAmObstructable)
             return;
         }
       }
@@ -549,33 +542,31 @@ public:
   virtual ~InteractiveToolDnD() = default;
 
 protected:
-
   dart::sub_ptr<InteractiveTool> mTool;
 };
 
 //==============================================================================
-InteractiveFrameDnD::InteractiveFrameDnD(Viewer* viewer,
-                                         InteractiveFrame* frame)
-  : DragAndDrop(viewer, frame),
-    mInteractiveFrame(frame)
+InteractiveFrameDnD::InteractiveFrameDnD(
+    Viewer* viewer, InteractiveFrame* frame)
+  : DragAndDrop(viewer, frame), mInteractiveFrame(frame)
 {
   mViewer->getDefaultEventHandler()->addMouseEventHandler(
-        new InteractiveFrameMouseEvent(frame));
+      new InteractiveFrameMouseEvent(frame));
 
-  for(std::size_t i=0; i<InteractiveTool::NUM_TYPES; ++i)
-    for(std::size_t j=0; j<3; ++j)
-      mDnDs.push_back(new InteractiveToolDnD(viewer, frame,
-                            frame->getTool((InteractiveTool::Type)i, j)));
+  for (std::size_t i = 0; i < InteractiveTool::NUM_TYPES; ++i)
+    for (std::size_t j = 0; j < 3; ++j)
+      mDnDs.push_back(new InteractiveToolDnD(
+          viewer, frame, frame->getTool((InteractiveTool::Type)i, j)));
 
-  for(std::size_t i=0; i<3; ++i)
+  for (std::size_t i = 0; i < 3; ++i)
   {
     DragAndDrop* dnd = mDnDs[i];
     dnd->setRotationOption(SimpleFrameDnD::RotationOption::ALWAYS_OFF);
 
-    dnd = mDnDs[i+3];
+    dnd = mDnDs[i + 3];
     dnd->setRotationOption(SimpleFrameDnD::RotationOption::ALWAYS_ON);
 
-    dnd = mDnDs[i+6];
+    dnd = mDnDs[i + 6];
     dnd->setRotationOption(SimpleFrameDnD::RotationOption::ALWAYS_OFF);
   }
 }
@@ -589,43 +580,43 @@ InteractiveFrame* InteractiveFrameDnD::getFrame() const
 //==============================================================================
 void InteractiveFrameDnD::update()
 {
-  if(!mAmMoving)
+  if (!mAmMoving)
   {
-    for(std::size_t i=0; i<3; ++i)
+    for (std::size_t i = 0; i < 3; ++i)
     {
       DragAndDrop* dnd = mDnDs[i];
       Eigen::Matrix3d R = mInteractiveFrame->getWorldTransform().linear();
       dnd->constrainToLine(R.col(i));
 
-      dnd = mDnDs[i+3];
+      dnd = mDnDs[i + 3];
       dnd->constrainToLine(R.col(i));
 
-      dnd = mDnDs[i+6];
+      dnd = mDnDs[i + 6];
       dnd->constrainToPlane(R.col(i));
     }
   }
 
   mAmMoving = false;
-  for(std::size_t i=0; i<mDnDs.size(); ++i)
+  for (std::size_t i = 0; i < mDnDs.size(); ++i)
   {
     DragAndDrop* dnd = mDnDs[i];
     dnd->update();
     mAmMoving |= dnd->isMoving();
   }
 
-  if(mAmMoving)
+  if (mAmMoving)
   {
-    for(std::size_t i=0; i<InteractiveTool::NUM_TYPES; ++i)
+    for (std::size_t i = 0; i < InteractiveTool::NUM_TYPES; ++i)
     {
-      for(std::size_t j=0; j<3; ++j)
+      for (std::size_t j = 0; j < 3; ++j)
       {
-        DragAndDrop* dnd = mDnDs[3*i+j];
-        InteractiveTool* tool =
-            mInteractiveFrame->getTool((InteractiveTool::Type)i,j);
-        if(!dnd->isMoving() && tool->getEnabled())
+        DragAndDrop* dnd = mDnDs[3 * i + j];
+        InteractiveTool* tool
+            = mInteractiveFrame->getTool((InteractiveTool::Type)i, j);
+        if (!dnd->isMoving() && tool->getEnabled())
         {
           const auto shapeFrames = tool->getShapeFrames();
-          for(std::size_t s=0; s<shapeFrames.size(); ++s)
+          for (std::size_t s = 0; s < shapeFrames.size(); ++s)
             shapeFrames[s]->getVisualAspect(true)->setHidden(true);
         }
       }
@@ -633,16 +624,16 @@ void InteractiveFrameDnD::update()
   }
   else
   {
-    for(std::size_t i=0; i<InteractiveTool::NUM_TYPES; ++i)
+    for (std::size_t i = 0; i < InteractiveTool::NUM_TYPES; ++i)
     {
-      for(std::size_t j=0; j<3; ++j)
+      for (std::size_t j = 0; j < 3; ++j)
       {
-        InteractiveTool* tool =
-            mInteractiveFrame->getTool((InteractiveTool::Type)i,j);
-        if(tool->getEnabled())
+        InteractiveTool* tool
+            = mInteractiveFrame->getTool((InteractiveTool::Type)i, j);
+        if (tool->getEnabled())
         {
           const auto shapeFrames = tool->getShapeFrames();
-          for(std::size_t s=0; s<shapeFrames.size(); ++s)
+          for (std::size_t s = 0; s < shapeFrames.size(); ++s)
             shapeFrames[s]->getVisualAspect(true)->setHidden(false);
         }
       }
@@ -663,8 +654,11 @@ void InteractiveFrameDnD::saveState()
 }
 
 //==============================================================================
-BodyNodeDnD::BodyNodeDnD(Viewer* viewer, dart::dynamics::BodyNode* bn,
-                         bool useExternalIK, bool useWholeBody)
+BodyNodeDnD::BodyNodeDnD(
+    Viewer* viewer,
+    dart::dynamics::BodyNode* bn,
+    bool useExternalIK,
+    bool useWholeBody)
   : DragAndDrop(viewer, bn),
     mBodyNode(bn),
     mUseExternalIK(useExternalIK),
@@ -684,15 +678,15 @@ dart::dynamics::BodyNode* BodyNodeDnD::getBodyNode() const
 //==============================================================================
 void BodyNodeDnD::update()
 {
-  if(nullptr == mEntity)
+  if (nullptr == mEntity)
     return;
 
-  osg::MouseButtonEvent event =
-      mViewer->getDefaultEventHandler()->getButtonEvent(LEFT_MOUSE);
+  osg::MouseButtonEvent event
+      = mViewer->getDefaultEventHandler()->getButtonEvent(LEFT_MOUSE);
 
-  if(mAmMoving)
+  if (mAmMoving)
   {
-    if(osg::BUTTON_RELEASE == event)
+    if (osg::BUTTON_RELEASE == event)
     {
       mAmMoving = false;
       release();
@@ -702,15 +696,15 @@ void BodyNodeDnD::update()
   }
   else // not moving
   {
-    if(osg::BUTTON_PUSH == event)
+    if (osg::BUTTON_PUSH == event)
     {
-      const std::vector<osg::PickInfo>& picks =
-          mViewer->getDefaultEventHandler()->getButtonPicks(
-            osg::LEFT_MOUSE, osg::BUTTON_PUSH);
+      const std::vector<osg::PickInfo>& picks
+          = mViewer->getDefaultEventHandler()->getButtonPicks(
+              osg::LEFT_MOUSE, osg::BUTTON_PUSH);
 
-      for(const osg::PickInfo& pick : picks)
+      for (const osg::PickInfo& pick : picks)
       {
-        if(pick.frame->getParentFrame() == mEntity)
+        if (pick.frame->getParentFrame() == mEntity)
         {
           mAmMoving = true;
           mPickedPosition = pick.position;
@@ -721,7 +715,7 @@ void BodyNodeDnD::update()
         // The picks are always ordered from closest to furthest. If the closest
         // pick is not our Entity, then something is blocking the way, so if we
         // are obstructable, then we should quit.
-        if(mAmObstructable)
+        if (mAmObstructable)
           return;
       }
     }
@@ -731,20 +725,21 @@ void BodyNodeDnD::update()
 //==============================================================================
 void BodyNodeDnD::move()
 {
-  if(mIK == nullptr)
+  if (mIK == nullptr)
     return;
 
-  bool restrictJoints = (mViewer->getDefaultEventHandler()->getModKeyMask()
-                         & mJointRestrictionModKey);
+  bool restrictJoints
+      = (mViewer->getDefaultEventHandler()->getModKeyMask()
+         & mJointRestrictionModKey);
 
-  if(restrictJoints)
+  if (restrictJoints)
   {
     std::vector<std::size_t> dofs;
 
     dart::dynamics::Joint* joint = mBodyNode.lock()->getParentJoint();
-    for(std::size_t count = 0; count <= mAdditionalBodyNodes; ++count)
+    for (std::size_t count = 0; count <= mAdditionalBodyNodes; ++count)
     {
-      for(std::size_t j=0; j < joint->getNumDofs(); ++j)
+      for (std::size_t j = 0; j < joint->getNumDofs(); ++j)
         dofs.push_back(joint->getDof(j)->getIndexInSkeleton());
     }
 
@@ -752,7 +747,7 @@ void BodyNodeDnD::move()
   }
   else
   {
-    if(mUseWholeBody)
+    if (mUseWholeBody)
       mIK->useWholeBody();
     else
       mIK->useChain();
@@ -760,10 +755,11 @@ void BodyNodeDnD::move()
 
   Eigen::Isometry3d tf(Eigen::Isometry3d::Identity());
 
-  bool preserveOrientation = (mViewer->getDefaultEventHandler()->getModKeyMask()
-                              & mPreserveOrientationModKey);
+  bool preserveOrientation
+      = (mViewer->getDefaultEventHandler()->getModKeyMask()
+         & mPreserveOrientationModKey);
 
-  if(preserveOrientation)
+  if (preserveOrientation)
   {
     tf.rotate(mSavedRotation);
   }
@@ -773,11 +769,11 @@ void BodyNodeDnD::move()
     tf.linear() = (R * mSavedRotation).matrix();
   }
 
-  bool rotationActive = (mViewer->getDefaultEventHandler()->getModKeyMask()
-                         & mRotationModKey);
+  bool rotationActive
+      = (mViewer->getDefaultEventHandler()->getModKeyMask() & mRotationModKey);
 
-  if( ((RotationOption::HOLD_MODKEY==mRotationOption) && rotationActive)
-      || RotationOption::ALWAYS_ON==mRotationOption)
+  if (((RotationOption::HOLD_MODKEY == mRotationOption) && rotationActive)
+      || RotationOption::ALWAYS_ON == mRotationOption)
   {
     tf.translation() = mPivot;
     mIK->setOffset();
@@ -789,12 +785,12 @@ void BodyNodeDnD::move()
     mIK->setOffset(mSavedLocalOffset);
   }
 
-  if(mIK->getTarget()->getParentFrame()->isWorld())
+  if (mIK->getTarget()->getParentFrame()->isWorld())
     mIK->getTarget()->setRelativeTransform(tf);
   else
     mIK->getTarget()->setTransform(tf);
 
-  if(mUseExternalIK)
+  if (mUseExternalIK)
   {
     mIK->getSolver()->setNumMaxIterations(10);
     mIK->solveAndApply(true);
@@ -808,7 +804,7 @@ void BodyNodeDnD::saveState()
   mPivot = bn->getWorldTransform().translation();
   mSavedRotation = bn->getWorldTransform().rotation();
 
-  if(mUseExternalIK)
+  if (mUseExternalIK)
   {
     mIK = dart::dynamics::InverseKinematics::create(bn);
   }
@@ -818,11 +814,12 @@ void BodyNodeDnD::saveState()
   }
 
   mSavedGlobalOffset = mPickedPosition - mPivot;
-  mSavedLocalOffset = bn->getWorldTransform().linear().transpose()
-                      * mSavedGlobalOffset;
+  mSavedLocalOffset
+      = bn->getWorldTransform().linear().transpose() * mSavedGlobalOffset;
 
   mIK->getTarget()->setTransform(bn->getWorldTransform());
-  mIK->setGradientMethod<dart::dynamics::InverseKinematics::JacobianTranspose>();
+  mIK->setGradientMethod<
+      dart::dynamics::InverseKinematics::JacobianTranspose>();
 
   mAdditionalBodyNodes = 0;
 }
@@ -830,7 +827,7 @@ void BodyNodeDnD::saveState()
 //==============================================================================
 void BodyNodeDnD::release()
 {
-  if(mUseExternalIK)
+  if (mUseExternalIK)
   {
     mIK = nullptr;
   }
@@ -873,7 +870,8 @@ void BodyNodeDnD::setPreserveOrientationModKey(
 }
 
 //==============================================================================
-::osgGA::GUIEventAdapter::ModKeyMask BodyNodeDnD::getPreserveOrientationModKey() const
+::osgGA::GUIEventAdapter::ModKeyMask BodyNodeDnD::getPreserveOrientationModKey()
+    const
 {
   return mPreserveOrientationModKey;
 }
@@ -886,7 +884,8 @@ void BodyNodeDnD::setJointRestrictionModKey(
 }
 
 //==============================================================================
-::osgGA::GUIEventAdapter::ModKeyMask BodyNodeDnD::getJointRestrictionModKey() const
+::osgGA::GUIEventAdapter::ModKeyMask BodyNodeDnD::getJointRestrictionModKey()
+    const
 {
   return mJointRestrictionModKey;
 }
