@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011-2019, The DART development contributors
+ * Copyright (c) 2011-2021, The DART development contributors
  * All rights reserved.
  *
  * The list of contributors can be found at:
@@ -266,20 +266,17 @@ void setVertices(
 
   switch (planeType)
   {
-    case GridVisual::PlaneType::XY:
-    {
+    case GridVisual::PlaneType::XY: {
       axis1 = 0;
       axis2 = 1;
       break;
     }
-    case GridVisual::PlaneType::YZ:
-    {
+    case GridVisual::PlaneType::YZ: {
       axis1 = 1;
       axis2 = 2;
       break;
     }
-    case GridVisual::PlaneType::ZX:
-    {
+    case GridVisual::PlaneType::ZX: {
       axis1 = 2;
       axis2 = 0;
       break;
@@ -458,20 +455,17 @@ void GridVisual::refresh()
 
     switch (mPlaneType)
     {
-      case GridVisual::PlaneType::XY:
-      {
+      case GridVisual::PlaneType::XY: {
         mAxisLineColor->at(0) = xAxisLineColor;
         mAxisLineColor->at(2) = yAxisLineColor;
         break;
       }
-      case GridVisual::PlaneType::YZ:
-      {
+      case GridVisual::PlaneType::YZ: {
         mAxisLineColor->at(0) = yAxisLineColor;
         mAxisLineColor->at(2) = zAxisLineColor;
         break;
       }
-      case GridVisual::PlaneType::ZX:
-      {
+      case GridVisual::PlaneType::ZX: {
         mAxisLineColor->at(0) = zAxisLineColor;
         mAxisLineColor->at(2) = xAxisLineColor;
         break;
@@ -523,6 +517,8 @@ void GridVisual::initialize()
   mAxisLineGeom->setDataVariance(::osg::Object::STATIC);
   mAxisLineGeom->getOrCreateStateSet()->setMode(
       GL_BLEND, ::osg::StateAttribute::ON);
+  mAxisLineGeom->getOrCreateStateSet()->setRenderingHint(
+      ::osg::StateSet::TRANSPARENT_BIN);
 
   // Set grid color
   static const ::osg::Vec4 majorLineColor(0.4f, 0.4f, 0.4f, 1.0f);
@@ -544,6 +540,8 @@ void GridVisual::initialize()
   mMajorLineGeom->setColorBinding(::osg::Geometry::BIND_OVERALL);
   mMajorLineGeom->getOrCreateStateSet()->setMode(
       GL_BLEND, ::osg::StateAttribute::ON);
+  mMajorLineGeom->getOrCreateStateSet()->setRenderingHint(
+      ::osg::StateSet::TRANSPARENT_BIN);
 
   mMinorLineColor = new ::osg::Vec4Array;
   mMinorLineColor->resize(1);
@@ -552,6 +550,8 @@ void GridVisual::initialize()
   mMinorLineGeom->setColorBinding(::osg::Geometry::BIND_OVERALL);
   mMinorLineGeom->getOrCreateStateSet()->setMode(
       GL_BLEND, ::osg::StateAttribute::ON);
+  mMinorLineGeom->getOrCreateStateSet()->setRenderingHint(
+      ::osg::StateSet::TRANSPARENT_BIN);
 
   mMinorLineFaces = new ::osg::DrawElementsUInt(::osg::PrimitiveSet::LINES, 0);
   mMinorLineGeom->addPrimitiveSet(mMinorLineFaces);
