@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011-2019, The DART development contributors
+ * Copyright (c) 2011-2021, The DART development contributors
  * All rights reserved.
  *
  * The list of contributors can be found at:
@@ -56,19 +56,19 @@ Eigen::Quaterniond expToQuat(const Eigen::Vector3d& _v);
 Eigen::Vector3d quatToExp(const Eigen::Quaterniond& _q);
 
 /// \brief
-Eigen::Vector3d rotatePoint(const Eigen::Quaterniond& _q,
-                            const Eigen::Vector3d& _pt);
+Eigen::Vector3d rotatePoint(
+    const Eigen::Quaterniond& _q, const Eigen::Vector3d& _pt);
 
 /// \brief
-Eigen::Vector3d rotatePoint(const Eigen::Quaterniond& _q,
-                            double _x, double _y, double _z);
+Eigen::Vector3d rotatePoint(
+    const Eigen::Quaterniond& _q, double _x, double _y, double _z);
 
 /// \brief
 Eigen::Matrix3d quatDeriv(const Eigen::Quaterniond& _q, int _el);
 
 /// \brief
-Eigen::Matrix3d quatSecondDeriv(const Eigen::Quaterniond& _q,
-                                int _el1, int _el2);
+Eigen::Matrix3d quatSecondDeriv(
+    const Eigen::Quaterniond& _q, int _el1, int _el2);
 
 //------------------------------------------------------------------------------
 /// \brief Given Euler XYX angles, return a 3x3 rotation matrix, which is
@@ -175,8 +175,8 @@ Eigen::Matrix3d expMapRot(const Eigen::Vector3d& _expmap);
 Eigen::Matrix3d expMapJac(const Eigen::Vector3d& _expmap);
 
 /// \brief Computes the time derivative of the expmap Jacobian.
-Eigen::Matrix3d expMapJacDot(const Eigen::Vector3d& _expmap,
-                             const Eigen::Vector3d& _qdot);
+Eigen::Matrix3d expMapJacDot(
+    const Eigen::Vector3d& _expmap, const Eigen::Vector3d& _qdot);
 
 /// \brief computes the derivative of the Jacobian of the expmap wrt to _qi
 /// indexed dof; _qi \f$ \in \f$ {0,1,2}
@@ -212,13 +212,14 @@ Eigen::Vector6d AdT(const Eigen::Isometry3d& _T, const Eigen::Vector6d& _V);
 Eigen::Matrix6d getAdTMatrix(const Eigen::Isometry3d& T);
 
 /// Adjoint mapping for dynamic size Jacobian
-template<typename Derived>
-typename Derived::PlainObject AdTJac(const Eigen::Isometry3d& _T,
-                                     const Eigen::MatrixBase<Derived>& _J)
+template <typename Derived>
+typename Derived::PlainObject AdTJac(
+    const Eigen::Isometry3d& _T, const Eigen::MatrixBase<Derived>& _J)
 {
   // Check the number of rows is 6 at compile time
-  EIGEN_STATIC_ASSERT(Derived::RowsAtCompileTime == 6,
-                      THIS_METHOD_IS_ONLY_FOR_MATRICES_OF_A_SPECIFIC_SIZE);
+  EIGEN_STATIC_ASSERT(
+      Derived::RowsAtCompileTime == 6,
+      THIS_METHOD_IS_ONLY_FOR_MATRICES_OF_A_SPECIFIC_SIZE);
 
   typename Derived::PlainObject ret(_J.rows(), _J.cols());
 
@@ -230,16 +231,17 @@ typename Derived::PlainObject AdTJac(const Eigen::Isometry3d& _T,
 }
 
 /// Adjoint mapping for fixed size Jacobian
-template<typename Derived>
-typename Derived::PlainObject AdTJacFixed(const Eigen::Isometry3d& _T,
-                                          const Eigen::MatrixBase<Derived>& _J)
+template <typename Derived>
+typename Derived::PlainObject AdTJacFixed(
+    const Eigen::Isometry3d& _T, const Eigen::MatrixBase<Derived>& _J)
 {
   // Check if _J is fixed size Jacobian
   EIGEN_STATIC_ASSERT_FIXED_SIZE(Derived);
 
   // Check the number of rows is 6 at compile time
-  EIGEN_STATIC_ASSERT(Derived::RowsAtCompileTime == 6,
-                      THIS_METHOD_IS_ONLY_FOR_MATRICES_OF_A_SPECIFIC_SIZE);
+  EIGEN_STATIC_ASSERT(
+      Derived::RowsAtCompileTime == 6,
+      THIS_METHOD_IS_ONLY_FOR_MATRICES_OF_A_SPECIFIC_SIZE);
 
   typename Derived::PlainObject ret(_J.rows(), _J.cols());
 
@@ -256,68 +258,70 @@ typename Derived::PlainObject AdTJacFixed(const Eigen::Isometry3d& _T,
 Eigen::Vector6d AdR(const Eigen::Isometry3d& _T, const Eigen::Vector6d& _V);
 
 /// \brief fast version of Ad(T, se3(w, 0))
-Eigen::Vector6d AdTAngular(const Eigen::Isometry3d& _T,
-                           const Eigen::Vector3d& _w);
+Eigen::Vector6d AdTAngular(
+    const Eigen::Isometry3d& _T, const Eigen::Vector3d& _w);
 
 /// \brief fast version of Ad(T, se3(0, v))
-Eigen::Vector6d AdTLinear(const Eigen::Isometry3d& _T,
-                          const Eigen::Vector3d& _v);
+Eigen::Vector6d AdTLinear(
+    const Eigen::Isometry3d& _T, const Eigen::Vector3d& _v);
 
 ///// \brief fast version of Ad([I p; 0 1], V)
 // se3 AdP(const Vec3& p, const se3& s);
 
 /// \brief Change coordinate Frame of a Jacobian
-template<typename Derived>
-typename Derived::PlainObject AdRJac(const Eigen::Isometry3d& _T,
-                                     const Eigen::MatrixBase<Derived>& _J)
+template <typename Derived>
+typename Derived::PlainObject AdRJac(
+    const Eigen::Isometry3d& _T, const Eigen::MatrixBase<Derived>& _J)
 {
-  EIGEN_STATIC_ASSERT(Derived::RowsAtCompileTime == 6,
-                      THIS_METHOD_IS_ONLY_FOR_MATRICES_OF_A_SPECIFIC_SIZE);
+  EIGEN_STATIC_ASSERT(
+      Derived::RowsAtCompileTime == 6,
+      THIS_METHOD_IS_ONLY_FOR_MATRICES_OF_A_SPECIFIC_SIZE);
 
   typename Derived::PlainObject ret(_J.rows(), _J.cols());
 
-  ret.template topRows<3>().noalias() =
-      _T.linear() * _J.template topRows<3>();
+  ret.template topRows<3>().noalias() = _T.linear() * _J.template topRows<3>();
 
-  ret.template bottomRows<3>().noalias() =
-      _T.linear() * _J.template bottomRows<3>();
+  ret.template bottomRows<3>().noalias()
+      = _T.linear() * _J.template bottomRows<3>();
 
   return ret;
 }
 
-template<typename Derived>
-typename Derived::PlainObject AdRInvJac(const Eigen::Isometry3d& _T,
-                                        const Eigen::MatrixBase<Derived>& _J)
+template <typename Derived>
+typename Derived::PlainObject AdRInvJac(
+    const Eigen::Isometry3d& _T, const Eigen::MatrixBase<Derived>& _J)
 {
-  EIGEN_STATIC_ASSERT(Derived::RowsAtCompileTime == 6,
-                      THIS_METHOD_IS_ONLY_FOR_MATRICES_OF_A_SPECIFIC_SIZE);
+  EIGEN_STATIC_ASSERT(
+      Derived::RowsAtCompileTime == 6,
+      THIS_METHOD_IS_ONLY_FOR_MATRICES_OF_A_SPECIFIC_SIZE);
 
   typename Derived::PlainObject ret(_J.rows(), _J.cols());
 
-  ret.template topRows<3>().noalias() =
-      _T.linear().transpose() * _J.template topRows<3>();
+  ret.template topRows<3>().noalias()
+      = _T.linear().transpose() * _J.template topRows<3>();
 
-  ret.template bottomRows<3>().noalias() =
-      _T.linear().transpose() * _J.template bottomRows<3>();
+  ret.template bottomRows<3>().noalias()
+      = _T.linear().transpose() * _J.template bottomRows<3>();
 
   return ret;
 }
 
-template<typename Derived>
-typename Derived::PlainObject adJac(const Eigen::Vector6d& _V,
-                                    const Eigen::MatrixBase<Derived>& _J)
+template <typename Derived>
+typename Derived::PlainObject adJac(
+    const Eigen::Vector6d& _V, const Eigen::MatrixBase<Derived>& _J)
 {
-  EIGEN_STATIC_ASSERT(Derived::RowsAtCompileTime == 6,
-                      THIS_METHOD_IS_ONLY_FOR_MATRICES_OF_A_SPECIFIC_SIZE);
+  EIGEN_STATIC_ASSERT(
+      Derived::RowsAtCompileTime == 6,
+      THIS_METHOD_IS_ONLY_FOR_MATRICES_OF_A_SPECIFIC_SIZE);
 
   typename Derived::PlainObject ret(_J.rows(), _J.cols());
 
-  ret.template topRows<3>().noalias() =
-      - _J.template topRows<3>().colwise().cross(_V.head<3>());
+  ret.template topRows<3>().noalias()
+      = -_J.template topRows<3>().colwise().cross(_V.head<3>());
 
-  ret.template bottomRows<3>().noalias() =
-      - _J.template bottomRows<3>().colwise().cross(_V.head<3>())
-      - _J.template topRows<3>().colwise().cross(_V.tail<3>());
+  ret.template bottomRows<3>().noalias()
+      = -_J.template bottomRows<3>().colwise().cross(_V.head<3>())
+        - _J.template topRows<3>().colwise().cross(_V.tail<3>());
 
   return ret;
 }
@@ -326,13 +330,14 @@ typename Derived::PlainObject adJac(const Eigen::Vector6d& _V,
 Eigen::Vector6d AdInvT(const Eigen::Isometry3d& _T, const Eigen::Vector6d& _V);
 
 /// Adjoint mapping for dynamic size Jacobian
-template<typename Derived>
-typename Derived::PlainObject AdInvTJac(const Eigen::Isometry3d& _T,
-                                        const Eigen::MatrixBase<Derived>& _J)
+template <typename Derived>
+typename Derived::PlainObject AdInvTJac(
+    const Eigen::Isometry3d& _T, const Eigen::MatrixBase<Derived>& _J)
 {
   // Check the number of rows is 6 at compile time
-  EIGEN_STATIC_ASSERT(Derived::RowsAtCompileTime == 6,
-                      THIS_METHOD_IS_ONLY_FOR_MATRICES_OF_A_SPECIFIC_SIZE);
+  EIGEN_STATIC_ASSERT(
+      Derived::RowsAtCompileTime == 6,
+      THIS_METHOD_IS_ONLY_FOR_MATRICES_OF_A_SPECIFIC_SIZE);
 
   typename Derived::PlainObject ret(_J.rows(), _J.cols());
 
@@ -344,17 +349,17 @@ typename Derived::PlainObject AdInvTJac(const Eigen::Isometry3d& _T,
 }
 
 /// Adjoint mapping for fixed size Jacobian
-template<typename Derived>
+template <typename Derived>
 typename Derived::PlainObject AdInvTJacFixed(
-    const Eigen::Isometry3d& _T,
-    const Eigen::MatrixBase<Derived>& _J)
+    const Eigen::Isometry3d& _T, const Eigen::MatrixBase<Derived>& _J)
 {
   // Check if _J is fixed size Jacobian
   EIGEN_STATIC_ASSERT_FIXED_SIZE(Derived);
 
   // Check the number of rows is 6 at compile time
-  EIGEN_STATIC_ASSERT(Derived::RowsAtCompileTime == 6,
-                      THIS_METHOD_IS_ONLY_FOR_MATRICES_OF_A_SPECIFIC_SIZE);
+  EIGEN_STATIC_ASSERT(
+      Derived::RowsAtCompileTime == 6,
+      THIS_METHOD_IS_ONLY_FOR_MATRICES_OF_A_SPECIFIC_SIZE);
 
   typename Derived::PlainObject ret(_J.rows(), _J.cols());
 
@@ -380,8 +385,8 @@ typename Derived::PlainObject AdInvTJacFixed(
 // se3 AdInvR(const SE3& T, const se3& V);
 
 /// \brief Fast version of Ad(Inv([R 0; 0 1]), se3(0, v))
-Eigen::Vector6d AdInvRLinear(const Eigen::Isometry3d& _T,
-                             const Eigen::Vector3d& _v);
+Eigen::Vector6d AdInvRLinear(
+    const Eigen::Isometry3d& _T, const Eigen::Vector3d& _v);
 
 /// \brief dual adjoint mapping
 /// \note @f$Ad^{@,*}_TF = ( R^T (m - p@times f)@,,~ R^T f)@f$,
@@ -421,9 +426,10 @@ Inertia transformInertia(const Eigen::Isometry3d& _T, const Inertia& _AI);
 
 /// Use the Parallel Axis Theorem to compute the moment of inertia of a body
 /// whose center of mass has been shifted from the origin
-Eigen::Matrix3d parallelAxisTheorem(const Eigen::Matrix3d& _original,
-                                    const Eigen::Vector3d& _comShift,
-                                    double _mass);
+Eigen::Matrix3d parallelAxisTheorem(
+    const Eigen::Matrix3d& _original,
+    const Eigen::Vector3d& _comShift,
+    double _mass);
 
 enum AxisType
 {
@@ -435,20 +441,21 @@ enum AxisType
 /// Compute a rotation matrix from a vector. One axis of the rotated coordinates
 /// by the rotation matrix matches the input axis where the axis is specified
 /// by axisType.
-Eigen::Matrix3d computeRotation(const Eigen::Vector3d& axis,
-                                AxisType axisType = AxisType::AXIS_X);
+Eigen::Matrix3d computeRotation(
+    const Eigen::Vector3d& axis, AxisType axisType = AxisType::AXIS_X);
 
 /// Compute a transform from a vector and a position. The rotation of the result
 /// transform is computed by computeRotationMatrix(), and the translation is
 /// just the input translation.
-Eigen::Isometry3d computeTransform(const Eigen::Vector3d& axis,
-                                   const Eigen::Vector3d& translation,
-                                   AxisType axisType = AxisType::AXIS_X);
+Eigen::Isometry3d computeTransform(
+    const Eigen::Vector3d& axis,
+    const Eigen::Vector3d& translation,
+    AxisType axisType = AxisType::AXIS_X);
 
 /// Generate frame given origin and z-axis
 DART_DEPRECATED(6.0)
-Eigen::Isometry3d getFrameOriginAxisZ(const Eigen::Vector3d& _origin,
-                                      const Eigen::Vector3d& _axisZ);
+Eigen::Isometry3d getFrameOriginAxisZ(
+    const Eigen::Vector3d& _origin, const Eigen::Vector3d& _axisZ);
 
 /// \brief Check if determinant of _R is equat to 1 and all the elements are not
 /// NaN values.
@@ -464,7 +471,7 @@ inline double wrapToPi(double angle)
 {
   constexpr auto pi = constantsd::pi();
 
-  return std::fmod(angle+pi, 2*pi) - pi;
+  return std::fmod(angle + pi, 2 * pi) - pi;
 }
 
 template <typename MatrixType, typename ReturnType>
@@ -472,18 +479,19 @@ void extractNullSpace(const Eigen::JacobiSVD<MatrixType>& _SVD, ReturnType& _NS)
 {
   int rank = 0;
   // TODO(MXG): Replace this with _SVD.rank() once the latest Eigen is released
-  if(_SVD.nonzeroSingularValues() > 0)
+  if (_SVD.nonzeroSingularValues() > 0)
   {
-    double thresh = std::max(_SVD.singularValues().coeff(0)*1e-10,
-                             std::numeric_limits<double>::min());
-    int i = _SVD.nonzeroSingularValues()-1;
-    while( i >= 0 && _SVD.singularValues().coeff(i) < thresh )
+    double thresh = std::max(
+        _SVD.singularValues().coeff(0) * 1e-10,
+        std::numeric_limits<double>::min());
+    int i = _SVD.nonzeroSingularValues() - 1;
+    while (i >= 0 && _SVD.singularValues().coeff(i) < thresh)
       --i;
-    rank = i+1;
+    rank = i + 1;
   }
 
   int cols = _SVD.matrixV().cols(), rows = _SVD.matrixV().rows();
-  _NS = _SVD.matrixV().block(0, rank, rows, cols-rank);
+  _NS = _SVD.matrixV().block(0, rank, rows, cols - rank);
 }
 
 template <typename MatrixType, typename ReturnType>
@@ -506,9 +514,10 @@ SupportPolygon computeSupportPolgyon(
     const Eigen::Vector3d& _axis1 = Eigen::Vector3d::UnitX(),
     const Eigen::Vector3d& _axis2 = Eigen::Vector3d::UnitY());
 
-/// Same as computeSupportPolgyon, except you can pass in a std::vector<std::size_t>
-/// which will have the same size as the returned SupportPolygon, and each entry
-/// will contain the original index of each point in the SupportPolygon
+/// Same as computeSupportPolgyon, except you can pass in a
+/// std::vector<std::size_t> which will have the same size as the returned
+/// SupportPolygon, and each entry will contain the original index of each point
+/// in the SupportPolygon
 SupportPolygon computeSupportPolgyon(
     std::vector<std::size_t>& _originalIndices,
     const SupportGeometry& _geometry,
@@ -520,19 +529,37 @@ SupportPolygon computeConvexHull(const SupportPolygon& _points);
 
 /// Computes the convex hull of a set of 2D points and fills in _originalIndices
 /// with the original index of each entry in the returned SupportPolygon
-SupportPolygon computeConvexHull(std::vector<std::size_t>& _originalIndices,
-                                 const SupportPolygon& _points);
+SupportPolygon computeConvexHull(
+    std::vector<std::size_t>& _originalIndices, const SupportPolygon& _points);
+
+/// Generates a 3D convex hull given vertices and indices.
+///
+/// \tparam S: The scalar type of the vertices.
+/// \tparam Index: The index type of the triangles.
+/// \param[in] vertices: The given vertices to generate a convex hull from.
+/// \param[in] optimize: (Optional) Whether to discard vertices that are not
+/// referred to in the resulted convex hull. The resulted indices will be
+/// updated accordingly.
+/// \return A tuple of the vertices and indices of the resulted convex hull.
+template <typename S = double, typename Index = std::size_t>
+std::tuple<
+    std::vector<Eigen::Matrix<S, 3, 1>>,
+    std::vector<Eigen::Matrix<Index, 3, 1>>>
+computeConvexHull3D(
+    const std::vector<Eigen::Matrix<S, 3, 1>>& vertices, bool optimize = true);
 
 /// Compute the centroid of a polygon, assuming the polygon is a convex hull
 Eigen::Vector2d computeCentroidOfHull(const SupportPolygon& _convexHull);
 
 /// Intersection_t is returned by the computeIntersection() function to indicate
 /// whether there was a valid intersection between the two line segments
-enum IntersectionResult {
+enum IntersectionResult
+{
 
-  INTERSECTING = 0,   ///< An intersection was found
-  PARALLEL,           ///< The line segments are parallel
-  BEYOND_ENDPOINTS    ///< There is no intersection because the end points do not expand far enough
+  INTERSECTING = 0, ///< An intersection was found
+  PARALLEL,         ///< The line segments are parallel
+  BEYOND_ENDPOINTS  ///< There is no intersection because the end points do not
+                    ///< expand far enough
 
 };
 
@@ -549,21 +576,22 @@ IntersectionResult computeIntersection(
 double cross(const Eigen::Vector2d& _v1, const Eigen::Vector2d& _v2);
 
 /// Returns true if the point _p is inside the support polygon
-bool isInsideSupportPolygon(const Eigen::Vector2d& _p,
-                            const SupportPolygon& _support,
-                            bool _includeEdge = true);
+bool isInsideSupportPolygon(
+    const Eigen::Vector2d& _p,
+    const SupportPolygon& _support,
+    bool _includeEdge = true);
 
 /// Returns the point which is closest to _p that also lays on the line segment
 /// that goes from _s1 -> _s2
-Eigen::Vector2d computeClosestPointOnLineSegment(const Eigen::Vector2d& _p,
-                                                 const Eigen::Vector2d& _s1,
-                                                 const Eigen::Vector2d& _s2);
+Eigen::Vector2d computeClosestPointOnLineSegment(
+    const Eigen::Vector2d& _p,
+    const Eigen::Vector2d& _s1,
+    const Eigen::Vector2d& _s2);
 
 /// Returns the point which is closest to _p that also lays on the edge of the
 /// support polygon
 Eigen::Vector2d computeClosestPointOnSupportPolygon(
-    const Eigen::Vector2d& _p,
-    const SupportPolygon& _support);
+    const Eigen::Vector2d& _p, const SupportPolygon& _support);
 
 /// Same as closestPointOnSupportPolygon, but also fills in _index1 and _index2
 /// with the indices of the line segment
@@ -573,36 +601,59 @@ Eigen::Vector2d computeClosestPointOnSupportPolygon(
     const Eigen::Vector2d& _p,
     const SupportPolygon& _support);
 
-
 // Represents a bounding box with minimum and maximum coordinates.
-class BoundingBox {
-    public:
-        EIGEN_MAKE_ALIGNED_OPERATOR_NEW
+class BoundingBox
+{
+public:
+  EIGEN_MAKE_ALIGNED_OPERATOR_NEW
 
-        BoundingBox();
-        BoundingBox(const Eigen::Vector3d& min, const Eigen::Vector3d& max);
+  BoundingBox();
+  BoundingBox(const Eigen::Vector3d& min, const Eigen::Vector3d& max);
 
-        inline const Eigen::Vector3d& getMin() const {  return mMin; }
-        inline const Eigen::Vector3d& getMax() const { return mMax; }
+  inline const Eigen::Vector3d& getMin() const
+  {
+    return mMin;
+  }
+  inline const Eigen::Vector3d& getMax() const
+  {
+    return mMax;
+  }
 
-        inline void setMin(const Eigen::Vector3d& min) { mMin = min; }
-        inline void setMax(const Eigen::Vector3d& max) { mMax = max; }
+  inline void setMin(const Eigen::Vector3d& min)
+  {
+    mMin = min;
+  }
+  inline void setMax(const Eigen::Vector3d& max)
+  {
+    mMax = max;
+  }
 
-        // \brief Centroid of the bounding box (i.e average of min and max)
-        inline Eigen::Vector3d computeCenter() const { return (mMax + mMin) * 0.5; }
-        // \brief Coordinates of the maximum corner with respect to the centroid.
-        inline Eigen::Vector3d computeHalfExtents() const { return (mMax - mMin) * 0.5; }
-        // \brief Length of each of the sides of the bounding box.
-        inline Eigen::Vector3d computeFullExtents() const { return (mMax - mMin); }
+  // \brief Centroid of the bounding box (i.e average of min and max)
+  inline Eigen::Vector3d computeCenter() const
+  {
+    return (mMax + mMin) * 0.5;
+  }
+  // \brief Coordinates of the maximum corner with respect to the centroid.
+  inline Eigen::Vector3d computeHalfExtents() const
+  {
+    return (mMax - mMin) * 0.5;
+  }
+  // \brief Length of each of the sides of the bounding box.
+  inline Eigen::Vector3d computeFullExtents() const
+  {
+    return (mMax - mMin);
+  }
 
-    protected:
-        // \brief minimum coordinates of the bounding box
-        Eigen::Vector3d mMin;
-        // \brief maximum coordinates of the bounding box
-        Eigen::Vector3d mMax;
+protected:
+  // \brief minimum coordinates of the bounding box
+  Eigen::Vector3d mMin;
+  // \brief maximum coordinates of the bounding box
+  Eigen::Vector3d mMax;
 };
 
-}  // namespace math
-}  // namespace dart
+} // namespace math
+} // namespace dart
 
-#endif  // DART_MATH_GEOMETRY_HPP_
+#include "dart/math/detail/Geometry-impl.hpp"
+
+#endif // DART_MATH_GEOMETRY_HPP_
