@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011-2019, The DART development contributors
+ * Copyright (c) 2011-2021, The DART development contributors
  * All rights reserved.
  *
  * The list of contributors can be found at:
@@ -33,10 +33,10 @@
 #include <dart/dart.hpp>
 #include <pybind11/pybind11.h>
 #include <pybind11/stl.h>
+
 #include "eigen_geometry_pybind.h"
 #include "eigen_pybind.h"
-
-PYBIND11_DECLARE_HOLDER_TYPE(T, dart::dynamics::TemplateBodyNodePtr<T>, true);
+#include "pointers.hpp"
 
 namespace py = pybind11;
 
@@ -104,36 +104,10 @@ void BodyNode(py::module& m)
               const std::string&,
               const dart::dynamics::Inertia&,
               bool,
-              double>(),
-          ::py::arg("name"),
-          ::py::arg("inertia"),
-          ::py::arg("isCollidable"),
-          ::py::arg("frictionCoeff"))
-      .def(
-          ::py::init<
-              const std::string&,
-              const dart::dynamics::Inertia&,
-              bool,
-              double,
-              double>(),
-          ::py::arg("name"),
-          ::py::arg("inertia"),
-          ::py::arg("isCollidable"),
-          ::py::arg("frictionCoeff"),
-          ::py::arg("restitutionCoeff"))
-      .def(
-          ::py::init<
-              const std::string&,
-              const dart::dynamics::Inertia&,
-              bool,
-              double,
-              double,
               bool>(),
           ::py::arg("name"),
           ::py::arg("inertia"),
           ::py::arg("isCollidable"),
-          ::py::arg("frictionCoeff"),
-          ::py::arg("restitutionCoeff"),
           ::py::arg("gravityMode"))
       .def_readwrite(
           "mName", &dart::dynamics::detail::BodyNodeAspectProperties::mName)
@@ -143,12 +117,6 @@ void BodyNode(py::module& m)
       .def_readwrite(
           "mIsCollidable",
           &dart::dynamics::detail::BodyNodeAspectProperties::mIsCollidable)
-      .def_readwrite(
-          "mFrictionCoeff",
-          &dart::dynamics::detail::BodyNodeAspectProperties::mFrictionCoeff)
-      .def_readwrite(
-          "mRestitutionCoeff",
-          &dart::dynamics::detail::BodyNodeAspectProperties::mRestitutionCoeff)
       .def_readwrite(
           "mGravityMode",
           &dart::dynamics::detail::BodyNodeAspectProperties::mGravityMode);
@@ -653,6 +621,11 @@ void BodyNode(py::module& m)
             self->setInertia(inertia);
           },
           ::py::arg("inertia"))
+      .def(
+          "getInertia",
+          +[](const dart::dynamics::BodyNode* self)
+              -> const dart::dynamics::Inertia& { return self->getInertia(); },
+          ::py::return_value_policy::reference_internal)
       .def(
           "setLocalCOM",
           +[](dart::dynamics::BodyNode* self, const Eigen::Vector3d& _com) {
@@ -753,28 +726,6 @@ void BodyNode(py::module& m)
           },
           ::py::arg("relativeTo"),
           ::py::arg("inCoordinatesOf"))
-      .def(
-          "setFrictionCoeff",
-          +[](dart::dynamics::BodyNode* self, double _coeff) {
-            self->setFrictionCoeff(_coeff);
-          },
-          ::py::arg("coeff"))
-      .def(
-          "getFrictionCoeff",
-          +[](const dart::dynamics::BodyNode* self) -> double {
-            return self->getFrictionCoeff();
-          })
-      .def(
-          "setRestitutionCoeff",
-          +[](dart::dynamics::BodyNode* self, double _coeff) {
-            self->setRestitutionCoeff(_coeff);
-          },
-          ::py::arg("coeff"))
-      .def(
-          "getRestitutionCoeff",
-          +[](const dart::dynamics::BodyNode* self) -> double {
-            return self->getRestitutionCoeff();
-          })
       .def(
           "getIndexInSkeleton",
           +[](const dart::dynamics::BodyNode* self) -> std::size_t {
@@ -920,11 +871,25 @@ void BodyNode(py::module& m)
           +[](const dart::dynamics::BodyNode* self) -> std::size_t {
             return self->getNumChildBodyNodes();
           })
+      .def(
+          "getChildBodyNode",
+          +[](dart::dynamics::BodyNode* self,
+              std::size_t index) -> dart::dynamics::BodyNode* {
+            return self->getChildBodyNode(index);
+          },
+          ::py::arg("index"),
+          ::py::return_value_policy::reference_internal)
       .def(
           "getNumChildJoints",
           +[](const dart::dynamics::BodyNode* self) -> std::size_t {
             return self->getNumChildJoints();
           })
+      .def(
+          "getChildJoint",
+          +[](dart::dynamics::BodyNode* self, std::size_t index)
+              -> dart::dynamics::Joint* { return self->getChildJoint(index); },
+          ::py::arg("index"),
+          ::py::return_value_policy::reference_internal)
       .def(
           "getNumShapeNodes",
           +[](const dart::dynamics::BodyNode* self) -> std::size_t {
@@ -1119,6 +1084,13 @@ void BodyNode(py::module& m)
           +[](const dart::dynamics::BodyNode* self) -> Eigen::Vector6d {
             return self->getExternalForceGlobal();
           })
+      .def(
+          "getBodyForce",
+          &dart::dynamics::BodyNode::getBodyForce,
+          "Get spatial body force transmitted from the parent joint. \n\nThe "
+          "spatial body force is transmitted to this BodyNode from the parent "
+          "body through the connecting joint. It is expressed in this "
+          "BodyNode's frame.")
       .def(
           "isReactive",
           +[](const dart::dynamics::BodyNode* self)
@@ -1225,9 +1197,9 @@ void BodyNode(py::module& m)
       .def(
           "dirtyExternalForces",
           +[](dart::dynamics::BodyNode* self) { self->dirtyExternalForces(); })
-      .def("dirtyCoriolisForces", +[](dart::dynamics::BodyNode* self) {
-        self->dirtyCoriolisForces();
-      });
+      .def(
+          "dirtyCoriolisForces",
+          +[](dart::dynamics::BodyNode* self) { self->dirtyCoriolisForces(); });
 }
 
 } // namespace python
