@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011-2019, The DART development contributors
+ * Copyright (c) 2011-2021, The DART development contributors
  * All rights reserved.
  *
  * The list of contributors can be found at:
@@ -33,6 +33,7 @@
 #include <dart/dart.hpp>
 #include <pybind11/pybind11.h>
 #include <pybind11/stl.h>
+
 #include "eigen_geometry_pybind.h"
 #include "eigen_pybind.h"
 
@@ -386,6 +387,12 @@ void Skeleton(py::module& m)
               -> dart::dynamics::Joint* { return self->getRootJoint(index); },
           ::py::arg("treeIndex"),
           py::return_value_policy::reference_internal)
+      .def(
+          "getBodyNodes",
+          +[](dart::dynamics::Skeleton* self)
+              -> const std::vector<dart::dynamics::BodyNode*>& {
+            return self->getBodyNodes();
+          })
       .def(
           "getBodyNodes",
           +[](dart::dynamics::Skeleton* self, const std::string& name)
@@ -501,6 +508,14 @@ void Skeleton(py::module& m)
           +[](const dart::dynamics::Skeleton* self) -> std::size_t {
             return self->getNumDofs();
           })
+      .def(
+          "getDof",
+          +[](dart::dynamics::Skeleton* self,
+              std::size_t index) -> dart::dynamics::DegreeOfFreedom* {
+            return self->getDof(index);
+          },
+          ::py::return_value_policy::reference_internal,
+          ::py::arg("index"))
       .def(
           "getDof",
           +[](dart::dynamics::Skeleton* self,
@@ -508,7 +523,7 @@ void Skeleton(py::module& m)
             return self->getDof(name);
           },
           ::py::return_value_policy::reference_internal,
-          ::py::arg("index"))
+          ::py::arg("name"))
       .def(
           "getDofs",
           +[](const dart::dynamics::Skeleton* self)
@@ -566,6 +581,22 @@ void Skeleton(py::module& m)
           +[](const dart::dynamics::Skeleton* self, std::size_t treeIndex)
               -> std::size_t { return self->getNumShapeNodes(treeIndex); },
           ::py::arg("treeIndex"))
+      .def(
+          "getShapeNode",
+          +[](dart::dynamics::Skeleton* self,
+              std::size_t index) -> dart::dynamics::ShapeNode* {
+            return self->getShapeNode(index);
+          },
+          ::py::return_value_policy::reference_internal,
+          ::py::arg("index"))
+      .def(
+          "getShapeNode",
+          +[](dart::dynamics::Skeleton* self,
+              const std::string& name) -> dart::dynamics::ShapeNode* {
+            return self->getShapeNode(name);
+          },
+          ::py::return_value_policy::reference_internal,
+          ::py::arg("name"))
       .def(
           "getNumEndEffectors",
           +[](const dart::dynamics::Skeleton* self) -> std::size_t {
@@ -1060,12 +1091,12 @@ void Skeleton(py::module& m)
           "getGravityForces",
           +[](dart::dynamics::Skeleton* self,
               std::size_t treeIndex) -> const Eigen::VectorXd& {
-            return self->getCoriolisForces(treeIndex);
+            return self->getGravityForces(treeIndex);
           })
       .def(
           "getGravityForces",
           +[](dart::dynamics::Skeleton* self) -> const Eigen::VectorXd& {
-            return self->getCoriolisForces();
+            return self->getGravityForces();
           })
       .def(
           "getCoriolisAndGravityForces",
@@ -1082,12 +1113,12 @@ void Skeleton(py::module& m)
           "getExternalForces",
           +[](dart::dynamics::Skeleton* self,
               std::size_t treeIndex) -> const Eigen::VectorXd& {
-            return self->getCoriolisAndGravityForces(treeIndex);
+            return self->getExternalForces(treeIndex);
           })
       .def(
           "getExternalForces",
           +[](dart::dynamics::Skeleton* self) -> const Eigen::VectorXd& {
-            return self->getCoriolisAndGravityForces();
+            return self->getExternalForces();
           })
       .def(
           "getConstraintForces",
