@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011-2019, The DART development contributors
+ * Copyright (c) 2011-2021, The DART development contributors
  * All rights reserved.
  *
  * The list of contributors can be found at:
@@ -32,27 +32,29 @@
 
 #include <array>
 #include <iostream>
-#include <gtest/gtest.h>
-#include "TestHelpers.hpp"
 
-#include "dart/math/Geometry.hpp"
-#include "dart/math/Helpers.hpp"
+#include <gtest/gtest.h>
+
 #include "dart/dynamics/BallJoint.hpp"
+#include "dart/dynamics/BodyNode.hpp"
+#include "dart/dynamics/EulerJoint.hpp"
 #include "dart/dynamics/FreeJoint.hpp"
+#include "dart/dynamics/PlanarJoint.hpp"
 #include "dart/dynamics/PrismaticJoint.hpp"
 #include "dart/dynamics/RevoluteJoint.hpp"
+#include "dart/dynamics/ScrewJoint.hpp"
+#include "dart/dynamics/Skeleton.hpp"
 #include "dart/dynamics/TranslationalJoint.hpp"
 #include "dart/dynamics/TranslationalJoint2D.hpp"
 #include "dart/dynamics/UniversalJoint.hpp"
 #include "dart/dynamics/WeldJoint.hpp"
-#include "dart/dynamics/EulerJoint.hpp"
-#include "dart/dynamics/ScrewJoint.hpp"
-#include "dart/dynamics/PlanarJoint.hpp"
-#include "dart/dynamics/BodyNode.hpp"
-#include "dart/dynamics/Skeleton.hpp"
+#include "dart/math/Geometry.hpp"
+#include "dart/math/Helpers.hpp"
 #include "dart/simulation/World.hpp"
 #include "dart/utils/SkelParser.hpp"
 
+#include "TestHelpers.hpp"
+
 using namespace dart;
 using namespace dart::math;
 using namespace dart::dynamics;
@@ -82,10 +84,10 @@ public:
   void kinematicsTest(
 #ifdef _WIN32
       const typename JointType::Properties& _joint
-          = BodyNode::createJointProperties<JointType>());
+      = createJointProperties<JointType>());
 #else
       const typename JointType::Properties& _joint
-          = typename JointType::Properties());
+      = typename JointType::Properties());
 #endif
 
 protected:
@@ -116,12 +118,13 @@ const std::vector<SimpleFrame*>& JOINTS::getFrames() const
 //==============================================================================
 void JOINTS::randomizeRefFrames()
 {
-  for(std::size_t i=0; i<frames.size(); ++i)
+  for (std::size_t i = 0; i < frames.size(); ++i)
   {
     SimpleFrame* F = frames[i];
 
     Eigen::Vector3d p = Random::uniform<Eigen::Vector3d>(-100, 100);
-    Eigen::Vector3d theta = Random::uniform<Eigen::Vector3d>(-2*M_PI, 2*M_PI);
+    Eigen::Vector3d theta = Random::uniform<Eigen::Vector3d>(
+        -2 * dart::math::constantsd::pi(), 2 * dart::math::constantsd::pi());
 
     Eigen::Isometry3d tf(Eigen::Isometry3d::Identity());
     tf.translate(p);
@@ -129,7 +132,8 @@ void JOINTS::randomizeRefFrames()
 
     F->setRelativeTransform(tf);
     F->setRelativeSpatialVelocity(Random::uniform<Eigen::Vector6d>(-100, 100));
-    F->setRelativeSpatialAcceleration(Random::uniform<Eigen::Vector6d>(-100, 100));
+    F->setRelativeSpatialAcceleration(
+        Random::uniform<Eigen::Vector6d>(-100, 100));
   }
 }
 
@@ -140,10 +144,12 @@ void JOINTS::kinematicsTest(const typename JointType::Properties& _properties)
   int numTests = 1;
 
   SkeletonPtr skeleton = Skeleton::create();
-  Joint* joint = skeleton->createJointAndBodyNodePair<JointType>(
-        nullptr, _properties).first;
+  Joint* joint
+      = skeleton->createJointAndBodyNodePair<JointType>(nullptr, _properties)
+            .first;
   joint->setTransformFromChildBodyNode(math::expMap(Eigen::Vector6d::Random()));
-  joint->setTransformFromParentBodyNode(math::expMap(Eigen::Vector6d::Random()));
+  joint->setTransformFromParentBodyNode(
+      math::expMap(Eigen::Vector6d::Random()));
 
   int dof = joint->getNumDofs();
 
@@ -159,8 +165,8 @@ void JOINTS::kinematicsTest(const typename JointType::Properties& _properties)
 
     for (int i = 0; i < dof; ++i)
     {
-      q(i) = Random::uniform(-constantsd::pi()*1.0, constantsd::pi()*1.0);
-      dq(i) = Random::uniform(-constantsd::pi()*1.0, constantsd::pi()*1.0);
+      q(i) = Random::uniform(-constantsd::pi() * 1.0, constantsd::pi() * 1.0);
+      dq(i) = Random::uniform(-constantsd::pi() * 1.0, constantsd::pi() * 1.0);
     }
 
     joint->setPositions(q);
@@ -182,7 +188,7 @@ void JOINTS::kinematicsTest(const typename JointType::Properties& _properties)
     // Test analytic Jacobian and numerical Jacobian
     // J == numericalJ
     //--------------------------------------------------------------------------
-    Jacobian numericJ = Jacobian::Zero(6,dof);
+    Jacobian numericJ = Jacobian::Zero(6, dof);
     for (int i = 0; i < dof; ++i)
     {
       // a
@@ -204,17 +210,17 @@ void JOINTS::kinematicsTest(const typename JointType::Properties& _properties)
       Eigen::Matrix4d T_a_eigen = T_a.matrix();
       Eigen::Matrix4d T_b_eigen = T_b.matrix();
       Eigen::Matrix4d dTdq_eigen = (T_b_eigen - T_a_eigen) / q_delta;
-      //Matrix4d dTdq_eigen = (T_b_eigen * T_a_eigen.inverse()) / dt;
+      // Matrix4d dTdq_eigen = (T_b_eigen * T_a_eigen.inverse()) / dt;
 
       // J(i)
       Eigen::Matrix4d Ji_4x4matrix_eigen = Tinv_a_eigen * dTdq_eigen;
       Eigen::Vector6d Ji;
-      Ji[0] = Ji_4x4matrix_eigen(2,1);
-      Ji[1] = Ji_4x4matrix_eigen(0,2);
-      Ji[2] = Ji_4x4matrix_eigen(1,0);
-      Ji[3] = Ji_4x4matrix_eigen(0,3);
-      Ji[4] = Ji_4x4matrix_eigen(1,3);
-      Ji[5] = Ji_4x4matrix_eigen(2,3);
+      Ji[0] = Ji_4x4matrix_eigen(2, 1);
+      Ji[1] = Ji_4x4matrix_eigen(0, 2);
+      Ji[2] = Ji_4x4matrix_eigen(1, 0);
+      Ji[3] = Ji_4x4matrix_eigen(0, 3);
+      Ji[4] = Ji_4x4matrix_eigen(1, 3);
+      Ji[5] = Ji_4x4matrix_eigen(2, 3);
       numericJ.col(i) = Ji;
     }
 
@@ -228,7 +234,7 @@ void JOINTS::kinematicsTest(const typename JointType::Properties& _properties)
     // Test first time derivative of analytic Jacobian and numerical Jacobian
     // dJ == numerical_dJ
     //--------------------------------------------------------------------------
-    Jacobian numeric_dJ = Jacobian::Zero(6,dof);
+    Jacobian numeric_dJ = Jacobian::Zero(6, dof);
     for (int i = 0; i < dof; ++i)
     {
       // a
@@ -312,7 +318,7 @@ TEST_F(JOINTS, TRANSLATIONAL_JOINT_2D)
 }
 
 // 3-dof joint
-//TEST_F(JOINTS, BALL_JOINT)
+// TEST_F(JOINTS, BALL_JOINT)
 //{
 //  kinematicsTest<BallJoint>();
 //}
@@ -346,7 +352,7 @@ TEST_F(JOINTS, PLANAR_JOINT)
 }
 
 // 6-dof joint
-//TEST_F(JOINTS, FREE_JOINT)
+// TEST_F(JOINTS, FREE_JOINT)
 //{
 //  kinematicsTest<FreeJoint>();
 //}
@@ -356,15 +362,16 @@ TEST_F(JOINTS, PLANAR_JOINT)
 // velocities and accelerations, repectively.
 
 //==============================================================================
-template <void (Joint::*setX)(std::size_t, double),
-          void (Joint::*setXLowerLimit)(std::size_t, double),
-          void (Joint::*setXUpperLimit)(std::size_t, double)>
+template <
+    void (Joint::*setX)(std::size_t, double),
+    void (Joint::*setXLowerLimit)(std::size_t, double),
+    void (Joint::*setXUpperLimit)(std::size_t, double)>
 void testCommandLimits(dynamics::Joint* joint)
 {
   const double lower = -5.0;
   const double upper = +5.0;
   const double mid = 0.5 * (lower + upper);
-  const double lessThanLower    = -10.0;
+  const double lessThanLower = -10.0;
   const double greaterThanUpper = +10.0;
 
   for (std::size_t i = 0; i < joint->getNumDofs(); ++i)
@@ -392,9 +399,8 @@ void testCommandLimits(dynamics::Joint* joint)
 //==============================================================================
 TEST_F(JOINTS, COMMAND_LIMIT)
 {
-  simulation::WorldPtr myWorld
-      = utils::SkelParser::readWorld(
-        "dart://sample/skel/test/joint_limit_test.skel");
+  simulation::WorldPtr myWorld = utils::SkelParser::readWorld(
+      "dart://sample/skel/test/joint_limit_test.skel");
   EXPECT_TRUE(myWorld != nullptr);
 
   dynamics::SkeletonPtr pendulum = myWorld->getSkeleton("double_pendulum");
@@ -434,9 +440,8 @@ TEST_F(JOINTS, POSITION_LIMIT)
 {
   double tol = 1e-3;
 
-  simulation::WorldPtr myWorld
-      = utils::SkelParser::readWorld(
-        "dart://sample/skel/test/joint_limit_test.skel");
+  simulation::WorldPtr myWorld = utils::SkelParser::readWorld(
+      "dart://sample/skel/test/joint_limit_test.skel");
   EXPECT_TRUE(myWorld != nullptr);
 
   myWorld->setGravity(Eigen::Vector3d(0.0, 0.0, 0.0));
@@ -453,11 +458,11 @@ TEST_F(JOINTS, POSITION_LIMIT)
   double limit0 = constantsd::pi() / 6.0;
   double limit1 = constantsd::pi() / 6.0;
 
-  joint0->setPositionLimitEnforced(true);
+  joint0->setLimitEnforcement(true);
   joint0->setPositionLowerLimit(0, -limit0);
   joint0->setPositionUpperLimit(0, limit0);
 
-  joint1->setPositionLimitEnforced(true);
+  joint1->setLimitEnforcement(true);
   joint1->setPositionLowerLimit(0, -limit1);
   joint1->setPositionUpperLimit(0, limit1);
 
@@ -504,12 +509,109 @@ TEST_F(JOINTS, POSITION_LIMIT)
   }
 }
 
+//==============================================================================
+TEST_F(JOINTS, POSITION_AND_VELOCITY_LIMIT)
+{
+  using namespace dart::math::suffixes;
+
+  const double tol = 1e-3;
+
+  simulation::WorldPtr myWorld = utils::SkelParser::readWorld(
+      "dart://sample/skel/test/joint_limit_test.skel");
+  EXPECT_TRUE(myWorld != nullptr);
+
+  myWorld->setGravity(Eigen::Vector3d(0.0, 0.0, 0.0));
+
+  dynamics::SkeletonPtr pendulum = myWorld->getSkeleton("double_pendulum");
+  EXPECT_TRUE(pendulum != nullptr);
+
+  dynamics::Joint* joint0 = pendulum->getJoint("joint0");
+  dynamics::Joint* joint1 = pendulum->getJoint("joint1");
+
+  EXPECT_TRUE(joint0 != nullptr);
+  EXPECT_TRUE(joint1 != nullptr);
+
+  const double posLimit0 = math::toRadian(360.0);
+  const double posLimit1 = math::toRadian(360.0);
+  const double velLimit0 = math::toRadian(5.0); // 5 degree per second
+  const double velLimit1 = math::toRadian(5.0); // 5 degree per second
+
+  joint0->setLimitEnforcement(true);
+  joint0->setPositionLowerLimit(0, -posLimit0);
+  joint0->setPositionUpperLimit(0, posLimit0);
+  joint0->setVelocityLowerLimit(0, -velLimit0);
+  joint0->setVelocityUpperLimit(0, velLimit0);
+
+  joint1->setLimitEnforcement(true);
+  joint1->setPositionLowerLimit(0, -posLimit1);
+  joint1->setPositionUpperLimit(0, posLimit1);
+  joint1->setVelocityLowerLimit(0, -velLimit1);
+  joint1->setVelocityUpperLimit(0, velLimit1);
+
+#ifndef NDEBUG // Debug mode
+  double simTime = 0.2;
+#else
+  double simTime = 2.0;
+#endif // ------- Debug mode
+  double timeStep = myWorld->getTimeStep();
+  int nSteps = simTime / timeStep;
+
+  // Two seconds with positive control forces
+  for (int i = 0; i < nSteps; i++)
+  {
+    // Apply sufficient force to hit the limits
+    joint0->setForce(0, 1.0);
+    joint1->setForce(0, 1.0);
+    myWorld->step();
+
+    // Check position limits
+    const double jointPos0 = joint0->getPosition(0);
+    const double jointPos1 = joint1->getPosition(0);
+    EXPECT_GE(jointPos0, -posLimit0 - tol);
+    EXPECT_GE(jointPos1, -posLimit1 - tol);
+    EXPECT_LE(jointPos0, posLimit0 + tol);
+    EXPECT_LE(jointPos1, posLimit1 + tol);
+
+    // Check velocity limits
+    const double jointVel0 = joint0->getVelocity(0);
+    const double jointVel1 = joint1->getVelocity(0);
+    EXPECT_GE(jointVel0, -velLimit0 - tol);
+    EXPECT_GE(jointVel1, -velLimit1 - tol);
+    EXPECT_LE(jointVel0, velLimit0 + tol);
+    EXPECT_LE(jointVel1, velLimit1 + tol);
+  }
+
+  // Two more seconds with negative control forces
+  for (int i = 0; i < nSteps; i++)
+  {
+    // Apply sufficient force to hit the limits
+    joint0->setForce(0, -1.0);
+    joint1->setForce(0, -1.0);
+    myWorld->step();
+
+    // Check position limits
+    const double jointPos0 = joint0->getPosition(0);
+    const double jointPos1 = joint1->getPosition(0);
+    EXPECT_GE(jointPos0, -posLimit0 - tol);
+    EXPECT_GE(jointPos1, -posLimit1 - tol);
+    EXPECT_LE(jointPos0, posLimit0 + tol);
+    EXPECT_LE(jointPos1, posLimit1 + tol);
+
+    // Check velocity limits
+    const double jointVel0 = joint0->getVelocity(0);
+    const double jointVel1 = joint1->getVelocity(0);
+    EXPECT_GE(jointVel0, -velLimit0 - tol);
+    EXPECT_GE(jointVel1, -velLimit1 - tol);
+    EXPECT_LE(jointVel0, velLimit0 + tol);
+    EXPECT_LE(jointVel1, velLimit1 + tol);
+  }
+}
+
 //==============================================================================
 TEST_F(JOINTS, JOINT_LIMITS)
 {
-  simulation::WorldPtr myWorld
-      = utils::SkelParser::readWorld(
-        "dart://sample/skel/test/joint_limit_test.skel");
+  simulation::WorldPtr myWorld = utils::SkelParser::readWorld(
+      "dart://sample/skel/test/joint_limit_test.skel");
   EXPECT_TRUE(myWorld != nullptr);
 
   myWorld->setGravity(Eigen::Vector3d(0.0, 0.0, 0.0));
@@ -551,9 +653,11 @@ TEST_F(JOINTS, JOINT_LIMITS)
   joint0->setAccelerationLowerLimit(0, -limit);
   joint0->setAccelerationUpperLimit(0, limit);
   EXPECT_EQ(
-      joint0->getAccelerationLowerLimits(), Eigen::VectorXd::Constant(1, -limit));
+      joint0->getAccelerationLowerLimits(),
+      Eigen::VectorXd::Constant(1, -limit));
   EXPECT_EQ(
-      joint0->getAccelerationUpperLimits(), Eigen::VectorXd::Constant(1, limit));
+      joint0->getAccelerationUpperLimits(),
+      Eigen::VectorXd::Constant(1, limit));
 
   joint0->setAccelerationLowerLimits(-limits);
   joint0->setAccelerationUpperLimits(limits);
@@ -564,8 +668,7 @@ TEST_F(JOINTS, JOINT_LIMITS)
   joint0->setForceUpperLimit(0, limit);
   EXPECT_EQ(
       joint0->getForceLowerLimits(), Eigen::VectorXd::Constant(1, -limit));
-  EXPECT_EQ(
-      joint0->getForceUpperLimits(), Eigen::VectorXd::Constant(1, limit));
+  EXPECT_EQ(joint0->getForceUpperLimits(), Eigen::VectorXd::Constant(1, limit));
 
   joint0->setForceLowerLimits(-limits);
   joint0->setForceUpperLimits(limits);
@@ -578,9 +681,8 @@ void testJointCoulombFrictionForce(double _timeStep)
 {
   double tol = 1e-9;
 
-  simulation::WorldPtr myWorld
-      = utils::SkelParser::readWorld(
-        "dart://sample/skel/test/joint_friction_test.skel");
+  simulation::WorldPtr myWorld = utils::SkelParser::readWorld(
+      "dart://sample/skel/test/joint_friction_test.skel");
   EXPECT_TRUE(myWorld != nullptr);
 
   myWorld->setGravity(Eigen::Vector3d(0.0, 0.0, 0.0));
@@ -596,10 +698,10 @@ void testJointCoulombFrictionForce(double _timeStep)
   EXPECT_TRUE(joint0 != nullptr);
   EXPECT_TRUE(joint1 != nullptr);
 
-  double frictionForce  = 5.0;
+  double frictionForce = 5.0;
 
-  joint0->setPositionLimitEnforced(false);
-  joint1->setPositionLimitEnforced(false);
+  joint0->setLimitEnforcement(false);
+  joint1->setLimitEnforcement(false);
 
   joint0->setCoulombFriction(0, frictionForce);
   joint1->setCoulombFriction(0, frictionForce);
@@ -723,12 +825,61 @@ SkeletonPtr createPendulum(Joint::ActuatorType actType)
   joint->setPosition(0, 90.0_deg);
   joint->setDampingCoefficient(0, 0.0);
   joint->setSpringStiffness(0, 0.0);
-  joint->setPositionLimitEnforced(true);
+  joint->setLimitEnforcement(true);
   joint->setCoulombFriction(0, 0.0);
 
   return pendulum;
 }
 
+//==============================================================================
+TEST_F(JOINTS, SpringRestPosition)
+{
+  using namespace math::suffixes;
+
+  auto skel = createPendulum(Joint::ActuatorType::PASSIVE);
+  ASSERT_NE(skel, nullptr);
+
+  auto joint = skel->getRootJoint();
+  ASSERT_NE(joint, nullptr);
+
+  auto world = simulation::World::create();
+  ASSERT_NE(world, nullptr);
+
+  world->addSkeleton(skel);
+  world->setGravity(Eigen::Vector3d::Zero());
+
+  joint->setPosition(0, 0);
+  joint->setRestPosition(0, -1.0_pi);
+  joint->setPositionLowerLimit(0, -0.5_pi);
+  joint->setPositionUpperLimit(0, +0.5_pi);
+  joint->setSpringStiffness(0, 5);
+
+  EXPECT_DOUBLE_EQ(joint->getPosition(0), 0);
+
+  const auto tol = 1e-3;
+
+  // Joint starts from 0 and rotates towards its spring rest position (i.e.,
+  // -pi), but it also should stay within the joint limits
+  // (i.e., [-0.5pi, 0.5pi]).
+  for (auto i = 0u; i < 1000; ++i)
+  {
+    world->step();
+    const auto pos = joint->getPosition(0);
+    EXPECT_GE(pos, joint->getPositionLowerLimit(0) - tol);
+    EXPECT_LE(pos, joint->getPositionUpperLimit(0) + tol);
+  }
+
+  // After a while, the joint should come to rest at its lower position limit.
+  for (auto i = 0u; i < 500; ++i)
+  {
+    world->step();
+    const auto pos = joint->getPosition(0);
+    EXPECT_GE(pos, joint->getPositionLowerLimit(0) - tol);
+    EXPECT_LE(pos, joint->getPositionUpperLimit(0) + tol);
+    EXPECT_NEAR(pos, joint->getPositionLowerLimit(0), tol);
+  }
+}
+
 //==============================================================================
 void testServoMotor()
 {
@@ -739,7 +890,7 @@ void testServoMotor()
   double tol = 1e-9;
   double posUpperLimit = 90.0_deg;
   double posLowerLimit = 45.0_deg;
-  double sufficient_force   = 1e+5;
+  double sufficient_force = 1e+5;
   double insufficient_force = 1e-1;
 
   // World
@@ -853,15 +1004,19 @@ void testServoMotor()
     EXPECT_NEAR(jointVels[0], 0.0, tol);
     EXPECT_NEAR(jointVels[1], expected_vel, tol);
     bool result2 = std::abs(jointVels[2] - expected_vel) < tol
-        || std::abs(joints[2]->getConstraintImpulse(0) / timeStep
-           - insufficient_force) < tol
-        || std::abs(joints[2]->getConstraintImpulse(0) / timeStep
-           + insufficient_force) < tol;
+                   || std::abs(
+                          joints[2]->getConstraintImpulse(0) / timeStep
+                          - insufficient_force)
+                          < tol
+                   || std::abs(
+                          joints[2]->getConstraintImpulse(0) / timeStep
+                          + insufficient_force)
+                          < tol;
     EXPECT_TRUE(result2);
-    EXPECT_LE(joints[3]->getPosition(0),
-        posUpperLimit + expected_vel * timeStep);
-    EXPECT_GE(joints[3]->getPosition(0),
-        posLowerLimit - expected_vel * timeStep);
+    EXPECT_LE(
+        joints[3]->getPosition(0), posUpperLimit + expected_vel * timeStep);
+    EXPECT_GE(
+        joints[3]->getPosition(0), posLowerLimit - expected_vel * timeStep);
     // EXPECT_LE(joints[4]->getPosition(0),
     //     posUpperLimit + expected_vel * timeStep);
     // EXPECT_GE(joints[4]->getPosition(0),
@@ -893,7 +1048,7 @@ void testMimicJoint()
   double timestep = 1e-3;
   double tol = 1e-9;
   double tolPos = 1e-3;
-  double sufficient_force   = 1e+5;
+  double sufficient_force = 1e+5;
 
   // World
   simulation::WorldPtr world = simulation::World::create();
@@ -927,7 +1082,7 @@ void testMimicJoint()
     joint->setPosition(0, 90.0_deg);
     joint->setDampingCoefficient(0, 0.0);
     joint->setSpringStiffness(0, 0.0);
-    joint->setPositionLimitEnforced(true);
+    joint->setLimitEnforcement(true);
     joint->setCoulombFriction(0, 0.0);
 
     joints[i] = joint;
@@ -985,9 +1140,8 @@ TEST_F(JOINTS, JOINT_COULOMB_FRICTION_AND_POSITION_LIMIT)
   const double timeStep = 1e-3;
   const double tol = 1e-2;
 
-  simulation::WorldPtr myWorld
-      = utils::SkelParser::readWorld(
-        "dart://sample/skel/test/joint_friction_test.skel");
+  simulation::WorldPtr myWorld = utils::SkelParser::readWorld(
+      "dart://sample/skel/test/joint_friction_test.skel");
   EXPECT_TRUE(myWorld != nullptr);
 
   myWorld->setGravity(Eigen::Vector3d(0.0, 0.0, 0.0));
@@ -1003,13 +1157,13 @@ TEST_F(JOINTS, JOINT_COULOMB_FRICTION_AND_POSITION_LIMIT)
   EXPECT_TRUE(joint0 != nullptr);
   EXPECT_TRUE(joint1 != nullptr);
 
-  double frictionForce  = 5.0;
+  double frictionForce = 5.0;
 
-  joint0->setPositionLimitEnforced(true);
-  joint1->setPositionLimitEnforced(true);
+  joint0->setLimitEnforcement(true);
+  joint1->setLimitEnforcement(true);
 
-  const double ll = -constantsd::pi()/12.0; // -15 degree
-  const double ul = +constantsd::pi()/12.0; // +15 degree
+  const double ll = -constantsd::pi() / 12.0; // -15 degree
+  const double ul = +constantsd::pi() / 12.0; // +15 degree
 
   std::size_t dof0 = joint0->getNumDofs();
   for (std::size_t i = 0; i < dof0; ++i)
@@ -1092,18 +1246,19 @@ TEST_F(JOINTS, JOINT_COULOMB_FRICTION_AND_POSITION_LIMIT)
 }
 
 //==============================================================================
-template<int N>
-Eigen::Matrix<double,N,1> random_vec(double limit=100)
+template <int N>
+Eigen::Matrix<double, N, 1> random_vec(double limit = 100)
 {
-  Eigen::Matrix<double,N,1> v;
-  for(std::size_t i=0; i<N; ++i)
+  Eigen::Matrix<double, N, 1> v;
+  for (std::size_t i = 0; i < N; ++i)
     v[i] = math::Random::uniform(-std::abs(limit), std::abs(limit));
   return v;
 }
 
 //==============================================================================
-Eigen::Isometry3d random_transform(double translation_limit=100,
-                                   double rotation_limit=2*M_PI)
+Eigen::Isometry3d random_transform(
+    double translation_limit = 100,
+    double rotation_limit = 2 * dart::math::constantsd::pi())
 {
   Eigen::Vector3d r = random_vec<3>(translation_limit);
   Eigen::Vector3d theta = random_vec<3>(rotation_limit);
@@ -1112,18 +1267,18 @@ Eigen::Isometry3d random_transform(double translation_limit=100,
   tf.setIdentity();
   tf.translate(r);
 
-  if(theta.norm()>0)
+  if (theta.norm() > 0)
     tf.rotate(Eigen::AngleAxisd(theta.norm(), theta.normalized()));
 
   return tf;
 }
 
 //==============================================================================
-Eigen::Isometry3d predict_joint_transform(Joint* joint,
-                                          const Eigen::Isometry3d& joint_tf)
+Eigen::Isometry3d predict_joint_transform(
+    Joint* joint, const Eigen::Isometry3d& joint_tf)
 {
   return joint->getTransformFromParentBodyNode() * joint_tf
-          * joint->getTransformFromChildBodyNode().inverse();
+         * joint->getTransformFromChildBodyNode().inverse();
 }
 
 //==============================================================================
@@ -1143,8 +1298,8 @@ TEST_F(JOINTS, CONVENIENCE_FUNCTIONS)
   BodyNode* root = pair.second;
 
   // -- set up the FreeJoint
-  std::pair<FreeJoint*, BodyNode*> freepair =
-      root->createChildJointAndBodyNodePair<FreeJoint>();
+  std::pair<FreeJoint*, BodyNode*> freepair
+      = root->createChildJointAndBodyNodePair<FreeJoint>();
   FreeJoint* freejoint = freepair.first;
   BodyNode* freejoint_bn = freepair.second;
 
@@ -1152,8 +1307,8 @@ TEST_F(JOINTS, CONVENIENCE_FUNCTIONS)
   freejoint->setTransformFromChildBodyNode(random_transform());
 
   // -- set up the EulerJoint
-  std::pair<EulerJoint*, BodyNode*> eulerpair =
-      root->createChildJointAndBodyNodePair<EulerJoint>();
+  std::pair<EulerJoint*, BodyNode*> eulerpair
+      = root->createChildJointAndBodyNodePair<EulerJoint>();
   EulerJoint* eulerjoint = eulerpair.first;
   BodyNode* eulerjoint_bn = eulerpair.second;
 
@@ -1161,8 +1316,8 @@ TEST_F(JOINTS, CONVENIENCE_FUNCTIONS)
   eulerjoint->setTransformFromChildBodyNode(random_transform());
 
   // -- set up the BallJoint
-  std::pair<BallJoint*, BodyNode*> ballpair =
-      root->createChildJointAndBodyNodePair<BallJoint>();
+  std::pair<BallJoint*, BodyNode*> ballpair
+      = root->createChildJointAndBodyNodePair<BallJoint>();
   BallJoint* balljoint = ballpair.first;
   BodyNode* balljoint_bn = ballpair.second;
 
@@ -1170,27 +1325,28 @@ TEST_F(JOINTS, CONVENIENCE_FUNCTIONS)
   balljoint->setTransformFromChildBodyNode(random_transform());
 
   // Test a hundred times
-  for(std::size_t n=0; n<100; ++n)
+  for (std::size_t n = 0; n < 100; ++n)
   {
     // -- convert transforms to positions and then positions back to transforms
     Eigen::Isometry3d desired_freejoint_tf = random_transform();
-    freejoint->setPositions(FreeJoint::convertToPositions(desired_freejoint_tf));
-    Eigen::Isometry3d actual_freejoint_tf = FreeJoint::convertToTransform(
-          freejoint->getPositions());
+    freejoint->setPositions(
+        FreeJoint::convertToPositions(desired_freejoint_tf));
+    Eigen::Isometry3d actual_freejoint_tf
+        = FreeJoint::convertToTransform(freejoint->getPositions());
 
     Eigen::Isometry3d desired_eulerjoint_tf = random_transform();
     desired_eulerjoint_tf.translation() = Eigen::Vector3d::Zero();
     eulerjoint->setPositions(
-          eulerjoint->convertToPositions(desired_eulerjoint_tf.linear()));
-    Eigen::Isometry3d actual_eulerjoint_tf = eulerjoint->convertToTransform(
-          eulerjoint->getPositions());
+        eulerjoint->convertToPositions(desired_eulerjoint_tf.linear()));
+    Eigen::Isometry3d actual_eulerjoint_tf
+        = eulerjoint->convertToTransform(eulerjoint->getPositions());
 
     Eigen::Isometry3d desired_balljoint_tf = random_transform();
     desired_balljoint_tf.translation() = Eigen::Vector3d::Zero();
     balljoint->setPositions(
-          BallJoint::convertToPositions(desired_balljoint_tf.linear()));
-    Eigen::Isometry3d actual_balljoint_tf = BallJoint::convertToTransform(
-          balljoint->getPositions());
+        BallJoint::convertToPositions(desired_balljoint_tf.linear()));
+    Eigen::Isometry3d actual_balljoint_tf
+        = BallJoint::convertToTransform(balljoint->getPositions());
 
     // -- collect everything so we can cycle through the tests
     std::vector<Joint*> joints;
@@ -1213,36 +1369,37 @@ TEST_F(JOINTS, CONVENIENCE_FUNCTIONS)
     desired_tfs.push_back(desired_balljoint_tf);
     actual_tfs.push_back(actual_balljoint_tf);
 
-    for(std::size_t i=0; i<joints.size(); ++i)
+    for (std::size_t i = 0; i < joints.size(); ++i)
     {
       Joint* joint = joints[i];
       BodyNode* bn = bns[i];
       Eigen::Isometry3d tf = desired_tfs[i];
 
-      bool check_transform_conversion =
-          equals(predict_joint_transform(joint, tf).matrix(),
-                 get_relative_transform(bn, bn->getParentBodyNode()).matrix());
+      bool check_transform_conversion = equals(
+          predict_joint_transform(joint, tf).matrix(),
+          get_relative_transform(bn, bn->getParentBodyNode()).matrix());
       EXPECT_TRUE(check_transform_conversion);
 
-      if(!check_transform_conversion)
+      if (!check_transform_conversion)
       {
         std::cout << "[" << joint->getName() << " Failed]\n";
-        std::cout << "Predicted:\n" << predict_joint_transform(joint, tf).matrix()
-                  << "\n\nActual:\n"
-                  << get_relative_transform(bn, bn->getParentBodyNode()).matrix()
-                  << "\n\n";
+        std::cout
+            << "Predicted:\n"
+            << predict_joint_transform(joint, tf).matrix() << "\n\nActual:\n"
+            << get_relative_transform(bn, bn->getParentBodyNode()).matrix()
+            << "\n\n";
       }
 
-      bool check_full_cycle = equals(desired_tfs[i].matrix(),
-                                     actual_tfs[i].matrix());
+      bool check_full_cycle
+          = equals(desired_tfs[i].matrix(), actual_tfs[i].matrix());
       EXPECT_TRUE(check_full_cycle);
 
-      if(!check_full_cycle)
+      if (!check_full_cycle)
       {
         std::cout << "[" << joint->getName() << " Failed]\n";
-        std::cout << "Desired:\n" << desired_tfs[i].matrix()
-                  << "\n\nActual:\n" << actual_tfs[i].matrix()
-                  << "\n\n";
+        std::cout << "Desired:\n"
+                  << desired_tfs[i].matrix() << "\n\nActual:\n"
+                  << actual_tfs[i].matrix() << "\n\n";
       }
     }
   }
@@ -1265,8 +1422,8 @@ TEST_F(JOINTS, FREE_JOINT_RELATIVE_TRANSFORM_VELOCITY_ACCELERATION)
   SkeletonPtr skel = Skeleton::create();
 
   auto pair = skel->createJointAndBodyNodePair<FreeJoint>();
-  FreeJoint* rootJoint    = pair.first;
-  BodyNode*  rootBodyNode = pair.second;
+  FreeJoint* rootJoint = pair.first;
+  BodyNode* rootBodyNode = pair.second;
   rootJoint->setRelativeTransform(random_transform());
   rootJoint->setRelativeSpatialVelocity(random_vec<6>());
   rootJoint->setRelativeSpatialAcceleration(random_vec<6>());
@@ -1274,36 +1431,36 @@ TEST_F(JOINTS, FREE_JOINT_RELATIVE_TRANSFORM_VELOCITY_ACCELERATION)
   rootJoint->setTransformFromChildBodyNode(random_transform());
 
   pair = rootBodyNode->createChildJointAndBodyNodePair<FreeJoint>();
-  FreeJoint* joint1    = pair.first;
-  BodyNode*  bodyNode1 = pair.second;
+  FreeJoint* joint1 = pair.first;
+  BodyNode* bodyNode1 = pair.second;
   joint1->setTransformFromParentBodyNode(random_transform());
   joint1->setTransformFromChildBodyNode(random_transform());
 
   //-- Actual terms
   Eigen::Isometry3d actualTf;
-  Eigen::Vector6d   actualVel;
-  Eigen::Vector6d   actualAcc;
+  Eigen::Vector6d actualVel;
+  Eigen::Vector6d actualAcc;
 
-  Eigen::Vector3d   actualLinVel;
-  Eigen::Vector3d   actualAngVel;
-  Eigen::Vector3d   actualLinAcc;
-  Eigen::Vector3d   actualAngAcc;
+  Eigen::Vector3d actualLinVel;
+  Eigen::Vector3d actualAngVel;
+  Eigen::Vector3d actualLinAcc;
+  Eigen::Vector3d actualAngAcc;
 
-  Eigen::Vector3d   oldLinVel;
-  Eigen::Vector3d   oldAngVel;
-  Eigen::Vector3d   oldLinAcc;
-  Eigen::Vector3d   oldAngAcc;
+  Eigen::Vector3d oldLinVel;
+  Eigen::Vector3d oldAngVel;
+  Eigen::Vector3d oldLinAcc;
+  Eigen::Vector3d oldAngAcc;
 
   //-- Test
   for (std::size_t i = 0; i < numTests; ++i)
   {
-    const Eigen::Isometry3d desiredTf     = random_transform();
-    const Eigen::Vector6d   desiredVel    = random_vec<6>();
-    const Eigen::Vector6d   desiredAcc    = random_vec<6>();
-    const Eigen::Vector3d   desiredLinVel = random_vec<3>();
-    const Eigen::Vector3d   desiredAngVel = random_vec<3>();
-    const Eigen::Vector3d   desiredLinAcc = random_vec<3>();
-    const Eigen::Vector3d   desiredAngAcc = random_vec<3>();
+    const Eigen::Isometry3d desiredTf = random_transform();
+    const Eigen::Vector6d desiredVel = random_vec<6>();
+    const Eigen::Vector6d desiredAcc = random_vec<6>();
+    const Eigen::Vector3d desiredLinVel = random_vec<3>();
+    const Eigen::Vector3d desiredAngVel = random_vec<3>();
+    const Eigen::Vector3d desiredLinAcc = random_vec<3>();
+    const Eigen::Vector3d desiredAngAcc = random_vec<3>();
 
     //-- Relative transformation
 
@@ -1322,7 +1479,7 @@ TEST_F(JOINTS, FREE_JOINT_RELATIVE_TRANSFORM_VELOCITY_ACCELERATION)
 
     joint1->setRelativeSpatialVelocity(desiredVel);
     actualVel = bodyNode1->getSpatialVelocity(
-                  bodyNode1->getParentBodyNode(), bodyNode1);
+        bodyNode1->getParentBodyNode(), bodyNode1);
 
     EXPECT_TRUE(equals(desiredVel, actualVel));
 
@@ -1331,8 +1488,7 @@ TEST_F(JOINTS, FREE_JOINT_RELATIVE_TRANSFORM_VELOCITY_ACCELERATION)
       for (auto inCoordinatesOf : refFrames)
       {
         joint1->setSpatialVelocity(desiredVel, relativeTo, inCoordinatesOf);
-        actualVel = bodyNode1->getSpatialVelocity(
-                      relativeTo, inCoordinatesOf);
+        actualVel = bodyNode1->getSpatialVelocity(relativeTo, inCoordinatesOf);
 
         EXPECT_TRUE(equals(desiredVel, actualVel));
       }
@@ -1345,8 +1501,7 @@ TEST_F(JOINTS, FREE_JOINT_RELATIVE_TRANSFORM_VELOCITY_ACCELERATION)
       for (auto inCoordinatesOf : refFrames)
       {
         joint1->setSpatialVelocity(desiredVel, relativeTo, inCoordinatesOf);
-        oldAngVel
-            = bodyNode1->getAngularVelocity(relativeTo, inCoordinatesOf);
+        oldAngVel = bodyNode1->getAngularVelocity(relativeTo, inCoordinatesOf);
         joint1->setLinearVelocity(desiredLinVel, relativeTo, inCoordinatesOf);
 
         actualLinVel
@@ -1366,14 +1521,13 @@ TEST_F(JOINTS, FREE_JOINT_RELATIVE_TRANSFORM_VELOCITY_ACCELERATION)
       for (auto inCoordinatesOf : refFrames)
       {
         joint1->setSpatialVelocity(desiredVel, relativeTo, inCoordinatesOf);
-        oldLinVel
-            = bodyNode1->getLinearVelocity(relativeTo, inCoordinatesOf);
+        oldLinVel = bodyNode1->getLinearVelocity(relativeTo, inCoordinatesOf);
         joint1->setAngularVelocity(desiredAngVel, relativeTo, inCoordinatesOf);
 
-        actualLinVel =
-            bodyNode1->getLinearVelocity(relativeTo, inCoordinatesOf);
-        actualAngVel =
-            bodyNode1->getAngularVelocity(relativeTo, inCoordinatesOf);
+        actualLinVel
+            = bodyNode1->getLinearVelocity(relativeTo, inCoordinatesOf);
+        actualAngVel
+            = bodyNode1->getAngularVelocity(relativeTo, inCoordinatesOf);
 
         EXPECT_TRUE(equals(oldLinVel, actualLinVel));
         EXPECT_TRUE(equals(desiredAngVel, actualAngVel));
@@ -1384,7 +1538,7 @@ TEST_F(JOINTS, FREE_JOINT_RELATIVE_TRANSFORM_VELOCITY_ACCELERATION)
 
     joint1->setRelativeSpatialAcceleration(desiredAcc);
     actualAcc = bodyNode1->getSpatialAcceleration(
-                  bodyNode1->getParentBodyNode(), bodyNode1);
+        bodyNode1->getParentBodyNode(), bodyNode1);
 
     EXPECT_TRUE(equals(desiredAcc, actualAcc));
 
@@ -1392,10 +1546,9 @@ TEST_F(JOINTS, FREE_JOINT_RELATIVE_TRANSFORM_VELOCITY_ACCELERATION)
     {
       for (auto inCoordinatesOf : refFrames)
       {
-        joint1->setSpatialAcceleration(
-              desiredAcc, relativeTo, inCoordinatesOf);
-        actualAcc = bodyNode1->getSpatialAcceleration(
-                      relativeTo, inCoordinatesOf);
+        joint1->setSpatialAcceleration(desiredAcc, relativeTo, inCoordinatesOf);
+        actualAcc
+            = bodyNode1->getSpatialAcceleration(relativeTo, inCoordinatesOf);
 
         EXPECT_TRUE(equals(desiredAcc, actualAcc));
       }
@@ -1407,14 +1560,18 @@ TEST_F(JOINTS, FREE_JOINT_RELATIVE_TRANSFORM_VELOCITY_ACCELERATION)
       for (auto inCoordinatesOf : refFrames)
       {
         joint1->setSpatialMotion(
-              &desiredTf, relativeTo,
-              &desiredVel, relativeTo, inCoordinatesOf,
-              &desiredAcc, relativeTo, inCoordinatesOf);
+            &desiredTf,
+            relativeTo,
+            &desiredVel,
+            relativeTo,
+            inCoordinatesOf,
+            &desiredAcc,
+            relativeTo,
+            inCoordinatesOf);
         actualTf = bodyNode1->getTransform(relativeTo);
-        actualVel = bodyNode1->getSpatialVelocity(
-                      relativeTo, inCoordinatesOf);
-        actualAcc = bodyNode1->getSpatialAcceleration(
-                      relativeTo, inCoordinatesOf);
+        actualVel = bodyNode1->getSpatialVelocity(relativeTo, inCoordinatesOf);
+        actualAcc
+            = bodyNode1->getSpatialAcceleration(relativeTo, inCoordinatesOf);
 
         EXPECT_TRUE(equals(desiredTf.matrix(), actualTf.matrix()));
         EXPECT_TRUE(equals(desiredVel, actualVel));
@@ -1422,19 +1579,17 @@ TEST_F(JOINTS, FREE_JOINT_RELATIVE_TRANSFORM_VELOCITY_ACCELERATION)
       }
     }
 
-
     //-- Relative classic linear acceleration
 
     for (auto relativeTo : relFrames)
     {
       for (auto inCoordinatesOf : refFrames)
       {
-        joint1->setSpatialAcceleration(
-              desiredAcc, relativeTo, inCoordinatesOf);
+        joint1->setSpatialAcceleration(desiredAcc, relativeTo, inCoordinatesOf);
         oldAngAcc
             = bodyNode1->getAngularAcceleration(relativeTo, inCoordinatesOf);
         joint1->setLinearAcceleration(
-              desiredLinAcc, relativeTo, inCoordinatesOf);
+            desiredLinAcc, relativeTo, inCoordinatesOf);
 
         actualLinAcc
             = bodyNode1->getLinearAcceleration(relativeTo, inCoordinatesOf);
@@ -1452,17 +1607,16 @@ TEST_F(JOINTS, FREE_JOINT_RELATIVE_TRANSFORM_VELOCITY_ACCELERATION)
     {
       for (auto inCoordinatesOf : refFrames)
       {
-        joint1->setSpatialAcceleration(
-              desiredAcc, relativeTo, inCoordinatesOf);
+        joint1->setSpatialAcceleration(desiredAcc, relativeTo, inCoordinatesOf);
         oldLinAcc
             = bodyNode1->getLinearAcceleration(relativeTo, inCoordinatesOf);
         joint1->setAngularAcceleration(
-              desiredAngAcc, relativeTo, inCoordinatesOf);
+            desiredAngAcc, relativeTo, inCoordinatesOf);
 
-        actualLinAcc =
-            bodyNode1->getLinearAcceleration(relativeTo, inCoordinatesOf);
-        actualAngAcc =
-            bodyNode1->getAngularAcceleration(relativeTo, inCoordinatesOf);
+        actualLinAcc
+            = bodyNode1->getLinearAcceleration(relativeTo, inCoordinatesOf);
+        actualAngAcc
+            = bodyNode1->getAngularAcceleration(relativeTo, inCoordinatesOf);
 
         EXPECT_TRUE(equals(oldLinAcc, actualLinAcc));
         EXPECT_TRUE(equals(desiredAngAcc, actualAngAcc));
