@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011-2019, The DART development contributors
+ * Copyright (c) 2011-2021, The DART development contributors
  * All rights reserved.
  *
  * The list of contributors can be found at:
@@ -31,16 +31,18 @@
  */
 
 #include <iostream>
+
 #include <gtest/gtest.h>
-#include "TestHelpers.hpp"
 
 #include "dart/common/sub_ptr.hpp"
-#include "dart/math/Geometry.hpp"
-#include "dart/utils/SkelParser.hpp"
 #include "dart/dynamics/BodyNode.hpp"
 #include "dart/dynamics/RevoluteJoint.hpp"
 #include "dart/dynamics/Skeleton.hpp"
+#include "dart/math/Geometry.hpp"
 #include "dart/simulation/World.hpp"
+#include "dart/utils/SkelParser.hpp"
+
+#include "TestHelpers.hpp"
 
 using namespace dart;
 using namespace math;
@@ -53,19 +55,25 @@ std::vector<common::Uri> getFileList()
   std::vector<common::Uri> fileList;
   fileList.push_back("dart://sample/skel/test/chainwhipa.skel");
   fileList.push_back("dart://sample/skel/test/single_pendulum.skel");
-  fileList.push_back("dart://sample/skel/test/single_pendulum_euler_joint.skel");
+  fileList.push_back(
+      "dart://sample/skel/test/single_pendulum_euler_joint.skel");
   fileList.push_back("dart://sample/skel/test/single_pendulum_ball_joint.skel");
   fileList.push_back("dart://sample/skel/test/double_pendulum.skel");
-  fileList.push_back("dart://sample/skel/test/double_pendulum_euler_joint.skel");
+  fileList.push_back(
+      "dart://sample/skel/test/double_pendulum_euler_joint.skel");
   fileList.push_back("dart://sample/skel/test/double_pendulum_ball_joint.skel");
-  fileList.push_back("dart://sample/skel/test/serial_chain_revolute_joint.skel");
-  fileList.push_back("dart://sample/skel/test/serial_chain_eulerxyz_joint.skel");
+  fileList.push_back(
+      "dart://sample/skel/test/serial_chain_revolute_joint.skel");
+  fileList.push_back(
+      "dart://sample/skel/test/serial_chain_eulerxyz_joint.skel");
   fileList.push_back("dart://sample/skel/test/serial_chain_ball_joint.skel");
   fileList.push_back("dart://sample/skel/test/serial_chain_ball_joint_20.skel");
   fileList.push_back("dart://sample/skel/test/serial_chain_ball_joint_40.skel");
   fileList.push_back("dart://sample/skel/test/simple_tree_structure.skel");
-  fileList.push_back("dart://sample/skel/test/simple_tree_structure_euler_joint.skel");
-  fileList.push_back("dart://sample/skel/test/simple_tree_structure_ball_joint.skel");
+  fileList.push_back(
+      "dart://sample/skel/test/simple_tree_structure_euler_joint.skel");
+  fileList.push_back(
+      "dart://sample/skel/test/simple_tree_structure_ball_joint.skel");
   fileList.push_back("dart://sample/skel/test/tree_structure.skel");
   fileList.push_back("dart://sample/skel/test/tree_structure_euler_joint.skel");
   fileList.push_back("dart://sample/skel/test/tree_structure_ball_joint.skel");
@@ -80,14 +88,14 @@ std::vector<SkeletonPtr> getSkeletons()
   const auto fileList = getFileList();
 
   std::vector<WorldPtr> worlds;
-  for(std::size_t i=0; i<fileList.size(); ++i)
+  for (std::size_t i = 0; i < fileList.size(); ++i)
     worlds.push_back(utils::SkelParser::readWorld(fileList[i]));
 
   std::vector<SkeletonPtr> skeletons;
-  for(std::size_t i=0; i<worlds.size(); ++i)
+  for (std::size_t i = 0; i < worlds.size(); ++i)
   {
     WorldPtr world = worlds[i];
-    for(std::size_t j=0; j<world->getNumSkeletons(); ++j)
+    for (std::size_t j = 0; j < world->getNumSkeletons(); ++j)
       skeletons.push_back(world->getSkeleton(j));
   }
 
@@ -105,22 +113,22 @@ TEST(MetaSkeleton, Referential)
   std::size_t numIterations = 20;
 #endif
 
-  for(std::size_t i=0; i<skeletons.size(); ++i)
+  for (std::size_t i = 0; i < skeletons.size(); ++i)
   {
     SkeletonPtr skeleton = skeletons[i];
 
     const auto& skelJoints = skeleton->getJoints();
     EXPECT_TRUE(skeleton->getNumJoints() == skelJoints.size());
-    for(auto* joint : skelJoints)
+    for (auto* joint : skelJoints)
       EXPECT_TRUE(skeleton->hasJoint(joint));
 
-    for(std::size_t j=0; j<skeleton->getNumTrees(); ++j)
+    for (std::size_t j = 0; j < skeleton->getNumTrees(); ++j)
     {
       BranchPtr tree = Branch::create(skeleton->getRootBodyNode(j));
 
       const std::vector<BodyNode*>& skelBns = skeleton->getTreeBodyNodes(j);
       EXPECT_TRUE(tree->getNumBodyNodes() == skelBns.size());
-      for(BodyNode* bn : skelBns)
+      for (BodyNode* bn : skelBns)
       {
         EXPECT_FALSE(tree->getIndexOf(bn) == INVALID_INDEX);
         EXPECT_TRUE(tree->getBodyNode(tree->getIndexOf(bn)) == bn);
@@ -129,7 +137,7 @@ TEST(MetaSkeleton, Referential)
 
       const std::vector<DegreeOfFreedom*>& skelDofs = skeleton->getTreeDofs(j);
       EXPECT_TRUE(tree->getNumDofs() == skelDofs.size());
-      for(DegreeOfFreedom* dof : skelDofs)
+      for (DegreeOfFreedom* dof : skelDofs)
       {
         EXPECT_FALSE(tree->getIndexOf(dof) == INVALID_INDEX);
         EXPECT_TRUE(tree->getDof(tree->getIndexOf(dof)) == dof);
@@ -139,9 +147,9 @@ TEST(MetaSkeleton, Referential)
       Eigen::VectorXd dq = tree->getVelocities();
       Eigen::VectorXd ddq = tree->getAccelerations();
 
-      for(std::size_t k=0; k<numIterations; ++k)
+      for (std::size_t k = 0; k < numIterations; ++k)
       {
-        for(int r=0; r<q.size(); ++r)
+        for (int r = 0; r < q.size(); ++r)
         {
           q[r] = math::Random::uniform<double>(-10, 10);
           dq[r] = math::Random::uniform<double>(-10, 10);
@@ -152,9 +160,9 @@ TEST(MetaSkeleton, Referential)
         tree->setVelocities(dq);
         tree->setAccelerations(ddq);
 
-        EXPECT_TRUE( equals(q, tree->getPositions(), 0.0) );
-        EXPECT_TRUE( equals(dq, tree->getVelocities(), 0.0) );
-        EXPECT_TRUE( equals(ddq, tree->getAccelerations(), 0.0) );
+        EXPECT_TRUE(equals(q, tree->getPositions(), 0.0));
+        EXPECT_TRUE(equals(dq, tree->getVelocities(), 0.0));
+        EXPECT_TRUE(equals(ddq, tree->getAccelerations(), 0.0));
 
         const Eigen::MatrixXd& skelMassMatrix = skeleton->getMassMatrix();
         const Eigen::MatrixXd& treeMassMatrix = tree->getMassMatrix();
@@ -184,40 +192,40 @@ TEST(MetaSkeleton, Referential)
         const Eigen::VectorXd& treeFc = tree->getConstraintForces();
 
         const std::size_t nDofs = tree->getNumDofs();
-        for(std::size_t r1=0; r1<nDofs; ++r1)
+        for (std::size_t r1 = 0; r1 < nDofs; ++r1)
         {
           const std::size_t sr1 = tree->getDof(r1)->getIndexInSkeleton();
-          for(std::size_t r2=0; r2<nDofs; ++r2)
+          for (std::size_t r2 = 0; r2 < nDofs; ++r2)
           {
             const std::size_t sr2 = tree->getDof(r2)->getIndexInSkeleton();
 
-            EXPECT_TRUE( skelMassMatrix(sr1,sr2) == treeMassMatrix(r1,r2) );
-            EXPECT_TRUE( skelAugM(sr1,sr2) == treeAugM(r1,r2) );
-            EXPECT_TRUE( skelInvM(sr1,sr2) == treeInvM(r1,r2) );
-            EXPECT_TRUE( skelInvAugM(sr1,sr2) == treeInvAugM(r1,r2) );
+            EXPECT_TRUE(skelMassMatrix(sr1, sr2) == treeMassMatrix(r1, r2));
+            EXPECT_TRUE(skelAugM(sr1, sr2) == treeAugM(r1, r2));
+            EXPECT_TRUE(skelInvM(sr1, sr2) == treeInvM(r1, r2));
+            EXPECT_TRUE(skelInvAugM(sr1, sr2) == treeInvAugM(r1, r2));
           }
 
-          EXPECT_TRUE( skelCvec[sr1] == treeCvec[r1] );
-          EXPECT_TRUE( skelFg[sr1]   == treeFg[r1] );
-          EXPECT_TRUE( skelCg[sr1]   == treeCg[r1] );
-          EXPECT_TRUE( skelFext[sr1] == treeFext[r1] );
-          EXPECT_TRUE( skelFext[sr1] == treeFext[r1] );
-          EXPECT_TRUE( skelFc[sr1]   == treeFc[r1] );
+          EXPECT_TRUE(skelCvec[sr1] == treeCvec[r1]);
+          EXPECT_TRUE(skelFg[sr1] == treeFg[r1]);
+          EXPECT_TRUE(skelCg[sr1] == treeCg[r1]);
+          EXPECT_TRUE(skelFext[sr1] == treeFext[r1]);
+          EXPECT_TRUE(skelFext[sr1] == treeFext[r1]);
+          EXPECT_TRUE(skelFc[sr1] == treeFc[r1]);
         }
 
         const std::size_t numBodyNodes = tree->getNumBodyNodes();
-        for(std::size_t m=0; m<numBodyNodes; ++m)
+        for (std::size_t m = 0; m < numBodyNodes; ++m)
         {
           const BodyNode* bn = tree->getBodyNode(m);
           const Eigen::MatrixXd Jtree = tree->getJacobian(bn);
           const Eigen::MatrixXd Jskel = skeleton->getJacobian(bn);
 
-          for(std::size_t r2=0; r2<nDofs; ++r2)
+          for (std::size_t r2 = 0; r2 < nDofs; ++r2)
           {
             const std::size_t sr2 = tree->getDof(r2)->getIndexInSkeleton();
-            for(std::size_t r1=0; r1<6; ++r1)
+            for (std::size_t r1 = 0; r1 < 6; ++r1)
             {
-              EXPECT_TRUE( Jtree(r1,r2) == Jskel(r1, sr2) );
+              EXPECT_TRUE(Jtree(r1, r2) == Jskel(r1, sr2));
             }
           }
         }
@@ -295,17 +303,17 @@ void checkForBodyNodes(
 //==============================================================================
 // Variadic function for testing a ReferentialSkeleton for a series of BodyNode
 // names
-template <typename ... Args>
+template <typename... Args>
 void checkForBodyNodes(
     std::size_t& count,
     const ReferentialSkeletonPtr& refSkel,
     const SkeletonPtr& skel,
     const std::string& name,
-    Args ... args)
+    Args... args)
 {
   bool contains = refSkel->getIndexOf(skel->getBodyNode(name)) != INVALID_INDEX;
   EXPECT_TRUE(contains);
-  if(!contains)
+  if (!contains)
   {
     dtmsg << "The ReferentialSkeleton [" << refSkel->getName() << "] does NOT "
           << "contain the BodyNode [" << name << "] of the Skeleton ["
@@ -317,21 +325,21 @@ void checkForBodyNodes(
 }
 
 //==============================================================================
-template <typename ... Args>
+template <typename... Args>
 std::size_t checkForBodyNodes(
     const ReferentialSkeletonPtr& refSkel,
     const SkeletonPtr& skel,
     bool checkCount,
-    Args ... args)
+    Args... args)
 {
   std::size_t count = 0;
   checkForBodyNodes(count, refSkel, skel, args...);
 
-  if(checkCount)
+  if (checkCount)
   {
     bool countValid = (count == refSkel->getNumBodyNodes());
     EXPECT_TRUE(countValid);
-    if(!countValid)
+    if (!countValid)
     {
       dtmsg << "The number of BodyNodes checked for [" << count << "] "
             << "does not equal the number [" << refSkel->getNumBodyNodes()
@@ -349,7 +357,7 @@ void checkLinkageJointConsistency(const ReferentialSkeletonPtr& refSkel)
 
   // Linkages should have the property:
   // getJoint(i) == getBodyNode(i)->getParentJoint()
-  for(std::size_t i=0; i < refSkel->getNumJoints(); ++i)
+  for (std::size_t i = 0; i < refSkel->getNumJoints(); ++i)
   {
     EXPECT_EQ(refSkel->getJoint(i), refSkel->getBodyNode(i)->getParentJoint());
     EXPECT_EQ(refSkel->getIndexOf(refSkel->getJoint(i)), i);
@@ -363,78 +371,128 @@ TEST(MetaSkeleton, Linkage)
   SkeletonPtr skel = constructLinkageTestSkeleton();
 
   BranchPtr subtree = Branch::create(skel->getBodyNode("c3b3"), "subtree");
-  checkForBodyNodes(subtree, skel, true,
-                    "c3b3", "c3b4", "c4b1", "c4b2", "c4b3");
+  checkForBodyNodes(
+      subtree, skel, true, "c3b3", "c3b4", "c4b1", "c4b2", "c4b3");
 
-  ChainPtr midchain = Chain::create(skel->getBodyNode("c1b3"),
-                 skel->getBodyNode("c3b4"), "midchain");
+  ChainPtr midchain = Chain::create(
+      skel->getBodyNode("c1b3"), skel->getBodyNode("c3b4"), "midchain");
   checkForBodyNodes(midchain, skel, true, "c3b1", "c3b2", "c3b3");
   checkLinkageJointConsistency(midchain);
 
   Linkage::Criteria criteria;
   criteria.mStart = skel->getBodyNode("c5b2");
   criteria.mTargets.push_back(
-        Linkage::Criteria::Target(skel->getBodyNode("c4b3")));
+      Linkage::Criteria::Target(skel->getBodyNode("c4b3")));
   LinkagePtr path = Linkage::create(criteria, "path");
-  checkForBodyNodes(path, skel, true, "c5b2", "c5b1", "c1b3", "c3b1", "c3b2",
-                                      "c3b3", "c4b1", "c4b2", "c4b3");
+  checkForBodyNodes(
+      path,
+      skel,
+      true,
+      "c5b2",
+      "c5b1",
+      "c1b3",
+      "c3b1",
+      "c3b2",
+      "c3b3",
+      "c4b1",
+      "c4b2",
+      "c4b3");
   checkLinkageJointConsistency(path);
 
   skel->getBodyNode(0)->copyTo(nullptr);
   criteria.mTargets.clear();
   criteria.mStart = skel->getBodyNode("c3b1");
   criteria.mStart.mPolicy = Linkage::Criteria::UPSTREAM;
-  criteria.mTargets.push_back(
-        Linkage::Criteria::Target(skel->getBodyNode("c3b1(1)"),
-                                  Linkage::Criteria::UPSTREAM));
+  criteria.mTargets.push_back(Linkage::Criteria::Target(
+      skel->getBodyNode("c3b1(1)"), Linkage::Criteria::UPSTREAM));
 
   LinkagePtr combinedTreeBases = Linkage::create(criteria, "combinedTreeBases");
-  checkForBodyNodes(combinedTreeBases, skel, true,
-                    "c3b1",    "c1b3",    "c2b1",    "c2b2",    "c2b3",
-                    "c3b1(1)", "c1b3(1)", "c2b1(1)", "c2b2(1)", "c2b3(1)",
-                    "c5b1",    "c5b2",    "c1b2",    "c1b1",
-                    "c5b1(1)", "c5b2(1)", "c1b2(1)", "c1b1(1)");
+  checkForBodyNodes(
+      combinedTreeBases,
+      skel,
+      true,
+      "c3b1",
+      "c1b3",
+      "c2b1",
+      "c2b2",
+      "c2b3",
+      "c3b1(1)",
+      "c1b3(1)",
+      "c2b1(1)",
+      "c2b2(1)",
+      "c2b3(1)",
+      "c5b1",
+      "c5b2",
+      "c1b2",
+      "c1b1",
+      "c5b1(1)",
+      "c5b2(1)",
+      "c1b2(1)",
+      "c1b1(1)");
   checkLinkageJointConsistency(combinedTreeBases);
 
   SkeletonPtr skel2 = skel->getBodyNode(0)->copyAs("skel2");
   criteria.mTargets.clear();
-  criteria.mTargets.push_back(
-        Linkage::Criteria::Target(skel2->getBodyNode("c3b1"),
-                                  Linkage::Criteria::UPSTREAM));
+  criteria.mTargets.push_back(Linkage::Criteria::Target(
+      skel2->getBodyNode("c3b1"), Linkage::Criteria::UPSTREAM));
   LinkagePtr combinedSkelBases = Linkage::create(criteria, "combinedSkelBases");
   std::size_t count = 0;
-  count += checkForBodyNodes(combinedSkelBases, skel, false,
-                             "c3b1", "c1b3", "c2b1", "c2b2", "c2b3",
-                             "c5b1", "c5b2", "c1b2", "c1b1");
-  count += checkForBodyNodes(combinedSkelBases, skel2, false,
-                             "c3b1", "c1b3", "c2b1", "c2b2", "c2b3",
-                             "c5b1", "c5b2", "c1b2", "c1b1");
-  EXPECT_TRUE( count == combinedSkelBases->getNumBodyNodes() );
+  count += checkForBodyNodes(
+      combinedSkelBases,
+      skel,
+      false,
+      "c3b1",
+      "c1b3",
+      "c2b1",
+      "c2b2",
+      "c2b3",
+      "c5b1",
+      "c5b2",
+      "c1b2",
+      "c1b1");
+  count += checkForBodyNodes(
+      combinedSkelBases,
+      skel2,
+      false,
+      "c3b1",
+      "c1b3",
+      "c2b1",
+      "c2b2",
+      "c2b3",
+      "c5b1",
+      "c5b2",
+      "c1b2",
+      "c1b1");
+  EXPECT_TRUE(count == combinedSkelBases->getNumBodyNodes());
 
-  ChainPtr downstreamFreeJoint = Chain::create(skel->getBodyNode("c1b1"),
-      skel->getBodyNode("c1b3"), Chain::IncludeUpstreamParentJoint,
+  ChainPtr downstreamFreeJoint = Chain::create(
+      skel->getBodyNode("c1b1"),
+      skel->getBodyNode("c1b3"),
+      Chain::IncludeUpstreamParentJoint,
       "downstreamFreeJoint");
   checkForBodyNodes(downstreamFreeJoint, skel, true, "c1b1");
   checkLinkageJointConsistency(downstreamFreeJoint);
 
-  ChainPtr emptyChain = Chain::create(skel->getBodyNode("c1b1"),
-      skel->getBodyNode("c1b3"), "emptyChain");
+  ChainPtr emptyChain = Chain::create(
+      skel->getBodyNode("c1b1"), skel->getBodyNode("c1b3"), "emptyChain");
   checkForBodyNodes(emptyChain, skel, true);
   checkLinkageJointConsistency(emptyChain);
 
-  ChainPtr chainFromNull = Chain::create(nullptr, skel->getBodyNode("c1b2"),
-                                         "chainFromNull");
+  ChainPtr chainFromNull
+      = Chain::create(nullptr, skel->getBodyNode("c1b2"), "chainFromNull");
   checkForBodyNodes(chainFromNull, skel, true, "c1b1");
   checkLinkageJointConsistency(chainFromNull);
 
-  ChainPtr upstreamFreeJoint = Chain::create(skel->getBodyNode("c1b3"),
-                          skel->getBodyNode("c1b1"), "upstreamFreeJoint");
+  ChainPtr upstreamFreeJoint = Chain::create(
+      skel->getBodyNode("c1b3"),
+      skel->getBodyNode("c1b1"),
+      "upstreamFreeJoint");
   checkForBodyNodes(upstreamFreeJoint, skel, true, "c1b3", "c1b2");
   checkLinkageJointConsistency(upstreamFreeJoint);
 
   // Using nullptr as the target should bring us towards the root of the tree
-  ChainPtr upTowardsRoot =
-      Chain::create(skel->getBodyNode("c1b3"), nullptr, "upTowardsRoot");
+  ChainPtr upTowardsRoot
+      = Chain::create(skel->getBodyNode("c1b3"), nullptr, "upTowardsRoot");
   checkForBodyNodes(upTowardsRoot, skel, true, "c1b3", "c1b2");
   checkLinkageJointConsistency(upTowardsRoot);
 
@@ -443,8 +501,7 @@ TEST(MetaSkeleton, Linkage)
   criteria.mStart = skel->getBodyNode("c1b3");
   criteria.mTerminals.push_back(skel->getBodyNode("c3b2"));
   LinkagePtr terminatedLinkage = Linkage::create(criteria, "terminatedLinkage");
-  checkForBodyNodes(terminatedLinkage, skel, true,
-                    "c1b3", "c3b1", "c3b2");
+  checkForBodyNodes(terminatedLinkage, skel, true, "c1b3", "c3b1", "c3b2");
   checkLinkageJointConsistency(terminatedLinkage);
 
   criteria.mStart = skel->getBodyNode("c1b1");
@@ -452,19 +509,37 @@ TEST(MetaSkeleton, Linkage)
   criteria.mTargets.clear();
   criteria.mTerminals.clear();
   criteria.mTerminals.push_back(
-        Linkage::Criteria::Terminal(skel->getBodyNode("c2b1"), false));
+      Linkage::Criteria::Terminal(skel->getBodyNode("c2b1"), false));
   criteria.mTerminals.push_back(skel->getBodyNode("c3b3"));
   LinkagePtr terminatedSubtree = Linkage::create(criteria, "terminatedSubtree");
-  checkForBodyNodes(terminatedSubtree, skel, true,
-                    "c1b1", "c1b2", "c1b3", "c5b1",
-                    "c5b2", "c3b1", "c3b2", "c3b3");
+  checkForBodyNodes(
+      terminatedSubtree,
+      skel,
+      true,
+      "c1b1",
+      "c1b2",
+      "c1b3",
+      "c5b1",
+      "c5b2",
+      "c3b1",
+      "c3b2",
+      "c3b3");
   checkLinkageJointConsistency(terminatedSubtree);
 
   criteria.mStart.mPolicy = Linkage::Criteria::UPSTREAM;
   criteria.mStart.mNode = skel->getBodyNode("c3b1");
-  LinkagePtr terminatedUpstream = Linkage::create(criteria, "terminatedUpstream");
-  checkForBodyNodes(terminatedUpstream, skel, true,
-                    "c3b1", "c1b3", "c5b1", "c5b2", "c1b2", "c1b1");
+  LinkagePtr terminatedUpstream
+      = Linkage::create(criteria, "terminatedUpstream");
+  checkForBodyNodes(
+      terminatedUpstream,
+      skel,
+      true,
+      "c3b1",
+      "c1b3",
+      "c5b1",
+      "c5b2",
+      "c1b2",
+      "c1b1");
   checkLinkageJointConsistency(terminatedUpstream);
 
   // Sequence linkage 1
@@ -479,8 +554,16 @@ TEST(MetaSkeleton, Linkage)
   Linkage::Criteria sequenceCriteria2(nullptr, skel->getBodyNode("c4b1"), true);
   LinkagePtr sequenceLinkage2 = Linkage::create(sequenceCriteria2, "sequence");
   checkForBodyNodes(
-      sequenceLinkage2, skel, true,
-      "c1b1", "c1b2", "c1b3", "c3b1", "c3b2", "c3b3", "c4b1");
+      sequenceLinkage2,
+      skel,
+      true,
+      "c1b1",
+      "c1b2",
+      "c1b3",
+      "c3b1",
+      "c3b2",
+      "c3b3",
+      "c4b1");
   checkLinkageJointConsistency(sequenceLinkage2);
 
   // Sequence linkage 3: nullptr target
@@ -492,11 +575,9 @@ TEST(MetaSkeleton, Linkage)
   // Sequence linkage 4: reversed
   Linkage::Criteria sequenceCriteria4(
       skel->getBodyNode("c4b1"), skel->getBodyNode("c1b3"), true);
-  LinkagePtr sequenceLinkage4
-      = Linkage::create(sequenceCriteria4, "sequence");
+  LinkagePtr sequenceLinkage4 = Linkage::create(sequenceCriteria4, "sequence");
   checkForBodyNodes(
-      sequenceLinkage4, skel, true,
-      "c1b3", "c3b1", "c3b2", "c3b3", "c4b1");
+      sequenceLinkage4, skel, true, "c1b3", "c3b1", "c3b2", "c3b3", "c4b1");
   checkLinkageJointConsistency(sequenceLinkage4);
 
   // Sequence linkage 5: empty
@@ -535,13 +616,13 @@ TEST(MetaSkeleton, Group)
   EXPECT_EQ(skel1Group->getNumJoints(), skel->getNumJoints());
   EXPECT_EQ(skel1Group->getNumDofs(), skel->getNumDofs());
 
-  for(std::size_t i=0; i < skel1Group->getNumBodyNodes(); ++i)
+  for (std::size_t i = 0; i < skel1Group->getNumBodyNodes(); ++i)
     EXPECT_EQ(skel1Group->getBodyNode(i), skel->getBodyNode(i));
 
-  for(std::size_t i=0; i < skel1Group->getNumJoints(); ++i)
+  for (std::size_t i = 0; i < skel1Group->getNumJoints(); ++i)
     EXPECT_EQ(skel1Group->getJoint(i), skel->getJoint(i));
 
-  for(std::size_t i=0; i < skel1Group->getNumDofs(); ++i)
+  for (std::size_t i = 0; i < skel1Group->getNumDofs(); ++i)
     EXPECT_EQ(skel1Group->getDof(i), skel->getDof(i));
 
   // Test arbitrary Groups by plucking random BodyNodes, Joints, and
@@ -550,21 +631,22 @@ TEST(MetaSkeleton, Group)
   std::vector<BodyNode*> bodyNodes;
   std::vector<Joint*> joints;
   std::vector<DegreeOfFreedom*> dofs;
-  for(std::size_t i=0; i < 2*skel->getNumBodyNodes(); ++i)
+  for (std::size_t i = 0; i < 2 * skel->getNumBodyNodes(); ++i)
   {
-    std::size_t randomIndex = Random::uniform<std::size_t>(0, skel->getNumBodyNodes()-1);
+    std::size_t randomIndex
+        = Random::uniform<std::size_t>(0, skel->getNumBodyNodes() - 1);
     BodyNode* bn = skel->getBodyNode(randomIndex);
-    if(group->addBodyNode(bn, false))
+    if (group->addBodyNode(bn, false))
       bodyNodes.push_back(bn);
 
-    randomIndex = Random::uniform<std::size_t>(0, skel->getNumJoints()-1);
+    randomIndex = Random::uniform<std::size_t>(0, skel->getNumJoints() - 1);
     Joint* joint = skel->getJoint(randomIndex);
-    if(group->addJoint(joint, false, false))
+    if (group->addJoint(joint, false, false))
       joints.push_back(joint);
 
-    randomIndex = Random::uniform<std::size_t>(0, skel->getNumDofs()-1);
+    randomIndex = Random::uniform<std::size_t>(0, skel->getNumDofs() - 1);
     DegreeOfFreedom* dof = skel->getDof(randomIndex);
-    if(group->addDof(dof, false, false))
+    if (group->addDof(dof, false, false))
       dofs.push_back(dof);
   }
 
@@ -572,13 +654,13 @@ TEST(MetaSkeleton, Group)
   EXPECT_EQ(group->getNumJoints(), joints.size());
   EXPECT_EQ(group->getNumDofs(), dofs.size());
 
-  for(std::size_t i=0; i < group->getNumBodyNodes(); ++i)
+  for (std::size_t i = 0; i < group->getNumBodyNodes(); ++i)
     EXPECT_EQ(group->getBodyNode(i), bodyNodes[i]);
 
-  for(std::size_t i=0; i < group->getNumJoints(); ++i)
+  for (std::size_t i = 0; i < group->getNumJoints(); ++i)
     EXPECT_EQ(group->getJoint(i), joints[i]);
 
-  for(std::size_t i=0; i < group->getNumDofs(); ++i)
+  for (std::size_t i = 0; i < group->getNumDofs(); ++i)
     EXPECT_EQ(group->getDof(i), dofs[i]);
 }
 
@@ -589,11 +671,11 @@ TEST(MetaSkeleton, LockSkeletonMutexesWithLockGuard)
   SkeletonPtr skel = constructLinkageTestSkeleton();
 
   BranchPtr subtree = Branch::create(skel->getBodyNode("c3b3"), "subtree");
-  checkForBodyNodes(subtree, skel, true,
-                    "c3b3", "c3b4", "c4b1", "c4b2", "c4b3");
+  checkForBodyNodes(
+      subtree, skel, true, "c3b3", "c3b4", "c4b1", "c4b2", "c4b3");
 
-  ChainPtr midchain = Chain::create(skel->getBodyNode("c1b3"),
-                 skel->getBodyNode("c3b4"), "midchain");
+  ChainPtr midchain = Chain::create(
+      skel->getBodyNode("c1b3"), skel->getBodyNode("c3b4"), "midchain");
   checkForBodyNodes(midchain, skel, true, "c3b1", "c3b2", "c3b3");
   checkLinkageJointConsistency(midchain);
 
@@ -711,10 +793,12 @@ TEST(MetaSkeleton, GetJointsAndBodyNodes)
   group->addJoint(jointB0);
   EXPECT_TRUE(group->getJoints("wrong name").empty());
   EXPECT_TRUE(group->getBodyNodes("wrong name").empty());
-  EXPECT_TRUE(group->getBodyNode("bodyNode0") == bodyNodeA0
-              || group->getBodyNode("bodyNode0") == bodyNodeB0);
-  EXPECT_TRUE(group->getJoint("joint0") == jointA0
-              || group->getJoint("joint0") == jointB0);
+  EXPECT_TRUE(
+      group->getBodyNode("bodyNode0") == bodyNodeA0
+      || group->getBodyNode("bodyNode0") == bodyNodeB0);
+  EXPECT_TRUE(
+      group->getJoint("joint0") == jointA0
+      || group->getJoint("joint0") == jointB0);
   EXPECT_EQ(group->getBodyNodes("bodyNode0").size(), 2u);
   EXPECT_EQ(group->getBodyNodes("bodyNode1").size(), 0u);
   EXPECT_EQ(group->getBodyNodes("bodyNode2").size(), 0u);
@@ -806,8 +890,8 @@ TEST(MetaSkeleton, CloneReferentialSkeletons)
   group->addBodyNode(skel2->getBodyNode(0));
   group->addJoint(skel1->getJoint(1));
   group->addJoint(skel2->getJoint(1));
-  GroupPtr groupClone = std::dynamic_pointer_cast<Group>(
-      group->cloneMetaSkeleton());
+  GroupPtr groupClone
+      = std::dynamic_pointer_cast<Group>(group->cloneMetaSkeleton());
   testReferentialSkeletonClone(group, groupClone);
 
   // Linkage
@@ -816,22 +900,22 @@ TEST(MetaSkeleton, CloneReferentialSkeletons)
   criteria.mTargets.push_back(
       Linkage::Criteria::Target(skel1->getBodyNode("c4b3")));
   LinkagePtr linkage = Linkage::create(criteria);
-  LinkagePtr linkageClone = std::dynamic_pointer_cast<Linkage>(
-      linkage->cloneMetaSkeleton());
+  LinkagePtr linkageClone
+      = std::dynamic_pointer_cast<Linkage>(linkage->cloneMetaSkeleton());
   testReferentialSkeletonClone(linkage, linkageClone);
 
   // Chain
   ChainPtr chain = Chain::create(
       skel1->getBodyNode("c1b3"), skel1->getBodyNode("c3b4"), "midchain");
-  ChainPtr chainClone = std::dynamic_pointer_cast<Chain>(
-      chain->cloneMetaSkeleton());
+  ChainPtr chainClone
+      = std::dynamic_pointer_cast<Chain>(chain->cloneMetaSkeleton());
   testReferentialSkeletonClone(chain, chainClone);
 
   // Branch
   BranchPtr branch = Branch::create(skel1->getBodyNode("c3b3"), "subtree");
   checkForBodyNodes(
       branch, skel1, true, "c3b3", "c3b4", "c4b1", "c4b2", "c4b3");
-  BranchPtr branchClone = std::dynamic_pointer_cast<Branch>(
-      branch->cloneMetaSkeleton());
+  BranchPtr branchClone
+      = std::dynamic_pointer_cast<Branch>(branch->cloneMetaSkeleton());
   testReferentialSkeletonClone(branch, branchClone);
 }
